[{"id":"node_modules/@jenkins-cd/js-modules/js/ModuleSpec.js","source":"var Version = require('./Version');\n\nfunction ModuleSpec(qName) {\n    var qNameTokens = qName.split(\":\");\n    \n    if (qNameTokens.length === 2) {\n        var namespace = qNameTokens[0].trim();\n        var nsTokens = namespace.split(\"/\");\n        var namespaceProvider = undefined;\n        if (nsTokens.length === 2) {\n            namespaceProvider = nsTokens[0].trim();\n            namespace = nsTokens[1].trim();\n            if (namespaceProvider !== 'plugin' && namespaceProvider !== 'core-assets') {\n                console.error('Unsupported module namespace provider \"' + namespaceProvider + '\". Setting to undefined.');\n                namespaceProvider = undefined;\n            }\n        }\n        \n        var npmName = parseNPMName(qNameTokens[1].trim());\n        \n        this.nsProvider = namespaceProvider;\n        this.namespace = namespace;\n        this.moduleName = npmName.name;\n        this.moduleVersion = npmName.version;\n    } else {\n        // The module/bundle is not in a namespace and doesn't\n        // need to be loaded i.e. it will load itself and export.\n        var npmName = parseNPMName(qNameTokens[0].trim());\n\n        this.moduleName = npmName.name;\n        this.moduleVersion = npmName.version;\n    }\n\n    // Attach version compatibility info\n    var versions = [];\n    \n    if (this.moduleVersion) {\n        var moduleVersionTokens = this.moduleVersion.split(/[,|]+/);\n\n        for (var i = 0; i < moduleVersionTokens.length; i++) {\n            var moduleVersionToken = moduleVersionTokens[i].trim();\n            var parsedVersion = new Version(moduleVersionToken);\n            versions.push(parsedVersion);\n        }\n    }\n    \n    this.moduleCompatVersions = versions;\n}\n\nModuleSpec.prototype.getLoadBundleVersion = function() {\n    if (this.moduleCompatVersions.length === 0) {\n        // If no versions were specified on the name, then we\n        // just return undefined.\n        return undefined;\n    }\n    // If a version is specified, we use the first \"specific\" version\n    // e.g. \"1.1.2\" is specific while \"1.1.x\" and \"any\" are not.\n    for (var i = 0; i < this.moduleCompatVersions.length; i++) {\n        var version = this.moduleCompatVersions[i];\n        if (version.isSpecific()) {\n            return version;\n        }\n    }\n    \n    // If there's no specific version then we return the first\n    // version in the list.\n    return this.moduleCompatVersions[0];\n};\n\nModuleSpec.prototype.getLoadBundleName = function() {\n    var version = this.getLoadBundleVersion();\n    if (version) {\n        return this.moduleName + '@' + version.asBaseVersionString();\n    } else {\n        return this.moduleName;\n    }\n};\n\nModuleSpec.prototype.importAs = function() {\n    if (this.moduleName.charAt(0) === '.') {\n        return this.moduleName;\n    }\n    \n    var version = this.getLoadBundleVersion();\n    var importName = normalizePackageName(this.moduleName);\n    var importNS = this.namespace;\n    \n    if (!importNS) {\n        importNS = importName;\n    }\n    \n    var importAs = importNS + ':' + importName;\n    if (this.nsProvider) {\n        importAs = this.nsProvider + '/' + importAs;\n    }\n    if (version) {\n        importAs += '@' + version.asBaseVersionString();\n    }\n    \n    return importAs;\n};\n\nModuleSpec.prototype.getLoadBundleFileNamePrefix = function() {\n    var version = this.getLoadBundleVersion();\n    var normalizedName = normalizePackageName(this.moduleName);\n    if (version) {\n        // If a version was specified then we only do the script load if a\n        // specific version was provided i.e. loading does not get triggered\n        // by imports that specify non-specific version numbers e.g. \"any\"\n        // or \"1.2.x\". A specific version number would be e.g. \"1.2.3\" i.e.\n        // fully qualified. When loading is not triggered, the import is depending\n        // on another import (with a specific version) or on a bundle do an\n        // export of an internal dependency i.e. on another bundle \"providing\"\n        // the module be exporting it.\n        if (version.isSpecific()) {\n            return normalizedName + '-' + version.asLoadVersionString();\n        } else {\n            return undefined;\n        }\n    } else {\n        return normalizedName;\n    }\n};\n\n/**\n * Normalize an NPM package name by removing all non alpha numerics and replacing\n * with hyphens.\n * @param packageName The NPM package name.\n * @returns The normalized NPM package name.\n */\nfunction normalizePackageName(packageName) {\n    packageName = packageName.replace(/[^\\w.]/g, \"-\"); // replace non alphanumerics.\n    if (packageName.charAt(0) === '-') {\n        packageName = packageName.substring(1);\n    }\n    return packageName;\n};\n\nfunction parseNPMName(resourceName) {\n    if (resourceName.length > 1) {\n        var npmName = {};\n        var orgSlashIndex = resourceName.indexOf('/');\n        \n        if (resourceName.charAt(0) === '@' && orgSlashIndex > 0) {\n            // It's an NPM org package. Strip off the org and package\n            // and add it to the name. We'll get the rest then and parse\n            // that.\n            npmName.name = resourceName.substring(0, orgSlashIndex + 1);\n            \n            // Remove the org part from the name and continue parsing.\n            resourceName = resourceName.substring(orgSlashIndex + 1);\n        } else {\n            // Initialise it so we can append to it below.\n            npmName.name = '';\n        }\n        \n        var versionIndex = resourceName.indexOf('@');\n        if (versionIndex > 0) {\n            npmName.name += resourceName.substring(0, versionIndex);\n            npmName.version = resourceName.substring(versionIndex + 1);\n        } else {\n            npmName.name += resourceName;\n        }\n        \n        return npmName;\n    } else {\n        return {\n            name: resourceName\n        }\n    }\n}\n\nmodule.exports = ModuleSpec;","deps":{"./Version":"node_modules/@jenkins-cd/js-modules/js/Version.js"}},{"id":"node_modules/@jenkins-cd/js-modules/js/ResourceLocationResolver.js","source":"function ResourceLocationResolver(canResolveFunc, resolverFunc, ordinal) {\n    this.canResolveFunc = canResolveFunc;\n    this.resolverFunc = resolverFunc;\n    // Use an ordinal for crude ordering\n    if (typeof ordinal === 'number') {\n        this.ordinal = ordinal;\n    } else {\n        this.ordinal = Number.MAX_VALUE;\n    }\n}\n\nResourceLocationResolver.prototype.canResolve = function(moduleSpec) {\n    return this.canResolveFunc(moduleSpec);\n};\n\nResourceLocationResolver.sort = function (resolvers) {\n    resolvers.sort(function(r1, r2) {\n        return r2.ordinal - r1.ordinal;\n    });\n};\n\nmodule.exports = ResourceLocationResolver;","deps":{}},{"id":"node_modules/@jenkins-cd/js-modules/js/Version.js","source":"function Version(version) {\n    this.raw = version;\n\n    // Remove leading non alphanum chars e.g. to\n    // convert \"^1.2.3\" to \"1.2.3\". If the version is something\n    // like \"any\" then the string will be trimmed to nothing and\n    // the next check catches it.\n    version = version.replace(/^(\\D)/, \"\");\n    \n    if (!version || version.length === 0) {\n        return;\n    }\n    \n    function normalizeToken(string) {\n        // remove anything that's not a digit, a dot or an x.\n        var normalized = string.replace(/[^\\d]/g, '');\n        if (normalized === '') {\n            return undefined;\n        }\n        return normalized;\n    }\n    \n    var versionTokens = version.split('.');\n    \n    this.prerelease = undefined;\n    \n    var patchAndPrerelease = '';\n    for (var i = 2; i < versionTokens.length; i++) {\n        if (patchAndPrerelease.length > 0) {\n            patchAndPrerelease += '.';\n        }\n        patchAndPrerelease += versionTokens[i];\n        \n        var separatorIdx = patchAndPrerelease.indexOf('-');\n        if (separatorIdx !== -1) {\n            this.patch = normalizeToken(patchAndPrerelease.substring(0, separatorIdx));\n            this.prerelease = patchAndPrerelease.substring(separatorIdx + 1);\n        } else {\n            this.patch = normalizeToken(patchAndPrerelease);\n        }\n    }\n    \n    if (versionTokens.length >= 2) {\n        this.minor = normalizeToken(versionTokens[1]);\n    }\n    if (versionTokens.length >= 1) {\n        this.major = normalizeToken(versionTokens[0]);\n    }    \n}\n\nVersion.prototype.isSpecific = function() {\n    return (this.major !== undefined && this.minor !== undefined && this.patch !== undefined);\n};\n\n/**\n * Get the \"base\" version string for this version number.\n * <p/>\n * This string should only ever include the major, minor and patch tokens\n * of the version i.e. should never include a prerelease tag.\n * @returns {string}\n */\nVersion.prototype.asBaseVersionString = function(separator) {\n    separator = (separator ? separator : '.');\n    \n    if (!this.major || this.major === 'x') {\n        if (this.raw === 'any') {\n            return this.raw;\n        } else {\n            return undefined;\n        }\n    } else if (!this.minor || this.minor === 'x') {\n        return this.major + separator + 'x';\n    } else if (!this.patch || this.patch === 'x') {\n        return this.major + separator + this.minor + separator + 'x';\n    } else {\n        return this.major + separator + this.minor + separator + this.patch;\n    }\n};\n\n/**\n * Get the load version string for this version number.\n * <p/>\n * This string should only ever include the major, minor and patch tokens\n * of the version i.e. should never include a prerelease tag. This function\n * just calls <code>asBaseVersionString</code>, supplying a hyphen as the\n * separator.\n * @returns {string}\n */\nVersion.prototype.asLoadVersionString = function() {\n    return this.asBaseVersionString('-');\n};\n\nmodule.exports = Version;","deps":{}},{"id":"node_modules/@jenkins-cd/js-modules/js/index.js","source":"var internal = require(\"./internal\");\nvar promise = require(\"./promise\");\nvar ModuleSpec = require('./ModuleSpec');\nvar onRegisterTimeout;\nvar whoami;\n\n/**\n * What's the top level module/bundle name.\n * @param moduleQName The module QName.\n * @returns The module QName, or undefined if unknown.\n */\nexports.whoami = function(moduleQName) {\n    if (moduleQName) {\n        whoami = moduleQName;\n        internal.whoami(whoami);\n    }\n    return whoami;\n};\n\n/**\n * Asynchronously import/require a set of modules.\n *\n * <p>\n * Responsible for triggering the async loading of modules if a given module is not already loaded.\n *\n * @param moduleQNames... A list of module \"qualified\" names, each containing the module name prefixed with the namespace\n * and separated by a colon i.e. \"<namespace>:<moduleName>\" e.g. \"jquery:jquery2\".\n *\n * @return A Promise, allowing async load of all modules. The promise is only fulfilled when all modules are loaded.\n */\nexports.importModule = function() {\n    if (arguments.length === 1) {\n        return internal.importModule(arguments[0], onRegisterTimeout);\n    }\n\n    var moduleQNames = [];\n    for (var i = 0; i < arguments.length; i++) {\n        var argument = arguments[i];\n        if (typeof argument === 'string') {\n            moduleQNames.push(argument);\n        }\n    }\n\n    if (moduleQNames.length == 0) {\n        throw new Error(\"No module names specified.\");\n    }\n\n    return promise.make(function (resolve, reject) {\n        var fulfillments = [];\n\n        function onFulfillment() {\n            if (fulfillments.length === moduleQNames.length) {\n                var modules = [];\n                for (var i = 0; i < fulfillments.length; i++) {\n                    if (fulfillments[i].value) {\n                        modules.push(fulfillments[i].value);\n                    } else {\n                        // don't have everything yet so can't fulfill all.\n                        return;\n                    }\n                }\n                // If we make it here, then we have fulfilled all individual promises, which \n                // means we can now fulfill the top level import promise.\n                resolve(modules);\n            }\n        }\n\n        // doRequire for each module\n        for (var i = 0; i < moduleQNames.length; i++) {\n            function doRequire(moduleQName) {\n                var promise = internal.importModule(moduleQName, onRegisterTimeout);\n                var fulfillment = {\n                    promise: promise,\n                    value: undefined\n                };\n                fulfillments.push(fulfillment);\n                promise\n                    .onFulfilled(function(value) {\n                        fulfillment.value = value;\n                        onFulfillment();\n                    })\n                    .onRejected(function(error) {\n                        reject(error);\n                    });\n            }\n            doRequire(moduleQNames[i]);\n        }\n    }).applyArgsOnFulfill();\n};\n\n/**\n * Synchronously \"require\" a module that it already loaded/registered.\n *\n * <p>\n * This function will throw an error if the module is not already loaded via an outer call to 'import'\n * (or 'import').\n *\n * @param moduleQName The module \"qualified\" name containing the module name prefixed with the namespace\n * separated by a colon i.e. \"<namespace>:<moduleName>\" e.g. \"jquery:jquery2\".\n *\n * @return The module.\n */\nexports.requireModule = function(moduleQName) {\n    var parsedModuleName = new ModuleSpec(moduleQName);\n    var module = internal.getModule(parsedModuleName);\n    if (!module) {\n        throw new Error(\"Unable to perform synchronous 'require' for module '\" + moduleQName + \"'. This module is not pre-loaded. \" +\n            \"The module needs to have been asynchronously pre-loaded via an outer call to 'import'.\");\n    }\n    return module.exports;\n};\n\n/**\n * Export a module.\n *\n * @param namespace The namespace in which the module resides, or \"undefined\" if the modules is in\n * the \"global\" module namespace e.g. a Jenkins core bundle.\n * @param moduleName The name of the module.\n * @param module The CommonJS style module, or \"undefined\" if we just want to notify other modules waiting on\n * the loading of this module.\n * @param onError On error callback;\n */\nexports.exportModule = function(namespace, moduleName, module, onError) {\n    try {\n        var moduleQName = (namespace ? namespace + ':' : '') + moduleName;\n        var moduleSpec = new ModuleSpec(moduleQName);\n        var moduleNamespaceObj = internal.getModuleNamespaceObj(moduleSpec);\n        var moduleLoadName = moduleSpec.getLoadBundleName();\n\n        if (moduleNamespaceObj[moduleLoadName]) {\n            if (namespace) {\n                console.debug(\"Jenkins plugin module '\" + namespace + \":\" + moduleName + \"' already registered.\");\n            } else {\n                console.debug(\"Jenkins global module '\" + moduleName + \"' already registered.\");\n            }\n            return;\n        }\n\n        if (!module) {\n            module = {\n                exports: {}\n            };\n        } else if (module.exports === undefined) {\n            module = {\n                exports: module\n            };\n        }\n        moduleNamespaceObj[moduleLoadName] = module;\n\n        // Notify all that the module has been registered. See internal.loadModule also.\n        internal.notifyModuleExported(moduleSpec, module.exports);\n    } catch (e) {\n        console.error(e);\n        if (onError) {\n            onError(e);\n        }\n    }\n};\n\n/**\n * Add a resource resolver.\n * @param {ResourceLocationResolver} resourceLocationResolver The resource resolver.\n */\nexports.addResourceLocationResolver = function(resourceLocationResolver) {\n    internal.addResourceLocationResolver(resourceLocationResolver);\n};\n\n/**\n * Get the ResourceLocationResolver function for the supplied ModuleSpec.\n * @param {ModuleSpec} moduleSpec The ModuleSpec.\n * @returns {function} The ResourceLocationResolver function for the supplied\n * ModuleSpec, or null if none specified.\n */\nexports.getResourceLocationResolver = function (moduleSpec) {\n    if (typeof moduleSpec === 'string') {\n        moduleSpec = new ModuleSpec(moduleSpec);\n    }\n    var resolver = internal.getResourceLocationResolverFunc(moduleSpec);\n    if (resolver) {\n        return function(resourcePath) {\n            return resolver(moduleSpec, resourcePath);\n        }\n    }\n    return undefined;\n};\n\n/**\n * Add a module's CSS to the browser page.\n *\n * <p>\n * The assumption is that the CSS can be accessed at e.g.\n * {@code <rootURL>/plugin/<namespace>/jsmodules/<moduleName>/style.css} i.e.\n * the pluginId acts as the namespace.\n *\n * @param namespace The namespace in which the module resides.\n * @param moduleName The name of the module.\n * @param onError On error callback;\n */\nexports.addModuleCSSToPage = function(namespace, moduleName, onError) {\n    try {\n        internal.addModuleCSSToPage(namespace, moduleName);\n    } catch (e) {\n        console.error(e);\n        if (onError) {\n            onError(e);\n        }\n    }\n};\n\n/**\n * Add a plugin CSS file to the browser page.\n *\n * @param pluginName The Jenkins plugin in which the module resides.\n * @param cssPath The CSS path.\n * @param onError On error callback;\n */\nexports.addPluginCSSToPage = function(pluginName, cssPath, onError) {\n    try {\n        internal.addPluginCSSToPage(pluginName, cssPath);\n    } catch (e) {\n        console.error(e);\n        if (onError) {\n            onError(e);\n        }\n    }\n};\n\n/**\n * Create a js-modules CSS id that can be used to refer to a link element.\n * @param cssPath The CSS path/url.\n * @param namespace Optional namespace.\n */\nexports.toCSSId = function (cssPath, namespace) {\n    return internal.toCSSId(cssPath, namespace);\n};\n\n/**\n * Add CSS file to the browser page.\n *\n * @param cssPath The CSS path.\n * @param onError On error callback;\n */\nexports.addCSSToPage = function(cssPath, onError) {\n    try {\n        if (cssPath.indexOf(internal.getAdjunctURL()) === 0) {\n            internal.addCSSToPage(undefined, cssPath);\n        } else if (cssPath.indexOf('http://') === 0 || cssPath.indexOf('https://') === 0) {\n            // the css path is already fully qualified\n            internal.addCSSToPage(undefined, cssPath);\n        } else {\n            internal.addCSSToPage(undefined, internal.getRootURL() + '/' + cssPath);\n        }\n    } catch (e) {\n        console.error(e);\n        if (onError) {\n            onError(e);\n        }\n    }\n};\n\n/**\n * Add a javascript &lt;script&gt; element to the document &lt;head&gt;.\n * <p/>\n * Options:\n * <ul>\n *     <li><strong>scriptId</strong>: The script Id to use for the element. If not specified, one will be generated from the scriptSrc.</li>\n *     <li><strong>async</strong>: Asynchronous loading of the script. Default is 'true'.</li>\n *     <li><strong>success</strong>: An optional onload success function for the script element.</li>\n *     <li><strong>error</strong>: An optional onload error function for the script element. This is called if the .js file exists but there's an error evaluating the script. It is NOT called if the .js file doesn't exist (ala 404).</li>\n *     <li><strong>removeElementOnLoad</strong>: Remove the script element after loading the script. Default is 'false'.</li>\n * </ul>\n *\n * @param scriptSrc The script src.\n * @param options Optional script load options object. See above.\n */\nexports.addScript = function(scriptSrc, options) {\n    internal.addScript(scriptSrc, options);\n};\n\n/**\n * Set the module registration timeout i.e. the length of time to wait for a module to load before failing.\n *\n * @param timeout Millisecond duration before onRegister times out. Defaults to 10000 (10s) if not specified.\n */\nexports.setRegisterTimeout = function(timeout) {\n    onRegisterTimeout = timeout;\n}\n\n/**\n * Set the Jenkins root/base URL.\n *\n * @param rootUrl The root/base URL.\n */\nexports.setRootURL = function(rootUrl) {\n    internal.setRootURL(rootUrl);\n};\n\nexports.getRootURL = internal.getRootURL;\nexports.getAdjunctURL = internal.getAdjunctURL;\n\n/**\n * Manually initialise the Jenkins Global.\n * <p>\n * This should only ever be called from a test environment.\n */\nexports.initJenkinsGlobal = function() {\n    internal.initJenkinsGlobal();\n};\n\ninternal.onJenkinsGlobalInit(function(jenkinsCIGlobal) {\n    // For backward compatibility, we need to make some js-modules\n    // functions globally available e.g. to allow legacy code wait for\n    // certain modules to be loaded, as with legacy adjuncts.\n    if (!jenkinsCIGlobal._internal) {\n        // Put the functions on an object called '_internal' as a way\n        // of hinting to people to not use it.\n        jenkinsCIGlobal._internal = {\n            importModule: exports.importModule,\n            addScript: internal.addScript\n        };\n    }\n});","deps":{"./ModuleSpec":"node_modules/@jenkins-cd/js-modules/js/ModuleSpec.js","./internal":"node_modules/@jenkins-cd/js-modules/js/internal.js","./promise":"node_modules/@jenkins-cd/js-modules/js/promise.js"}},{"id":"node_modules/@jenkins-cd/js-modules/js/internal.js","source":"var promise = require(\"./promise\");\nvar ModuleSpec = require('./ModuleSpec');\nvar ResourceLocationResolver = require('./ResourceLocationResolver');\n\nvar jenkinsCIGlobal;\nvar globalInitListeners = [];\nvar whoami;\n\nexports.whoami = function(moduleQName) {\n    if (moduleQName) {\n        whoami = new ModuleSpec(moduleQName);\n        whoami.nsProvider = getBundleNSProviderFromScriptElement(whoami.namespace, whoami.moduleName);\n    }\n    return whoami;\n};\n\nexports.onJenkinsGlobalInit = function(callback) {\n    globalInitListeners.push(callback);\n};\n\nexports.initJenkinsGlobal = function() {\n    jenkinsCIGlobal = {\n    };\n    if (globalInitListeners) {\n        for (var i = 0; i < globalInitListeners.length; i++) {\n            globalInitListeners[i](jenkinsCIGlobal);\n        }\n    }\n};\n\nexports.clearJenkinsGlobal = function() {    \n    jenkinsCIGlobal = undefined;\n    whoami = undefined;\n};\n\nexports.addResourceLocationResolver = function(resourceLocationResolver) {\n    var resolvers = getResourceLocationResolvers();\n    resolvers.push(resourceLocationResolver);\n    ResourceLocationResolver.sort(resolvers);\n};\n\nexports.getJenkins = function() {\n    if (jenkinsCIGlobal) {\n        return jenkinsCIGlobal;\n    }\n    if (window.jenkinsCIGlobal) {\n        jenkinsCIGlobal = window.jenkinsCIGlobal;\n    } else {\n        exports.initJenkinsGlobal();\n        jenkinsCIGlobal.rootURL = getRootURL();\n        window.jenkinsCIGlobal = jenkinsCIGlobal;\n    }   \n    return jenkinsCIGlobal;\n};\n\nexports.getModuleNamespaceObj = function(moduleSpec) {\n    if (moduleSpec.namespace) {\n        return exports.getNamespace(moduleSpec.namespace);\n    } else {\n        return exports.getGlobalModules();\n    }\n};\n\nexports.getNamespace = function(namespaceName) {\n    var namespaces = exports.getNamespaces();\n    var namespace = namespaces[namespaceName];\n    if (!namespace) {\n        namespace = {\n            globalNS: false            \n        };\n        namespaces[namespaceName] = namespace;\n    }\n    return namespace;\n};\n\nexports.importModule = function(moduleQName, onRegisterTimeout) {\n    return promise.make(function (resolve, reject) {\n        var moduleSpec = new ModuleSpec(moduleQName);\n        var module = exports.getModule(moduleSpec);\n\n        if (module) {\n            // module already loaded\n            resolve(module.exports);\n        } else {\n            if (onRegisterTimeout === 0) {\n                if (moduleSpec.namespace) {\n                    throw new Error('Module ' + moduleSpec.namespace + ':' + moduleSpec.moduleName + ' require failure. Async load mode disabled.');\n                } else {\n                    throw new Error('Global module ' + moduleSpec.moduleName + ' require failure. Async load mode disabled.');\n                }\n            }\n\n            // module not loaded. Load async, fulfilling promise once registered\n            exports.loadModule(moduleSpec, onRegisterTimeout)\n                .onFulfilled(function (moduleExports) {\n                    resolve(moduleExports);\n                })\n                .onRejected(function (error) {\n                    reject(error);\n                });\n        }\n    });    \n};\n\nexports.loadModule = function(moduleSpec, onRegisterTimeout) {\n    var module = exports.getModule(moduleSpec);\n    \n    if (module) {\n        // Module already loaded. This prob shouldn't happen.\n        console.log(\"Unexpected call to 'loadModule' for a module (\" + moduleSpec.moduleName + \") that's already loaded.\");\n        return promise.make(function (resolve) {\n            resolve(module.exports);\n        });\n    }\n\n    function waitForRegistration(loadingModule, onRegisterTimeout) {\n        return promise.make(function (resolve, reject) {\n            if (typeof onRegisterTimeout !== \"number\") {\n                onRegisterTimeout = 10000;\n            }\n            \n            var timeoutObj = setTimeout(function () {\n                // Timed out waiting on the module to load and register itself.\n                if (!loadingModule.loaded) {\n                    var moduleSpec = loadingModule.moduleSpec;\n                    var errorDetail;\n                    \n                    if (moduleSpec.namespace) {\n                        errorDetail = \"Timed out waiting on module '\" + moduleSpec.namespace + \":\" + moduleSpec.moduleName + \"' to load.\";\n                    } else {\n                        errorDetail = \"Timed out waiting on module '\" + moduleSpec.moduleName + \"' to load.\";\n                    }                    \n                    console.error('Module load failure: ' + errorDetail);\n\n                    // Call the reject function and tell it we timed out\n                    reject({\n                        reason: 'timeout',\n                        detail: errorDetail\n                    });\n                }\n            }, onRegisterTimeout);\n            \n            loadingModule.waitList.push({\n                resolve: resolve,\n                timeoutObj: timeoutObj\n            });                    \n        });\n    }\n\n    var loadVersion = moduleSpec.getLoadBundleVersion();\n    var doScriptLoad = true;\n    \n    if (loadVersion) {\n        // If a version was specified then we only do the script load if a\n        // specific version was provided i.e. loading does not get triggered\n        // by imports that specify non-specific version numbers e.g. \"any\"\n        // or \"1.2.x\". A specific version number would be e.g. \"1.2.3\" i.e.\n        // fully qualified. When loading is not triggered, the import is depending\n        // on another import (with a specific version) or on another bundle to do an\n        // export of an internal dependency i.e. on another bundle \"providing\"\n        // the module by exporting it.\n        doScriptLoad = loadVersion.isSpecific();\n    }\n\n    var loadingModule = getLoadingModule(moduleSpec);\n    if (!loadingModule.waitList) {\n        loadingModule.waitList = [];\n    }\n    loadingModule.moduleSpec = moduleSpec; \n    loadingModule.loaded = false;\n\n    try {\n        return waitForRegistration(loadingModule, onRegisterTimeout);\n    } finally {\n        if (doScriptLoad && !loadingModule.loadedBy) {\n            // Capture the name of the bundle that triggered importing/loading\n            // of the bundle.\n            loadingModule.loadedBy = whoami;\n\n            var loadModuleName = moduleSpec.getLoadBundleName();\n            var scriptId = exports.toModuleId(moduleSpec.namespace, loadModuleName) + ':js';\n            var scriptSrc = exports.toModuleSrc(moduleSpec, 'js');\n            var scriptEl = exports.addScript(scriptSrc, {\n                scriptId: scriptId,\n                scriptSrcBase: ''\n            });\n\n            if (scriptEl) {\n                // Set the module spec info on the <script> element. This allows us to resolve the\n                // nsProvider for that bundle after 'whoami' is called for it (as it loads). whoami\n                // is not called with the nsProvider info on it because a given bundle can\n                // potentially be loaded from multiple different ns providers, so we only resole the provider\n                // at load-time i.e. just after a bundle is loaded it calls 'whoami' for itself\n                // and then this module magically works out where it was loaded from (it's nsProvider)\n                // by locating the <script> element and using this information. For a module/bundle, knowing\n                // where it was loaded from is important because it dictates where that module/bundle\n                // should load it dependencies from. For example, the Bootstrap module/bundle depends on the\n                // jQuery bundle. So, if the bootstrap bundle is loaded from the 'core-assets' namespace provider,\n                // then that means the jQuery bundle should also be loaded from the 'core-assets'\n                // namespace provider.\n                // See getBundleNSProviderFromScriptElement.\n                scriptEl.setAttribute('data-jenkins-module-nsProvider', moduleSpec.nsProvider);\n                scriptEl.setAttribute('data-jenkins-module-namespace', moduleSpec.namespace);\n                scriptEl.setAttribute('data-jenkins-module-moduleName', loadModuleName);\n            } else {\n                loadingModule.loadedBy = undefined;\n            }\n        }\n    }\n};\n\nexports.addScript = function(scriptSrc, options) {\n    if (!scriptSrc) {\n        console.warn('Call to addScript with undefined \"scriptSrc\" arg.');\n        return undefined;\n    }    \n    \n    var normalizedOptions;\n    \n    // If there's no options object, create it.\n    if (typeof options === 'object') {\n        normalizedOptions = options;\n    } else {\n        normalizedOptions = {};\n    }\n    \n    // May want to transform/map some urls.\n    if (normalizedOptions.scriptSrcMap) {\n        if (typeof normalizedOptions.scriptSrcMap === 'function') {\n            scriptSrc = normalizedOptions.scriptSrcMap(scriptSrc);\n        } else if (Array.isArray(normalizedOptions.scriptSrcMap)) {\n            // it's an array of suffix mappings\n            for (var i = 0; i < normalizedOptions.scriptSrcMap.length; i++) {\n                var mapping = normalizedOptions.scriptSrcMap[i];\n                if (mapping.from && mapping.to) {\n                    if (endsWith(scriptSrc, mapping.from)) {\n                        normalizedOptions.originalScriptSrc = scriptSrc;\n                        scriptSrc = scriptSrc.replace(mapping.from, mapping.to);\n                        break;\n                    }\n                }\n            }\n        }\n    }\n    \n    normalizedOptions.scriptId = getScriptId(scriptSrc, options);\n    \n    // set some default options\n    if (normalizedOptions.async === undefined) {\n        normalizedOptions.async = true;\n    }\n    if (normalizedOptions.scriptSrcBase === undefined) {\n        normalizedOptions.scriptSrcBase = '@root';\n    }\n    \n    if (normalizedOptions.scriptSrcBase === '@root') {\n        normalizedOptions.scriptSrcBase = getRootURL() + '/';\n    } else if (normalizedOptions.scriptSrcBase === '@adjunct') {\n        normalizedOptions.scriptSrcBase = getAdjunctURL() + '/';\n    }\n\n    var document = window.document;\n    var head = exports.getHeadElement();\n    var script = document.getElementById(normalizedOptions.scriptId);\n\n    if (script) {\n        var replaceable = script.getAttribute('data-replaceable');\n        if (replaceable && replaceable === 'true') {\n            // This <script> element is replaceable. In this case, \n            // we remove the existing script element and add a new one of the\n            // same id and with the specified src attribute.\n            // Adding happens below.\n            script.parentNode.removeChild(script);\n        } else {\n            return undefined;\n        }\n    }\n\n    script = createElement('script');\n\n    // Parts of the following onload code were inspired by how the ACE editor does it,\n    // as well as from the follow SO post: http://stackoverflow.com/a/4845802/1166986\n    var onload = function (_, isAborted) {\n        script.setAttribute('data-onload-complete', true);\n        try {\n            if (isAborted) {\n                console.warn('Script load aborted: ' + scriptSrc);\n            } else if (!script.readyState || script.readyState === \"loaded\" || script.readyState === \"complete\") {\n                // If the options contains an onload function, call it.\n                if (typeof normalizedOptions.success === 'function') {\n                    normalizedOptions.success(script);\n                }\n                return;\n            }\n            if (typeof normalizedOptions.error === 'function') {\n                normalizedOptions.error(script, isAborted);\n            }\n        } finally {\n            if (normalizedOptions.removeElementOnLoad) {\n                head.removeChild(script);\n            }\n            // Handle memory leak in IE\n            script = script.onload = script.onreadystatechange = null;\n        }\n    };\n    script.onload = onload; \n    script.onreadystatechange = onload;\n\n    script.setAttribute('id', normalizedOptions.scriptId);\n    script.setAttribute('type', 'text/javascript');\n    script.setAttribute('src', normalizedOptions.scriptSrcBase + scriptSrc);\n    if (normalizedOptions.originalScriptSrc) {\n        script.setAttribute('data-referrer', normalizedOptions.originalScriptSrc);        \n    }\n    if (normalizedOptions.async) {\n        script.setAttribute('async', normalizedOptions.async);\n    }\n    \n    head.appendChild(script);\n    \n    return script;\n};\n\nexports.notifyModuleExported = function(moduleSpec, moduleExports) {\n    var loadingModule = getLoadingModule(moduleSpec);\n    \n    loadingModule.loaded = true;\n    if (loadingModule.waitList) {\n        for (var i = 0; i < loadingModule.waitList.length; i++) {\n            var waiter = loadingModule.waitList[i];\n            clearTimeout(waiter.timeoutObj);\n            waiter.resolve(moduleExports);\n        }\n    }    \n};\n\nexports.addModuleCSSToPage = function(namespace, moduleName) {\n    var moduleSpec = exports.getModuleSpec(namespace + ':' + moduleName);\n    var cssElId = exports.toModuleId(namespace, moduleName) + ':css';\n    var cssPath = exports.toModuleSrc(moduleSpec, 'css');\n    return exports.addCSSToPage(namespace, cssPath, cssElId);\n};\n\nexports.addPluginCSSToPage = function(namespace, cssPath, cssElId) {\n    var cssPath = exports.getPluginPath(namespace) + '/' + cssPath;\n    return exports.addCSSToPage(namespace, cssPath, cssElId);\n};\n\nexports.toCSSId = function (cssPath, namespace) {\n    return 'jenkins-js-module:' + (namespace || 'global' ) + ':css:' + cssPath;\n};\n\nexports.addCSSToPage = function(namespace, cssPath, cssElId) {\n    var document = window.document;\n    \n    if (cssElId === undefined) {\n        cssElId = exports.toCSSId(cssPath, namespace);\n    }\n    \n    var cssEl = document.getElementById(cssElId);\n    \n    if (cssEl) {\n        // already added to page\n        return;\n    }\n\n    var docHead = exports.getHeadElement();\n    cssEl = createElement('link');\n    cssEl.setAttribute('id', cssElId);\n    cssEl.setAttribute('type', 'text/css');\n    cssEl.setAttribute('rel', 'stylesheet');\n    cssEl.setAttribute('href', cssPath);\n    docHead.appendChild(cssEl);\n\n    return cssEl;\n};\n\nexports.getGlobalModules = function() {\n    var jenkinsCIGlobal = exports.getJenkins();\n    if (!jenkinsCIGlobal.globals) {\n        jenkinsCIGlobal.globals = {\n            globalNS: true\n        };\n    }\n    return jenkinsCIGlobal.globals;\n};\n\nexports.getNamespaces = function() {\n    var jenkinsCIGlobal = exports.getJenkins();\n\n    // The namespaces are stored in an object named \"plugins\". This is a legacy from the\n    // time when all modules lived in plugins. By right we'd like to rename this, but\n    // that would cause compatibility issues.\n\n    if (!jenkinsCIGlobal.plugins) {\n        jenkinsCIGlobal.plugins = {\n            __README__: 'This object holds namespaced JS modules/bundles, with the property names representing the module namespace. It\\'s name (\"plugins\") is a legacy thing. Changing it to a better name (e.g. \"namespaces\") would cause compatibility issues.'\n        };\n    }\n    return jenkinsCIGlobal.plugins;\n};\n\nexports.toModuleId = function(namespace, moduleName) {\n    return 'jenkins-js-module:' + (namespace ? namespace + ':' : '') + moduleName;\n};\n\nexports.toModuleSrc = function(moduleSpec, srcType) {\n    var nsProvider = moduleSpec.nsProvider;\n\n    // If a moduleSpec on a module/bundle import doesn't specify a namespace provider\n    // (i.e. is of the form \"a:b\" and not \"core-assets/a:b\"),\n    // then check \"this\" bundles module spec and see if it was imported from a specific\n    // namespace. If it was (e.g. 'core-assets'), then import from that namespace.\n    if (nsProvider === undefined) {\n        nsProvider = thisBundleNamespaceProvider();\n        if (nsProvider === undefined) {\n            nsProvider = 'adjuncts';\n        }\n        // Store the nsProvider back onto the moduleSpec.\n        moduleSpec.nsProvider = nsProvider;\n    }\n\n    var srcPath = undefined;\n    if (srcType === 'js') {\n        srcPath = moduleSpec.getLoadBundleFileNamePrefix() + '.js';\n    } else if (srcType === 'css') {\n        srcPath = moduleSpec.getLoadBundleFileNamePrefix() + '/style.css';\n    } else {\n        throw new Error('Unsupported srcType \"'+ srcType + '\".');\n    }\n\n    // Maybe there's a custom resource resolver for this resource.\n    var resourceLocationResolverFunc = getResourceLocationResolverFunc(moduleSpec);\n    if (resourceLocationResolverFunc) {\n        var resourcePath = resourceLocationResolverFunc(moduleSpec, srcPath);\n        if (resourcePath) {\n            return resourcePath;\n        }\n    }\n\n    // Default resource resolution ...\n    if (nsProvider === 'adjuncts') {\n        return exports.getAdjunctJSModulesPath(moduleSpec.namespace) + '/' + srcPath;\n    } else if (nsProvider === 'plugin') {\n        return exports.getPluginJSModulesPath(moduleSpec.namespace) + '/' + srcPath;\n    } else if (nsProvider === 'core-assets') {\n        return exports.getCoreAssetsJSModulesPath(moduleSpec.namespace) + '/' + srcPath;\n    } else {\n        throw new Error('Unsupported namespace provider: ' + nsProvider);\n    }\n};\n\nexports.getAdjunctJSModulesPath = function(namespace) {\n    if (namespace) {\n        return getAdjunctURL() + '/org/jenkins/ui/jsmodules/' + namespace;\n    } else {\n        return getAdjunctURL() + '/org/jenkins/ui/jsmodules';\n    }\n};\n\nexports.getPluginJSModulesPath = function(pluginId) {\n    return exports.getPluginPath(pluginId) + '/jsmodules';\n};\n\nexports.getCoreAssetsJSModulesPath = function(namespace) {\n    return getRootURL() + '/assets/' + namespace + '/jsmodules';\n};\n\nexports.getPluginPath = function(pluginId) {\n    return getRootURL() + '/plugin/' + pluginId;\n};\n\nexports.getHeadElement = function() {\n    var docHead = window.document.getElementsByTagName(\"head\");\n    if (!docHead || docHead.length == 0) {\n        throw new Error('No head element found in document.');\n    }\n    return docHead[0];\n};\n\nexports.setRootURL = function(url) {    \n    if (!jenkinsCIGlobal) {\n        exports.initJenkinsGlobal();\n    }\n    jenkinsCIGlobal.rootURL = url;\n};\n\nexports.getModule = function(moduleSpec) {\n    var namespace = exports.getModuleNamespaceObj(moduleSpec);\n    \n    if (!moduleSpec.moduleVersion) {\n        return namespace[moduleSpec.moduleName];\n    } else {\n        for (var i = 0; i < moduleSpec.moduleCompatVersions.length; i++) {\n            var moduleCompatVersion = moduleSpec.moduleCompatVersions[i];\n            var module = namespace[moduleSpec.moduleName + '@' + moduleCompatVersion.raw];\n            if (module) {\n                return module;\n            }\n        }\n    }\n    \n    return undefined;\n};\n\nexports.getModuleSpec = function(moduleQName) {\n    var moduleSpec = new ModuleSpec(moduleQName);\n    var moduleNamespaceObj = exports.getModuleNamespaceObj(moduleSpec);\n    if (moduleNamespaceObj) {\n        var loading = getLoadingModule(moduleSpec);\n        if (loading && loading.moduleSpec) {\n            return loading.moduleSpec;\n        }\n    }\n    return moduleSpec;\n};\n\nfunction getResourceLocationResolvers() {\n    var jenkinsCIGlobal = exports.getJenkins();\n    if (!jenkinsCIGlobal.resourceLocationResolvers) {\n        jenkinsCIGlobal.resourceLocationResolvers = [];\n    }\n    return jenkinsCIGlobal.resourceLocationResolvers;\n}\n\nfunction getResourceLocationResolverFunc(moduleSpec) {\n    var resolvers = getResourceLocationResolvers();\n\n    for (var i = 0; i < resolvers.length; i++) {\n        var resolver = resolvers[i];\n        if (resolver && resolver.canResolve(moduleSpec)) {\n            return resolver.resolverFunc;\n        }\n    }\n\n    // Failed to find a specific resolver for the supplied moduleSpec.\n    // In this case, lets try the resolver used to load the bundle\n    // that's currently loading this resource. Iow, resources should\n    // be loaded from the same location as the bundle that's triggering\n    // the loading of that resource. Obviously this is recursive up\n    // through the \"parents\".\n    var loadingModule = getLoadingModule(moduleSpec);\n    if (loadingModule.loadedBy) {\n        return getResourceLocationResolverFunc(loadingModule.loadedBy);\n    }\n\n    return undefined;\n}\nexports.getResourceLocationResolverFunc = getResourceLocationResolverFunc;\n\nfunction getScriptId(scriptSrc, config) {\n    if (typeof config === 'string') {\n        return config;\n    } else if (typeof config === 'object' && config.scriptId) {\n        return config.scriptId;\n    } else {\n        return 'jenkins-script:' + scriptSrc;\n    }    \n}\n\nexports.getRootURL = getRootURL;\nfunction getRootURL() {\n    if (jenkinsCIGlobal && jenkinsCIGlobal.rootURL) {\n        return jenkinsCIGlobal.rootURL;\n    }\n    \n    var docHead = exports.getHeadElement();\n    var rootURL = getAttribute(docHead, \"data-rooturl\");\n\n    if (rootURL === undefined || rootURL === null) {\n        // Backward compatibility - used to use a 'resurl' attribute.\n        rootURL = getAttribute(docHead, \"resurl\");\n        if (rootURL === undefined || rootURL === null) {\n            throw new Error(\"Attribute 'data-rooturl' not defined on the document <head> element.\");\n        }\n    }\n\n    if (jenkinsCIGlobal) {\n        jenkinsCIGlobal.rootURL = rootURL;\n    }\n    \n    return rootURL;\n}\n\nexports.getAdjunctURL = getAdjunctURL;\nfunction getAdjunctURL() {\n    if (jenkinsCIGlobal && jenkinsCIGlobal.adjunctURL) {\n        return jenkinsCIGlobal.adjunctURL;\n    }\n    \n    var docHead = exports.getHeadElement();\n    var adjunctURL = getAttribute(docHead, \"data-adjuncturl\");\n\n    if (adjunctURL === undefined || adjunctURL === null) {\n        // Backward compatibility - older Jenkins do not have the adjunct url on the\n        // <head> element. Lets try getting the resurl (older jenkins) and patching it \n        // to be an adjunct url.\n        adjunctURL = getAttribute(docHead, \"resurl\");\n        if (adjunctURL === undefined || adjunctURL === null) {\n            throw new Error(\"Attribute 'data-adjuncturl' not defined on the document <head> element.\");\n        }\n        // Replace the first occurrence of 'static/' with 'adjuncts/' \n        adjunctURL = adjunctURL.replace('static\\/', 'adjuncts\\/');\n    }\n\n    if (jenkinsCIGlobal) {\n        jenkinsCIGlobal.adjunctURL = adjunctURL;\n    }\n    \n    return adjunctURL;\n}\n\nfunction createElement(name) {\n    var document = window.document;\n    return document.createElement(name);\n}\n\nfunction getAttribute(element, attributeName) {\n    var value = element.getAttribute(attributeName.toLowerCase());\n    \n    if (value) {\n        return value;\n    } else {\n        // try without lowercasing\n        return element.getAttribute(attributeName);\n    }    \n}\n\nfunction getLoadingModule(moduleSpec) {\n    var moduleNamespaceObj = exports.getModuleNamespaceObj(moduleSpec);\n    var moduleName = moduleSpec.getLoadBundleName();\n\n    if (!moduleNamespaceObj.loadingModules) {\n        moduleNamespaceObj.loadingModules = {};\n    }\n    if (!moduleNamespaceObj.loadingModules[moduleName]) {\n        moduleNamespaceObj.loadingModules[moduleName] = {};\n    }\n    return moduleNamespaceObj.loadingModules[moduleName];\n}\n\nfunction endsWith(string, suffix) {\n    return (string.indexOf(suffix, string.length - suffix.length) !== -1);\n}\n\nfunction thisBundleNamespaceProvider() {\n    if (whoami !== undefined) {\n        return whoami.nsProvider;\n    }\n    return undefined;\n}\n\nfunction getBundleNSProviderFromScriptElement(namespace, moduleName) {\n    var docHead = exports.getHeadElement();\n    var scripts = docHead.getElementsByTagName(\"script\");\n\n    for (var i = 0; i < scripts.length; i++) {\n        var script = scripts[i];\n        var elNamespace = script.getAttribute('data-jenkins-module-namespace');\n        var elModuleName = script.getAttribute('data-jenkins-module-moduleName');\n\n        if (elNamespace === namespace && elModuleName === moduleName) {\n            return script.getAttribute('data-jenkins-module-nsProvider');\n        }\n    }\n\n    return undefined;\n}","deps":{"./ModuleSpec":"node_modules/@jenkins-cd/js-modules/js/ModuleSpec.js","./ResourceLocationResolver":"node_modules/@jenkins-cd/js-modules/js/ResourceLocationResolver.js","./promise":"node_modules/@jenkins-cd/js-modules/js/promise.js"}},{"id":"node_modules/@jenkins-cd/js-modules/js/promise.js","source":"exports.make = function(executor) {\n    var thePromise = new APromise();\n    executor.call(thePromise, function(result) {\n        thePromise.resolve(result);\n    }, function(reason) {\n        thePromise.reject(reason);\n    });\n    return thePromise;\n};\n\nfunction APromise() {\n    this.state = 'PENDING';\n    this.whenFulfilled = undefined;\n    this.whenRejected = undefined;\n    this.applyFulfillArgs = false;\n}\n\nAPromise.prototype.applyArgsOnFulfill = function() {\n    this.applyFulfillArgs = true;\n    return this;\n}\n\nAPromise.prototype.resolve = function (result) {\n    this.state = 'FULFILLED';\n    \n    var thePromise = this;\n    function doFulfill(whenFulfilled, result) {\n        if (thePromise.applyFulfillArgs) {\n            whenFulfilled.apply(whenFulfilled, result);\n        } else {\n            whenFulfilled(result);\n        }\n    }\n    \n    if (this.whenFulfilled) {\n        doFulfill(this.whenFulfilled, result);\n    }\n    // redefine \"onFulfilled\" to call immediately\n    this.onFulfilled = function (whenFulfilled) {\n        if (whenFulfilled) {\n            doFulfill(whenFulfilled, result);\n        }\n        return this;\n    }\n};\n\nAPromise.prototype.reject = function (reason) {\n    this.state = 'REJECTED';\n    if (this.whenRejected) {\n        this.whenRejected(reason);\n    }\n    // redefine \"onRejected\" to call immediately\n    this.onRejected = function(whenRejected) {\n        if (whenRejected) {\n            whenRejected(reason);\n        }\n        return this;\n    }\n};\n\nAPromise.prototype.onFulfilled = function(whenFulfilled) {\n    if (!whenFulfilled) {\n        throw new Error('Must provide an \"whenFulfilled\" callback.');\n    }\n    this.whenFulfilled = whenFulfilled;\n    return this;\n};\n\nAPromise.prototype.onRejected = function(whenRejected) {        \n    if (whenRejected) {\n        this.whenRejected = whenRejected;\n    }\n    return this;\n};","deps":{}},{"id":"node_modules/deep-equal/index.js","source":"var pSlice = Array.prototype.slice;\nvar objectKeys = require('./lib/keys.js');\nvar isArguments = require('./lib/is_arguments.js');\n\nvar deepEqual = module.exports = function (actual, expected, opts) {\n  if (!opts) opts = {};\n  // 7.1. All identical values are equivalent, as determined by ===.\n  if (actual === expected) {\n    return true;\n\n  } else if (actual instanceof Date && expected instanceof Date) {\n    return actual.getTime() === expected.getTime();\n\n  // 7.3. Other pairs that do not both pass typeof value == 'object',\n  // equivalence is determined by ==.\n  } else if (!actual || !expected || typeof actual != 'object' && typeof expected != 'object') {\n    return opts.strict ? actual === expected : actual == expected;\n\n  // 7.4. For all other Object pairs, including Array objects, equivalence is\n  // determined by having the same number of owned properties (as verified\n  // with Object.prototype.hasOwnProperty.call), the same set of keys\n  // (although not necessarily the same order), equivalent values for every\n  // corresponding key, and an identical 'prototype' property. Note: this\n  // accounts for both named and indexed properties on Arrays.\n  } else {\n    return objEquiv(actual, expected, opts);\n  }\n}\n\nfunction isUndefinedOrNull(value) {\n  return value === null || value === undefined;\n}\n\nfunction isBuffer (x) {\n  if (!x || typeof x !== 'object' || typeof x.length !== 'number') return false;\n  if (typeof x.copy !== 'function' || typeof x.slice !== 'function') {\n    return false;\n  }\n  if (x.length > 0 && typeof x[0] !== 'number') return false;\n  return true;\n}\n\nfunction objEquiv(a, b, opts) {\n  var i, key;\n  if (isUndefinedOrNull(a) || isUndefinedOrNull(b))\n    return false;\n  // an identical 'prototype' property.\n  if (a.prototype !== b.prototype) return false;\n  //~~~I've managed to break Object.keys through screwy arguments passing.\n  //   Converting to array solves the problem.\n  if (isArguments(a)) {\n    if (!isArguments(b)) {\n      return false;\n    }\n    a = pSlice.call(a);\n    b = pSlice.call(b);\n    return deepEqual(a, b, opts);\n  }\n  if (isBuffer(a)) {\n    if (!isBuffer(b)) {\n      return false;\n    }\n    if (a.length !== b.length) return false;\n    for (i = 0; i < a.length; i++) {\n      if (a[i] !== b[i]) return false;\n    }\n    return true;\n  }\n  try {\n    var ka = objectKeys(a),\n        kb = objectKeys(b);\n  } catch (e) {//happens when one is a string literal and the other isn't\n    return false;\n  }\n  // having the same number of owned properties (keys incorporates\n  // hasOwnProperty)\n  if (ka.length != kb.length)\n    return false;\n  //the same set of keys (although not necessarily the same order),\n  ka.sort();\n  kb.sort();\n  //~~~cheap key test\n  for (i = ka.length - 1; i >= 0; i--) {\n    if (ka[i] != kb[i])\n      return false;\n  }\n  //equivalent values for every corresponding key, and\n  //~~~possibly expensive deep test\n  for (i = ka.length - 1; i >= 0; i--) {\n    key = ka[i];\n    if (!deepEqual(a[key], b[key], opts)) return false;\n  }\n  return typeof a === typeof b;\n}","deps":{"./lib/is_arguments.js":"node_modules/deep-equal/lib/is_arguments.js","./lib/keys.js":"node_modules/deep-equal/lib/keys.js"}},{"id":"node_modules/deep-equal/lib/is_arguments.js","source":"var supportsArgumentsClass = (function(){\n  return Object.prototype.toString.call(arguments)\n})() == '[object Arguments]';\n\nexports = module.exports = supportsArgumentsClass ? supported : unsupported;\n\nexports.supported = supported;\nfunction supported(object) {\n  return Object.prototype.toString.call(object) == '[object Arguments]';\n};\n\nexports.unsupported = unsupported;\nfunction unsupported(object){\n  return object &&\n    typeof object == 'object' &&\n    typeof object.length == 'number' &&\n    Object.prototype.hasOwnProperty.call(object, 'callee') &&\n    !Object.prototype.propertyIsEnumerable.call(object, 'callee') ||\n    false;\n};","deps":{}},{"id":"node_modules/deep-equal/lib/keys.js","source":"exports = module.exports = typeof Object.keys === 'function'\n  ? Object.keys : shim;\n\nexports.shim = shim;\nfunction shim (obj) {\n  var keys = [];\n  for (var key in obj) keys.push(key);\n  return keys;\n}","deps":{}},{"id":"node_modules/history/lib/Actions.js","source":"'use strict';\n\nexports.__esModule = true;\nvar PUSH = 'PUSH';\n\nexports.PUSH = PUSH;\n/**\n * Indicates that navigation was caused by a call to history.replace.\n */\nvar REPLACE = 'REPLACE';\n\nexports.REPLACE = REPLACE;\n/**\n * Indicates that navigation was caused by some other action such\n * as using a browser's back/forward buttons and/or manually manipulating\n * the URL in a browser's location bar. This is the default.\n *\n * See https://developer.mozilla.org/en-US/docs/Web/API/WindowEventHandlers/onpopstate\n * for more information.\n */\nvar POP = 'POP';\n\nexports.POP = POP;\nexports['default'] = {\n  PUSH: PUSH,\n  REPLACE: REPLACE,\n  POP: POP\n};","deps":{}},{"id":"node_modules/history/lib/AsyncUtils.js","source":"\"use strict\";\n\nexports.__esModule = true;\nvar _slice = Array.prototype.slice;\nexports.loopAsync = loopAsync;\n\nfunction loopAsync(turns, work, callback) {\n  var currentTurn = 0,\n      isDone = false;\n  var sync = false,\n      hasNext = false,\n      doneArgs = undefined;\n\n  function done() {\n    isDone = true;\n    if (sync) {\n      // Iterate instead of recursing if possible.\n      doneArgs = [].concat(_slice.call(arguments));\n      return;\n    }\n\n    callback.apply(this, arguments);\n  }\n\n  function next() {\n    if (isDone) {\n      return;\n    }\n\n    hasNext = true;\n    if (sync) {\n      // Iterate instead of recursing if possible.\n      return;\n    }\n\n    sync = true;\n\n    while (!isDone && currentTurn < turns && hasNext) {\n      hasNext = false;\n      work.call(this, currentTurn++, next, done);\n    }\n\n    sync = false;\n\n    if (isDone) {\n      // This means the loop finished synchronously.\n      callback.apply(this, doneArgs);\n      return;\n    }\n\n    if (currentTurn >= turns && hasNext) {\n      isDone = true;\n      callback();\n    }\n  }\n\n  next();\n}","deps":{}},{"id":"node_modules/history/lib/DOMStateStorage.js","source":"(function (process){\n/*eslint-disable no-empty */\n'use strict';\n\nexports.__esModule = true;\nexports.saveState = saveState;\nexports.readState = readState;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _warning = require('warning');\n\nvar _warning2 = _interopRequireDefault(_warning);\n\nvar KeyPrefix = '@@History/';\nvar QuotaExceededErrors = ['QuotaExceededError', 'QUOTA_EXCEEDED_ERR'];\n\nvar SecurityError = 'SecurityError';\n\nfunction createKey(key) {\n  return KeyPrefix + key;\n}\n\nfunction saveState(key, state) {\n  try {\n    if (state == null) {\n      window.sessionStorage.removeItem(createKey(key));\n    } else {\n      window.sessionStorage.setItem(createKey(key), JSON.stringify(state));\n    }\n  } catch (error) {\n    if (error.name === SecurityError) {\n      // Blocking cookies in Chrome/Firefox/Safari throws SecurityError on any\n      // attempt to access window.sessionStorage.\n      process.env.NODE_ENV !== 'production' ? _warning2['default'](false, '[history] Unable to save state; sessionStorage is not available due to security settings') : undefined;\n\n      return;\n    }\n\n    if (QuotaExceededErrors.indexOf(error.name) >= 0 && window.sessionStorage.length === 0) {\n      // Safari \"private mode\" throws QuotaExceededError.\n      process.env.NODE_ENV !== 'production' ? _warning2['default'](false, '[history] Unable to save state; sessionStorage is not available in Safari private mode') : undefined;\n\n      return;\n    }\n\n    throw error;\n  }\n}\n\nfunction readState(key) {\n  var json = undefined;\n  try {\n    json = window.sessionStorage.getItem(createKey(key));\n  } catch (error) {\n    if (error.name === SecurityError) {\n      // Blocking cookies in Chrome/Firefox/Safari throws SecurityError on any\n      // attempt to access window.sessionStorage.\n      process.env.NODE_ENV !== 'production' ? _warning2['default'](false, '[history] Unable to read state; sessionStorage is not available due to security settings') : undefined;\n\n      return null;\n    }\n  }\n\n  if (json) {\n    try {\n      return JSON.parse(json);\n    } catch (error) {\n      // Ignore invalid JSON.\n    }\n  }\n\n  return null;\n}\n}).call(this,require('_process'))","deps":{"_process":"node_modules/process/browser.js","warning":"node_modules/warning/browser.js"}},{"id":"node_modules/history/lib/DOMUtils.js","source":"'use strict';\n\nexports.__esModule = true;\nexports.addEventListener = addEventListener;\nexports.removeEventListener = removeEventListener;\nexports.getHashPath = getHashPath;\nexports.replaceHashPath = replaceHashPath;\nexports.getWindowPath = getWindowPath;\nexports.go = go;\nexports.getUserConfirmation = getUserConfirmation;\nexports.supportsHistory = supportsHistory;\nexports.supportsGoWithoutReloadUsingHash = supportsGoWithoutReloadUsingHash;\n\nfunction addEventListener(node, event, listener) {\n  if (node.addEventListener) {\n    node.addEventListener(event, listener, false);\n  } else {\n    node.attachEvent('on' + event, listener);\n  }\n}\n\nfunction removeEventListener(node, event, listener) {\n  if (node.removeEventListener) {\n    node.removeEventListener(event, listener, false);\n  } else {\n    node.detachEvent('on' + event, listener);\n  }\n}\n\nfunction getHashPath() {\n  // We can't use window.location.hash here because it's not\n  // consistent across browsers - Firefox will pre-decode it!\n  return window.location.href.split('#')[1] || '';\n}\n\nfunction replaceHashPath(path) {\n  window.location.replace(window.location.pathname + window.location.search + '#' + path);\n}\n\nfunction getWindowPath() {\n  return window.location.pathname + window.location.search + window.location.hash;\n}\n\nfunction go(n) {\n  if (n) window.history.go(n);\n}\n\nfunction getUserConfirmation(message, callback) {\n  callback(window.confirm(message));\n}\n\n/**\n * Returns true if the HTML5 history API is supported. Taken from Modernizr.\n *\n * https://github.com/Modernizr/Modernizr/blob/master/LICENSE\n * https://github.com/Modernizr/Modernizr/blob/master/feature-detects/history.js\n * changed to avoid false negatives for Windows Phones: https://github.com/rackt/react-router/issues/586\n */\n\nfunction supportsHistory() {\n  var ua = navigator.userAgent;\n  if ((ua.indexOf('Android 2.') !== -1 || ua.indexOf('Android 4.0') !== -1) && ua.indexOf('Mobile Safari') !== -1 && ua.indexOf('Chrome') === -1 && ua.indexOf('Windows Phone') === -1) {\n    return false;\n  }\n  return window.history && 'pushState' in window.history;\n}\n\n/**\n * Returns false if using go(n) with hash history causes a full page reload.\n */\n\nfunction supportsGoWithoutReloadUsingHash() {\n  var ua = navigator.userAgent;\n  return ua.indexOf('Firefox') === -1;\n}","deps":{}},{"id":"node_modules/history/lib/ExecutionEnvironment.js","source":"'use strict';\n\nexports.__esModule = true;\nvar canUseDOM = !!(typeof window !== 'undefined' && window.document && window.document.createElement);\nexports.canUseDOM = canUseDOM;","deps":{}},{"id":"node_modules/history/lib/PathUtils.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\nexports.extractPath = extractPath;\nexports.parsePath = parsePath;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _warning = require('warning');\n\nvar _warning2 = _interopRequireDefault(_warning);\n\nfunction extractPath(string) {\n  var match = string.match(/^https?:\\/\\/[^\\/]*/);\n\n  if (match == null) return string;\n\n  return string.substring(match[0].length);\n}\n\nfunction parsePath(path) {\n  var pathname = extractPath(path);\n  var search = '';\n  var hash = '';\n\n  process.env.NODE_ENV !== 'production' ? _warning2['default'](path === pathname, 'A path must be pathname + search + hash only, not a fully qualified URL like \"%s\"', path) : undefined;\n\n  var hashIndex = pathname.indexOf('#');\n  if (hashIndex !== -1) {\n    hash = pathname.substring(hashIndex);\n    pathname = pathname.substring(0, hashIndex);\n  }\n\n  var searchIndex = pathname.indexOf('?');\n  if (searchIndex !== -1) {\n    search = pathname.substring(searchIndex);\n    pathname = pathname.substring(0, searchIndex);\n  }\n\n  if (pathname === '') pathname = '/';\n\n  return {\n    pathname: pathname,\n    search: search,\n    hash: hash\n  };\n}\n}).call(this,require('_process'))","deps":{"_process":"node_modules/process/browser.js","warning":"node_modules/warning/browser.js"}},{"id":"node_modules/history/lib/createBrowserHistory.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _invariant = require('invariant');\n\nvar _invariant2 = _interopRequireDefault(_invariant);\n\nvar _Actions = require('./Actions');\n\nvar _PathUtils = require('./PathUtils');\n\nvar _ExecutionEnvironment = require('./ExecutionEnvironment');\n\nvar _DOMUtils = require('./DOMUtils');\n\nvar _DOMStateStorage = require('./DOMStateStorage');\n\nvar _createDOMHistory = require('./createDOMHistory');\n\nvar _createDOMHistory2 = _interopRequireDefault(_createDOMHistory);\n\n/**\n * Creates and returns a history object that uses HTML5's history API\n * (pushState, replaceState, and the popstate event) to manage history.\n * This is the recommended method of managing history in browsers because\n * it provides the cleanest URLs.\n *\n * Note: In browsers that do not support the HTML5 history API full\n * page reloads will be used to preserve URLs.\n */\nfunction createBrowserHistory() {\n  var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];\n\n  !_ExecutionEnvironment.canUseDOM ? process.env.NODE_ENV !== 'production' ? _invariant2['default'](false, 'Browser history needs a DOM') : _invariant2['default'](false) : undefined;\n\n  var forceRefresh = options.forceRefresh;\n\n  var isSupported = _DOMUtils.supportsHistory();\n  var useRefresh = !isSupported || forceRefresh;\n\n  function getCurrentLocation(historyState) {\n    try {\n      historyState = historyState || window.history.state || {};\n    } catch (e) {\n      historyState = {};\n    }\n\n    var path = _DOMUtils.getWindowPath();\n    var _historyState = historyState;\n    var key = _historyState.key;\n\n    var state = undefined;\n    if (key) {\n      state = _DOMStateStorage.readState(key);\n    } else {\n      state = null;\n      key = history.createKey();\n\n      if (isSupported) window.history.replaceState(_extends({}, historyState, { key: key }), null);\n    }\n\n    var location = _PathUtils.parsePath(path);\n\n    return history.createLocation(_extends({}, location, { state: state }), undefined, key);\n  }\n\n  function startPopStateListener(_ref) {\n    var transitionTo = _ref.transitionTo;\n\n    function popStateListener(event) {\n      if (event.state === undefined) return; // Ignore extraneous popstate events in WebKit.\n\n      transitionTo(getCurrentLocation(event.state));\n    }\n\n    _DOMUtils.addEventListener(window, 'popstate', popStateListener);\n\n    return function () {\n      _DOMUtils.removeEventListener(window, 'popstate', popStateListener);\n    };\n  }\n\n  function finishTransition(location) {\n    var basename = location.basename;\n    var pathname = location.pathname;\n    var search = location.search;\n    var hash = location.hash;\n    var state = location.state;\n    var action = location.action;\n    var key = location.key;\n\n    if (action === _Actions.POP) return; // Nothing to do.\n\n    _DOMStateStorage.saveState(key, state);\n\n    var path = (basename || '') + pathname + search + hash;\n    var historyState = {\n      key: key\n    };\n\n    if (action === _Actions.PUSH) {\n      if (useRefresh) {\n        window.location.href = path;\n        return false; // Prevent location update.\n      } else {\n          window.history.pushState(historyState, null, path);\n        }\n    } else {\n      // REPLACE\n      if (useRefresh) {\n        window.location.replace(path);\n        return false; // Prevent location update.\n      } else {\n          window.history.replaceState(historyState, null, path);\n        }\n    }\n  }\n\n  var history = _createDOMHistory2['default'](_extends({}, options, {\n    getCurrentLocation: getCurrentLocation,\n    finishTransition: finishTransition,\n    saveState: _DOMStateStorage.saveState\n  }));\n\n  var listenerCount = 0,\n      stopPopStateListener = undefined;\n\n  function listenBefore(listener) {\n    if (++listenerCount === 1) stopPopStateListener = startPopStateListener(history);\n\n    var unlisten = history.listenBefore(listener);\n\n    return function () {\n      unlisten();\n\n      if (--listenerCount === 0) stopPopStateListener();\n    };\n  }\n\n  function listen(listener) {\n    if (++listenerCount === 1) stopPopStateListener = startPopStateListener(history);\n\n    var unlisten = history.listen(listener);\n\n    return function () {\n      unlisten();\n\n      if (--listenerCount === 0) stopPopStateListener();\n    };\n  }\n\n  // deprecated\n  function registerTransitionHook(hook) {\n    if (++listenerCount === 1) stopPopStateListener = startPopStateListener(history);\n\n    history.registerTransitionHook(hook);\n  }\n\n  // deprecated\n  function unregisterTransitionHook(hook) {\n    history.unregisterTransitionHook(hook);\n\n    if (--listenerCount === 0) stopPopStateListener();\n  }\n\n  return _extends({}, history, {\n    listenBefore: listenBefore,\n    listen: listen,\n    registerTransitionHook: registerTransitionHook,\n    unregisterTransitionHook: unregisterTransitionHook\n  });\n}\n\nexports['default'] = createBrowserHistory;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./Actions":"node_modules/history/lib/Actions.js","./DOMStateStorage":"node_modules/history/lib/DOMStateStorage.js","./DOMUtils":"node_modules/history/lib/DOMUtils.js","./ExecutionEnvironment":"node_modules/history/lib/ExecutionEnvironment.js","./PathUtils":"node_modules/history/lib/PathUtils.js","./createDOMHistory":"node_modules/history/lib/createDOMHistory.js","_process":"node_modules/process/browser.js","invariant":"node_modules/invariant/browser.js"}},{"id":"node_modules/history/lib/createDOMHistory.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _invariant = require('invariant');\n\nvar _invariant2 = _interopRequireDefault(_invariant);\n\nvar _ExecutionEnvironment = require('./ExecutionEnvironment');\n\nvar _DOMUtils = require('./DOMUtils');\n\nvar _createHistory = require('./createHistory');\n\nvar _createHistory2 = _interopRequireDefault(_createHistory);\n\nfunction createDOMHistory(options) {\n  var history = _createHistory2['default'](_extends({\n    getUserConfirmation: _DOMUtils.getUserConfirmation\n  }, options, {\n    go: _DOMUtils.go\n  }));\n\n  function listen(listener) {\n    !_ExecutionEnvironment.canUseDOM ? process.env.NODE_ENV !== 'production' ? _invariant2['default'](false, 'DOM history needs a DOM') : _invariant2['default'](false) : undefined;\n\n    return history.listen(listener);\n  }\n\n  return _extends({}, history, {\n    listen: listen\n  });\n}\n\nexports['default'] = createDOMHistory;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./DOMUtils":"node_modules/history/lib/DOMUtils.js","./ExecutionEnvironment":"node_modules/history/lib/ExecutionEnvironment.js","./createHistory":"node_modules/history/lib/createHistory.js","_process":"node_modules/process/browser.js","invariant":"node_modules/invariant/browser.js"}},{"id":"node_modules/history/lib/createHashHistory.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _warning = require('warning');\n\nvar _warning2 = _interopRequireDefault(_warning);\n\nvar _invariant = require('invariant');\n\nvar _invariant2 = _interopRequireDefault(_invariant);\n\nvar _Actions = require('./Actions');\n\nvar _PathUtils = require('./PathUtils');\n\nvar _ExecutionEnvironment = require('./ExecutionEnvironment');\n\nvar _DOMUtils = require('./DOMUtils');\n\nvar _DOMStateStorage = require('./DOMStateStorage');\n\nvar _createDOMHistory = require('./createDOMHistory');\n\nvar _createDOMHistory2 = _interopRequireDefault(_createDOMHistory);\n\nfunction isAbsolutePath(path) {\n  return typeof path === 'string' && path.charAt(0) === '/';\n}\n\nfunction ensureSlash() {\n  var path = _DOMUtils.getHashPath();\n\n  if (isAbsolutePath(path)) return true;\n\n  _DOMUtils.replaceHashPath('/' + path);\n\n  return false;\n}\n\nfunction addQueryStringValueToPath(path, key, value) {\n  return path + (path.indexOf('?') === -1 ? '?' : '&') + (key + '=' + value);\n}\n\nfunction stripQueryStringValueFromPath(path, key) {\n  return path.replace(new RegExp('[?&]?' + key + '=[a-zA-Z0-9]+'), '');\n}\n\nfunction getQueryStringValueFromPath(path, key) {\n  var match = path.match(new RegExp('\\\\?.*?\\\\b' + key + '=(.+?)\\\\b'));\n  return match && match[1];\n}\n\nvar DefaultQueryKey = '_k';\n\nfunction createHashHistory() {\n  var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];\n\n  !_ExecutionEnvironment.canUseDOM ? process.env.NODE_ENV !== 'production' ? _invariant2['default'](false, 'Hash history needs a DOM') : _invariant2['default'](false) : undefined;\n\n  var queryKey = options.queryKey;\n\n  if (queryKey === undefined || !!queryKey) queryKey = typeof queryKey === 'string' ? queryKey : DefaultQueryKey;\n\n  function getCurrentLocation() {\n    var path = _DOMUtils.getHashPath();\n\n    var key = undefined,\n        state = undefined;\n    if (queryKey) {\n      key = getQueryStringValueFromPath(path, queryKey);\n      path = stripQueryStringValueFromPath(path, queryKey);\n\n      if (key) {\n        state = _DOMStateStorage.readState(key);\n      } else {\n        state = null;\n        key = history.createKey();\n        _DOMUtils.replaceHashPath(addQueryStringValueToPath(path, queryKey, key));\n      }\n    } else {\n      key = state = null;\n    }\n\n    var location = _PathUtils.parsePath(path);\n\n    return history.createLocation(_extends({}, location, { state: state }), undefined, key);\n  }\n\n  function startHashChangeListener(_ref) {\n    var transitionTo = _ref.transitionTo;\n\n    function hashChangeListener() {\n      if (!ensureSlash()) return; // Always make sure hashes are preceeded with a /.\n\n      transitionTo(getCurrentLocation());\n    }\n\n    ensureSlash();\n    _DOMUtils.addEventListener(window, 'hashchange', hashChangeListener);\n\n    return function () {\n      _DOMUtils.removeEventListener(window, 'hashchange', hashChangeListener);\n    };\n  }\n\n  function finishTransition(location) {\n    var basename = location.basename;\n    var pathname = location.pathname;\n    var search = location.search;\n    var state = location.state;\n    var action = location.action;\n    var key = location.key;\n\n    if (action === _Actions.POP) return; // Nothing to do.\n\n    var path = (basename || '') + pathname + search;\n\n    if (queryKey) {\n      path = addQueryStringValueToPath(path, queryKey, key);\n      _DOMStateStorage.saveState(key, state);\n    } else {\n      // Drop key and state.\n      location.key = location.state = null;\n    }\n\n    var currentHash = _DOMUtils.getHashPath();\n\n    if (action === _Actions.PUSH) {\n      if (currentHash !== path) {\n        window.location.hash = path;\n      } else {\n        process.env.NODE_ENV !== 'production' ? _warning2['default'](false, 'You cannot PUSH the same path using hash history') : undefined;\n      }\n    } else if (currentHash !== path) {\n      // REPLACE\n      _DOMUtils.replaceHashPath(path);\n    }\n  }\n\n  var history = _createDOMHistory2['default'](_extends({}, options, {\n    getCurrentLocation: getCurrentLocation,\n    finishTransition: finishTransition,\n    saveState: _DOMStateStorage.saveState\n  }));\n\n  var listenerCount = 0,\n      stopHashChangeListener = undefined;\n\n  function listenBefore(listener) {\n    if (++listenerCount === 1) stopHashChangeListener = startHashChangeListener(history);\n\n    var unlisten = history.listenBefore(listener);\n\n    return function () {\n      unlisten();\n\n      if (--listenerCount === 0) stopHashChangeListener();\n    };\n  }\n\n  function listen(listener) {\n    if (++listenerCount === 1) stopHashChangeListener = startHashChangeListener(history);\n\n    var unlisten = history.listen(listener);\n\n    return function () {\n      unlisten();\n\n      if (--listenerCount === 0) stopHashChangeListener();\n    };\n  }\n\n  function push(location) {\n    process.env.NODE_ENV !== 'production' ? _warning2['default'](queryKey || location.state == null, 'You cannot use state without a queryKey it will be dropped') : undefined;\n\n    history.push(location);\n  }\n\n  function replace(location) {\n    process.env.NODE_ENV !== 'production' ? _warning2['default'](queryKey || location.state == null, 'You cannot use state without a queryKey it will be dropped') : undefined;\n\n    history.replace(location);\n  }\n\n  var goIsSupportedWithoutReload = _DOMUtils.supportsGoWithoutReloadUsingHash();\n\n  function go(n) {\n    process.env.NODE_ENV !== 'production' ? _warning2['default'](goIsSupportedWithoutReload, 'Hash history go(n) causes a full page reload in this browser') : undefined;\n\n    history.go(n);\n  }\n\n  function createHref(path) {\n    return '#' + history.createHref(path);\n  }\n\n  // deprecated\n  function registerTransitionHook(hook) {\n    if (++listenerCount === 1) stopHashChangeListener = startHashChangeListener(history);\n\n    history.registerTransitionHook(hook);\n  }\n\n  // deprecated\n  function unregisterTransitionHook(hook) {\n    history.unregisterTransitionHook(hook);\n\n    if (--listenerCount === 0) stopHashChangeListener();\n  }\n\n  // deprecated\n  function pushState(state, path) {\n    process.env.NODE_ENV !== 'production' ? _warning2['default'](queryKey || state == null, 'You cannot use state without a queryKey it will be dropped') : undefined;\n\n    history.pushState(state, path);\n  }\n\n  // deprecated\n  function replaceState(state, path) {\n    process.env.NODE_ENV !== 'production' ? _warning2['default'](queryKey || state == null, 'You cannot use state without a queryKey it will be dropped') : undefined;\n\n    history.replaceState(state, path);\n  }\n\n  return _extends({}, history, {\n    listenBefore: listenBefore,\n    listen: listen,\n    push: push,\n    replace: replace,\n    go: go,\n    createHref: createHref,\n\n    registerTransitionHook: registerTransitionHook, // deprecated - warning is in createHistory\n    unregisterTransitionHook: unregisterTransitionHook, // deprecated - warning is in createHistory\n    pushState: pushState, // deprecated - warning is in createHistory\n    replaceState: replaceState // deprecated - warning is in createHistory\n  });\n}\n\nexports['default'] = createHashHistory;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./Actions":"node_modules/history/lib/Actions.js","./DOMStateStorage":"node_modules/history/lib/DOMStateStorage.js","./DOMUtils":"node_modules/history/lib/DOMUtils.js","./ExecutionEnvironment":"node_modules/history/lib/ExecutionEnvironment.js","./PathUtils":"node_modules/history/lib/PathUtils.js","./createDOMHistory":"node_modules/history/lib/createDOMHistory.js","_process":"node_modules/process/browser.js","invariant":"node_modules/invariant/browser.js","warning":"node_modules/warning/browser.js"}},{"id":"node_modules/history/lib/createHistory.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _warning = require('warning');\n\nvar _warning2 = _interopRequireDefault(_warning);\n\nvar _deepEqual = require('deep-equal');\n\nvar _deepEqual2 = _interopRequireDefault(_deepEqual);\n\nvar _PathUtils = require('./PathUtils');\n\nvar _AsyncUtils = require('./AsyncUtils');\n\nvar _Actions = require('./Actions');\n\nvar _createLocation2 = require('./createLocation');\n\nvar _createLocation3 = _interopRequireDefault(_createLocation2);\n\nvar _runTransitionHook = require('./runTransitionHook');\n\nvar _runTransitionHook2 = _interopRequireDefault(_runTransitionHook);\n\nvar _deprecate = require('./deprecate');\n\nvar _deprecate2 = _interopRequireDefault(_deprecate);\n\nfunction createRandomKey(length) {\n  return Math.random().toString(36).substr(2, length);\n}\n\nfunction locationsAreEqual(a, b) {\n  return a.pathname === b.pathname && a.search === b.search &&\n  //a.action === b.action && // Different action !== location change.\n  a.key === b.key && _deepEqual2['default'](a.state, b.state);\n}\n\nvar DefaultKeyLength = 6;\n\nfunction createHistory() {\n  var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];\n  var getCurrentLocation = options.getCurrentLocation;\n  var finishTransition = options.finishTransition;\n  var saveState = options.saveState;\n  var go = options.go;\n  var getUserConfirmation = options.getUserConfirmation;\n  var keyLength = options.keyLength;\n\n  if (typeof keyLength !== 'number') keyLength = DefaultKeyLength;\n\n  var transitionHooks = [];\n\n  function listenBefore(hook) {\n    transitionHooks.push(hook);\n\n    return function () {\n      transitionHooks = transitionHooks.filter(function (item) {\n        return item !== hook;\n      });\n    };\n  }\n\n  var allKeys = [];\n  var changeListeners = [];\n  var location = undefined;\n\n  function getCurrent() {\n    if (pendingLocation && pendingLocation.action === _Actions.POP) {\n      return allKeys.indexOf(pendingLocation.key);\n    } else if (location) {\n      return allKeys.indexOf(location.key);\n    } else {\n      return -1;\n    }\n  }\n\n  function updateLocation(newLocation) {\n    var current = getCurrent();\n\n    location = newLocation;\n\n    if (location.action === _Actions.PUSH) {\n      allKeys = [].concat(allKeys.slice(0, current + 1), [location.key]);\n    } else if (location.action === _Actions.REPLACE) {\n      allKeys[current] = location.key;\n    }\n\n    changeListeners.forEach(function (listener) {\n      listener(location);\n    });\n  }\n\n  function listen(listener) {\n    changeListeners.push(listener);\n\n    if (location) {\n      listener(location);\n    } else {\n      var _location = getCurrentLocation();\n      allKeys = [_location.key];\n      updateLocation(_location);\n    }\n\n    return function () {\n      changeListeners = changeListeners.filter(function (item) {\n        return item !== listener;\n      });\n    };\n  }\n\n  function confirmTransitionTo(location, callback) {\n    _AsyncUtils.loopAsync(transitionHooks.length, function (index, next, done) {\n      _runTransitionHook2['default'](transitionHooks[index], location, function (result) {\n        if (result != null) {\n          done(result);\n        } else {\n          next();\n        }\n      });\n    }, function (message) {\n      if (getUserConfirmation && typeof message === 'string') {\n        getUserConfirmation(message, function (ok) {\n          callback(ok !== false);\n        });\n      } else {\n        callback(message !== false);\n      }\n    });\n  }\n\n  var pendingLocation = undefined;\n\n  function transitionTo(nextLocation) {\n    if (location && locationsAreEqual(location, nextLocation)) return; // Nothing to do.\n\n    pendingLocation = nextLocation;\n\n    confirmTransitionTo(nextLocation, function (ok) {\n      if (pendingLocation !== nextLocation) return; // Transition was interrupted.\n\n      if (ok) {\n        // treat PUSH to current path like REPLACE to be consistent with browsers\n        if (nextLocation.action === _Actions.PUSH) {\n          var prevPath = createPath(location);\n          var nextPath = createPath(nextLocation);\n\n          if (nextPath === prevPath && _deepEqual2['default'](location.state, nextLocation.state)) nextLocation.action = _Actions.REPLACE;\n        }\n\n        if (finishTransition(nextLocation) !== false) updateLocation(nextLocation);\n      } else if (location && nextLocation.action === _Actions.POP) {\n        var prevIndex = allKeys.indexOf(location.key);\n        var nextIndex = allKeys.indexOf(nextLocation.key);\n\n        if (prevIndex !== -1 && nextIndex !== -1) go(prevIndex - nextIndex); // Restore the URL.\n      }\n    });\n  }\n\n  function push(location) {\n    transitionTo(createLocation(location, _Actions.PUSH, createKey()));\n  }\n\n  function replace(location) {\n    transitionTo(createLocation(location, _Actions.REPLACE, createKey()));\n  }\n\n  function goBack() {\n    go(-1);\n  }\n\n  function goForward() {\n    go(1);\n  }\n\n  function createKey() {\n    return createRandomKey(keyLength);\n  }\n\n  function createPath(location) {\n    if (location == null || typeof location === 'string') return location;\n\n    var pathname = location.pathname;\n    var search = location.search;\n    var hash = location.hash;\n\n    var result = pathname;\n\n    if (search) result += search;\n\n    if (hash) result += hash;\n\n    return result;\n  }\n\n  function createHref(location) {\n    return createPath(location);\n  }\n\n  function createLocation(location, action) {\n    var key = arguments.length <= 2 || arguments[2] === undefined ? createKey() : arguments[2];\n\n    if (typeof action === 'object') {\n      process.env.NODE_ENV !== 'production' ? _warning2['default'](false, 'The state (2nd) argument to history.createLocation is deprecated; use a ' + 'location descriptor instead') : undefined;\n\n      if (typeof location === 'string') location = _PathUtils.parsePath(location);\n\n      location = _extends({}, location, { state: action });\n\n      action = key;\n      key = arguments[3] || createKey();\n    }\n\n    return _createLocation3['default'](location, action, key);\n  }\n\n  // deprecated\n  function setState(state) {\n    if (location) {\n      updateLocationState(location, state);\n      updateLocation(location);\n    } else {\n      updateLocationState(getCurrentLocation(), state);\n    }\n  }\n\n  function updateLocationState(location, state) {\n    location.state = _extends({}, location.state, state);\n    saveState(location.key, location.state);\n  }\n\n  // deprecated\n  function registerTransitionHook(hook) {\n    if (transitionHooks.indexOf(hook) === -1) transitionHooks.push(hook);\n  }\n\n  // deprecated\n  function unregisterTransitionHook(hook) {\n    transitionHooks = transitionHooks.filter(function (item) {\n      return item !== hook;\n    });\n  }\n\n  // deprecated\n  function pushState(state, path) {\n    if (typeof path === 'string') path = _PathUtils.parsePath(path);\n\n    push(_extends({ state: state }, path));\n  }\n\n  // deprecated\n  function replaceState(state, path) {\n    if (typeof path === 'string') path = _PathUtils.parsePath(path);\n\n    replace(_extends({ state: state }, path));\n  }\n\n  return {\n    listenBefore: listenBefore,\n    listen: listen,\n    transitionTo: transitionTo,\n    push: push,\n    replace: replace,\n    go: go,\n    goBack: goBack,\n    goForward: goForward,\n    createKey: createKey,\n    createPath: createPath,\n    createHref: createHref,\n    createLocation: createLocation,\n\n    setState: _deprecate2['default'](setState, 'setState is deprecated; use location.key to save state instead'),\n    registerTransitionHook: _deprecate2['default'](registerTransitionHook, 'registerTransitionHook is deprecated; use listenBefore instead'),\n    unregisterTransitionHook: _deprecate2['default'](unregisterTransitionHook, 'unregisterTransitionHook is deprecated; use the callback returned from listenBefore instead'),\n    pushState: _deprecate2['default'](pushState, 'pushState is deprecated; use push instead'),\n    replaceState: _deprecate2['default'](replaceState, 'replaceState is deprecated; use replace instead')\n  };\n}\n\nexports['default'] = createHistory;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./Actions":"node_modules/history/lib/Actions.js","./AsyncUtils":"node_modules/history/lib/AsyncUtils.js","./PathUtils":"node_modules/history/lib/PathUtils.js","./createLocation":"node_modules/history/lib/createLocation.js","./deprecate":"node_modules/history/lib/deprecate.js","./runTransitionHook":"node_modules/history/lib/runTransitionHook.js","_process":"node_modules/process/browser.js","deep-equal":"node_modules/deep-equal/index.js","warning":"node_modules/warning/browser.js"}},{"id":"node_modules/history/lib/createLocation.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _warning = require('warning');\n\nvar _warning2 = _interopRequireDefault(_warning);\n\nvar _Actions = require('./Actions');\n\nvar _PathUtils = require('./PathUtils');\n\nfunction createLocation() {\n  var location = arguments.length <= 0 || arguments[0] === undefined ? '/' : arguments[0];\n  var action = arguments.length <= 1 || arguments[1] === undefined ? _Actions.POP : arguments[1];\n  var key = arguments.length <= 2 || arguments[2] === undefined ? null : arguments[2];\n\n  var _fourthArg = arguments.length <= 3 || arguments[3] === undefined ? null : arguments[3];\n\n  if (typeof location === 'string') location = _PathUtils.parsePath(location);\n\n  if (typeof action === 'object') {\n    process.env.NODE_ENV !== 'production' ? _warning2['default'](false, 'The state (2nd) argument to createLocation is deprecated; use a ' + 'location descriptor instead') : undefined;\n\n    location = _extends({}, location, { state: action });\n\n    action = key || _Actions.POP;\n    key = _fourthArg;\n  }\n\n  var pathname = location.pathname || '/';\n  var search = location.search || '';\n  var hash = location.hash || '';\n  var state = location.state || null;\n\n  return {\n    pathname: pathname,\n    search: search,\n    hash: hash,\n    state: state,\n    action: action,\n    key: key\n  };\n}\n\nexports['default'] = createLocation;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./Actions":"node_modules/history/lib/Actions.js","./PathUtils":"node_modules/history/lib/PathUtils.js","_process":"node_modules/process/browser.js","warning":"node_modules/warning/browser.js"}},{"id":"node_modules/history/lib/createMemoryHistory.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _warning = require('warning');\n\nvar _warning2 = _interopRequireDefault(_warning);\n\nvar _invariant = require('invariant');\n\nvar _invariant2 = _interopRequireDefault(_invariant);\n\nvar _PathUtils = require('./PathUtils');\n\nvar _Actions = require('./Actions');\n\nvar _createHistory = require('./createHistory');\n\nvar _createHistory2 = _interopRequireDefault(_createHistory);\n\nfunction createStateStorage(entries) {\n  return entries.filter(function (entry) {\n    return entry.state;\n  }).reduce(function (memo, entry) {\n    memo[entry.key] = entry.state;\n    return memo;\n  }, {});\n}\n\nfunction createMemoryHistory() {\n  var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];\n\n  if (Array.isArray(options)) {\n    options = { entries: options };\n  } else if (typeof options === 'string') {\n    options = { entries: [options] };\n  }\n\n  var history = _createHistory2['default'](_extends({}, options, {\n    getCurrentLocation: getCurrentLocation,\n    finishTransition: finishTransition,\n    saveState: saveState,\n    go: go\n  }));\n\n  var _options = options;\n  var entries = _options.entries;\n  var current = _options.current;\n\n  if (typeof entries === 'string') {\n    entries = [entries];\n  } else if (!Array.isArray(entries)) {\n    entries = ['/'];\n  }\n\n  entries = entries.map(function (entry) {\n    var key = history.createKey();\n\n    if (typeof entry === 'string') return { pathname: entry, key: key };\n\n    if (typeof entry === 'object' && entry) return _extends({}, entry, { key: key });\n\n    !false ? process.env.NODE_ENV !== 'production' ? _invariant2['default'](false, 'Unable to create history entry from %s', entry) : _invariant2['default'](false) : undefined;\n  });\n\n  if (current == null) {\n    current = entries.length - 1;\n  } else {\n    !(current >= 0 && current < entries.length) ? process.env.NODE_ENV !== 'production' ? _invariant2['default'](false, 'Current index must be >= 0 and < %s, was %s', entries.length, current) : _invariant2['default'](false) : undefined;\n  }\n\n  var storage = createStateStorage(entries);\n\n  function saveState(key, state) {\n    storage[key] = state;\n  }\n\n  function readState(key) {\n    return storage[key];\n  }\n\n  function getCurrentLocation() {\n    var entry = entries[current];\n    var basename = entry.basename;\n    var pathname = entry.pathname;\n    var search = entry.search;\n\n    var path = (basename || '') + pathname + (search || '');\n\n    var key = undefined,\n        state = undefined;\n    if (entry.key) {\n      key = entry.key;\n      state = readState(key);\n    } else {\n      key = history.createKey();\n      state = null;\n      entry.key = key;\n    }\n\n    var location = _PathUtils.parsePath(path);\n\n    return history.createLocation(_extends({}, location, { state: state }), undefined, key);\n  }\n\n  function canGo(n) {\n    var index = current + n;\n    return index >= 0 && index < entries.length;\n  }\n\n  function go(n) {\n    if (n) {\n      if (!canGo(n)) {\n        process.env.NODE_ENV !== 'production' ? _warning2['default'](false, 'Cannot go(%s) there is not enough history', n) : undefined;\n        return;\n      }\n\n      current += n;\n\n      var currentLocation = getCurrentLocation();\n\n      // change action to POP\n      history.transitionTo(_extends({}, currentLocation, { action: _Actions.POP }));\n    }\n  }\n\n  function finishTransition(location) {\n    switch (location.action) {\n      case _Actions.PUSH:\n        current += 1;\n\n        // if we are not on the top of stack\n        // remove rest and push new\n        if (current < entries.length) entries.splice(current);\n\n        entries.push(location);\n        saveState(location.key, location.state);\n        break;\n      case _Actions.REPLACE:\n        entries[current] = location;\n        saveState(location.key, location.state);\n        break;\n    }\n  }\n\n  return history;\n}\n\nexports['default'] = createMemoryHistory;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./Actions":"node_modules/history/lib/Actions.js","./PathUtils":"node_modules/history/lib/PathUtils.js","./createHistory":"node_modules/history/lib/createHistory.js","_process":"node_modules/process/browser.js","invariant":"node_modules/invariant/browser.js","warning":"node_modules/warning/browser.js"}},{"id":"node_modules/history/lib/deprecate.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _warning = require('warning');\n\nvar _warning2 = _interopRequireDefault(_warning);\n\nfunction deprecate(fn, message) {\n  return function () {\n    process.env.NODE_ENV !== 'production' ? _warning2['default'](false, '[history] ' + message) : undefined;\n    return fn.apply(this, arguments);\n  };\n}\n\nexports['default'] = deprecate;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"_process":"node_modules/process/browser.js","warning":"node_modules/warning/browser.js"}},{"id":"node_modules/history/lib/runTransitionHook.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _warning = require('warning');\n\nvar _warning2 = _interopRequireDefault(_warning);\n\nfunction runTransitionHook(hook, location, callback) {\n  var result = hook(location, callback);\n\n  if (hook.length < 2) {\n    // Assume the hook runs synchronously and automatically\n    // call the callback with the return value.\n    callback(result);\n  } else {\n    process.env.NODE_ENV !== 'production' ? _warning2['default'](result === undefined, 'You should not \"return\" in a transition hook with a callback argument; call the callback instead') : undefined;\n  }\n}\n\nexports['default'] = runTransitionHook;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"_process":"node_modules/process/browser.js","warning":"node_modules/warning/browser.js"}},{"id":"node_modules/history/lib/useBasename.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _warning = require('warning');\n\nvar _warning2 = _interopRequireDefault(_warning);\n\nvar _ExecutionEnvironment = require('./ExecutionEnvironment');\n\nvar _PathUtils = require('./PathUtils');\n\nvar _runTransitionHook = require('./runTransitionHook');\n\nvar _runTransitionHook2 = _interopRequireDefault(_runTransitionHook);\n\nvar _deprecate = require('./deprecate');\n\nvar _deprecate2 = _interopRequireDefault(_deprecate);\n\nfunction useBasename(createHistory) {\n  return function () {\n    var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];\n\n    var history = createHistory(options);\n\n    var basename = options.basename;\n\n    var checkedBaseHref = false;\n\n    function checkBaseHref() {\n      if (checkedBaseHref) {\n        return;\n      }\n\n      // Automatically use the value of <base href> in HTML\n      // documents as basename if it's not explicitly given.\n      if (basename == null && _ExecutionEnvironment.canUseDOM) {\n        var base = document.getElementsByTagName('base')[0];\n        var baseHref = base && base.getAttribute('href');\n\n        if (baseHref != null) {\n          basename = baseHref;\n\n          process.env.NODE_ENV !== 'production' ? _warning2['default'](false, 'Automatically setting basename using <base href> is deprecated and will ' + 'be removed in the next major release. The semantics of <base href> are ' + 'subtly different from basename. Please pass the basename explicitly in ' + 'the options to createHistory') : undefined;\n        }\n      }\n\n      checkedBaseHref = true;\n    }\n\n    function addBasename(location) {\n      checkBaseHref();\n\n      if (basename && location.basename == null) {\n        if (location.pathname.indexOf(basename) === 0) {\n          location.pathname = location.pathname.substring(basename.length);\n          location.basename = basename;\n\n          if (location.pathname === '') location.pathname = '/';\n        } else {\n          location.basename = '';\n        }\n      }\n\n      return location;\n    }\n\n    function prependBasename(location) {\n      checkBaseHref();\n\n      if (!basename) return location;\n\n      if (typeof location === 'string') location = _PathUtils.parsePath(location);\n\n      var pname = location.pathname;\n      var normalizedBasename = basename.slice(-1) === '/' ? basename : basename + '/';\n      var normalizedPathname = pname.charAt(0) === '/' ? pname.slice(1) : pname;\n      var pathname = normalizedBasename + normalizedPathname;\n\n      return _extends({}, location, {\n        pathname: pathname\n      });\n    }\n\n    // Override all read methods with basename-aware versions.\n    function listenBefore(hook) {\n      return history.listenBefore(function (location, callback) {\n        _runTransitionHook2['default'](hook, addBasename(location), callback);\n      });\n    }\n\n    function listen(listener) {\n      return history.listen(function (location) {\n        listener(addBasename(location));\n      });\n    }\n\n    // Override all write methods with basename-aware versions.\n    function push(location) {\n      history.push(prependBasename(location));\n    }\n\n    function replace(location) {\n      history.replace(prependBasename(location));\n    }\n\n    function createPath(location) {\n      return history.createPath(prependBasename(location));\n    }\n\n    function createHref(location) {\n      return history.createHref(prependBasename(location));\n    }\n\n    function createLocation(location) {\n      for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {\n        args[_key - 1] = arguments[_key];\n      }\n\n      return addBasename(history.createLocation.apply(history, [prependBasename(location)].concat(args)));\n    }\n\n    // deprecated\n    function pushState(state, path) {\n      if (typeof path === 'string') path = _PathUtils.parsePath(path);\n\n      push(_extends({ state: state }, path));\n    }\n\n    // deprecated\n    function replaceState(state, path) {\n      if (typeof path === 'string') path = _PathUtils.parsePath(path);\n\n      replace(_extends({ state: state }, path));\n    }\n\n    return _extends({}, history, {\n      listenBefore: listenBefore,\n      listen: listen,\n      push: push,\n      replace: replace,\n      createPath: createPath,\n      createHref: createHref,\n      createLocation: createLocation,\n\n      pushState: _deprecate2['default'](pushState, 'pushState is deprecated; use push instead'),\n      replaceState: _deprecate2['default'](replaceState, 'replaceState is deprecated; use replace instead')\n    });\n  };\n}\n\nexports['default'] = useBasename;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./ExecutionEnvironment":"node_modules/history/lib/ExecutionEnvironment.js","./PathUtils":"node_modules/history/lib/PathUtils.js","./deprecate":"node_modules/history/lib/deprecate.js","./runTransitionHook":"node_modules/history/lib/runTransitionHook.js","_process":"node_modules/process/browser.js","warning":"node_modules/warning/browser.js"}},{"id":"node_modules/history/lib/useQueries.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _warning = require('warning');\n\nvar _warning2 = _interopRequireDefault(_warning);\n\nvar _queryString = require('query-string');\n\nvar _runTransitionHook = require('./runTransitionHook');\n\nvar _runTransitionHook2 = _interopRequireDefault(_runTransitionHook);\n\nvar _PathUtils = require('./PathUtils');\n\nvar _deprecate = require('./deprecate');\n\nvar _deprecate2 = _interopRequireDefault(_deprecate);\n\nvar SEARCH_BASE_KEY = '$searchBase';\n\nfunction defaultStringifyQuery(query) {\n  return _queryString.stringify(query).replace(/%20/g, '+');\n}\n\nvar defaultParseQueryString = _queryString.parse;\n\nfunction isNestedObject(object) {\n  for (var p in object) {\n    if (Object.prototype.hasOwnProperty.call(object, p) && typeof object[p] === 'object' && !Array.isArray(object[p]) && object[p] !== null) return true;\n  }return false;\n}\n\n/**\n * Returns a new createHistory function that may be used to create\n * history objects that know how to handle URL queries.\n */\nfunction useQueries(createHistory) {\n  return function () {\n    var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];\n\n    var history = createHistory(options);\n\n    var stringifyQuery = options.stringifyQuery;\n    var parseQueryString = options.parseQueryString;\n\n    if (typeof stringifyQuery !== 'function') stringifyQuery = defaultStringifyQuery;\n\n    if (typeof parseQueryString !== 'function') parseQueryString = defaultParseQueryString;\n\n    function addQuery(location) {\n      if (location.query == null) {\n        var search = location.search;\n\n        location.query = parseQueryString(search.substring(1));\n        location[SEARCH_BASE_KEY] = { search: search, searchBase: '' };\n      }\n\n      // TODO: Instead of all the book-keeping here, this should just strip the\n      // stringified query from the search.\n\n      return location;\n    }\n\n    function appendQuery(location, query) {\n      var _extends2;\n\n      var searchBaseSpec = location[SEARCH_BASE_KEY];\n      var queryString = query ? stringifyQuery(query) : '';\n      if (!searchBaseSpec && !queryString) {\n        return location;\n      }\n\n      process.env.NODE_ENV !== 'production' ? _warning2['default'](stringifyQuery !== defaultStringifyQuery || !isNestedObject(query), 'useQueries does not stringify nested query objects by default; ' + 'use a custom stringifyQuery function') : undefined;\n\n      if (typeof location === 'string') location = _PathUtils.parsePath(location);\n\n      var searchBase = undefined;\n      if (searchBaseSpec && location.search === searchBaseSpec.search) {\n        searchBase = searchBaseSpec.searchBase;\n      } else {\n        searchBase = location.search || '';\n      }\n\n      var search = searchBase;\n      if (queryString) {\n        search += (search ? '&' : '?') + queryString;\n      }\n\n      return _extends({}, location, (_extends2 = {\n        search: search\n      }, _extends2[SEARCH_BASE_KEY] = { search: search, searchBase: searchBase }, _extends2));\n    }\n\n    // Override all read methods with query-aware versions.\n    function listenBefore(hook) {\n      return history.listenBefore(function (location, callback) {\n        _runTransitionHook2['default'](hook, addQuery(location), callback);\n      });\n    }\n\n    function listen(listener) {\n      return history.listen(function (location) {\n        listener(addQuery(location));\n      });\n    }\n\n    // Override all write methods with query-aware versions.\n    function push(location) {\n      history.push(appendQuery(location, location.query));\n    }\n\n    function replace(location) {\n      history.replace(appendQuery(location, location.query));\n    }\n\n    function createPath(location, query) {\n      process.env.NODE_ENV !== 'production' ? _warning2['default'](!query, 'the query argument to createPath is deprecated; use a location descriptor instead') : undefined;\n\n      return history.createPath(appendQuery(location, query || location.query));\n    }\n\n    function createHref(location, query) {\n      process.env.NODE_ENV !== 'production' ? _warning2['default'](!query, 'the query argument to createHref is deprecated; use a location descriptor instead') : undefined;\n\n      return history.createHref(appendQuery(location, query || location.query));\n    }\n\n    function createLocation(location) {\n      for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {\n        args[_key - 1] = arguments[_key];\n      }\n\n      var fullLocation = history.createLocation.apply(history, [appendQuery(location, location.query)].concat(args));\n      if (location.query) {\n        fullLocation.query = location.query;\n      }\n      return addQuery(fullLocation);\n    }\n\n    // deprecated\n    function pushState(state, path, query) {\n      if (typeof path === 'string') path = _PathUtils.parsePath(path);\n\n      push(_extends({ state: state }, path, { query: query }));\n    }\n\n    // deprecated\n    function replaceState(state, path, query) {\n      if (typeof path === 'string') path = _PathUtils.parsePath(path);\n\n      replace(_extends({ state: state }, path, { query: query }));\n    }\n\n    return _extends({}, history, {\n      listenBefore: listenBefore,\n      listen: listen,\n      push: push,\n      replace: replace,\n      createPath: createPath,\n      createHref: createHref,\n      createLocation: createLocation,\n\n      pushState: _deprecate2['default'](pushState, 'pushState is deprecated; use push instead'),\n      replaceState: _deprecate2['default'](replaceState, 'replaceState is deprecated; use replace instead')\n    });\n  };\n}\n\nexports['default'] = useQueries;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./PathUtils":"node_modules/history/lib/PathUtils.js","./deprecate":"node_modules/history/lib/deprecate.js","./runTransitionHook":"node_modules/history/lib/runTransitionHook.js","_process":"node_modules/process/browser.js","query-string":"node_modules/query-string/index.js","warning":"node_modules/warning/browser.js"}},{"id":"node_modules/invariant/browser.js","source":"'use strict';\n\n/**\n * Use invariant() to assert state which your program assumes to be true.\n *\n * Provide sprintf-style format (only %s is supported) and arguments\n * to provide information about what broke and what you were\n * expecting.\n *\n * The invariant message will be stripped in production, but the invariant\n * will remain to ensure logic does not differ in production.\n */\n\nvar invariant = function(condition, format, a, b, c, d, e, f) {\n  if (\"production\" !== 'production') {\n    if (format === undefined) {\n      throw new Error('invariant requires an error message argument');\n    }\n  }\n\n  if (!condition) {\n    var error;\n    if (format === undefined) {\n      error = new Error(\n        'Minified exception occurred; use the non-minified dev environment ' +\n        'for the full error message and additional helpful warnings.'\n      );\n    } else {\n      var args = [a, b, c, d, e, f];\n      var argIndex = 0;\n      error = new Error(\n        format.replace(/%s/g, function() { return args[argIndex++]; })\n      );\n      error.name = 'Invariant Violation';\n    }\n\n    error.framesToPop = 1; // we don't care about invariant's own frame\n    throw error;\n  }\n};\n\nmodule.exports = invariant;","deps":{}},{"id":"node_modules/process/browser.js","source":"var process = module.exports = {};\n\n// cached from whatever global is present so that test runners that stub it\n// don't break things.  But we need to wrap it in a try catch in case it is\n// wrapped in strict mode code which doesn't define any globals.  It's inside a\n// function because try/catches deoptimize in certain engines.\n\nvar cachedSetTimeout;\nvar cachedClearTimeout;\n\nfunction defaultSetTimout() {\n    throw new Error('setTimeout has not been defined');\n}\nfunction defaultClearTimeout () {\n    throw new Error('clearTimeout has not been defined');\n}\n(function () {\n    try {\n        if (typeof setTimeout === 'function') {\n            cachedSetTimeout = setTimeout;\n        } else {\n            cachedSetTimeout = defaultSetTimout;\n        }\n    } catch (e) {\n        cachedSetTimeout = defaultSetTimout;\n    }\n    try {\n        if (typeof clearTimeout === 'function') {\n            cachedClearTimeout = clearTimeout;\n        } else {\n            cachedClearTimeout = defaultClearTimeout;\n        }\n    } catch (e) {\n        cachedClearTimeout = defaultClearTimeout;\n    }\n} ())\nfunction runTimeout(fun) {\n    if (cachedSetTimeout === setTimeout) {\n        //normal enviroments in sane situations\n        return setTimeout(fun, 0);\n    }\n    // if setTimeout wasn't available but was latter defined\n    if ((cachedSetTimeout === defaultSetTimout || !cachedSetTimeout) && setTimeout) {\n        cachedSetTimeout = setTimeout;\n        return setTimeout(fun, 0);\n    }\n    try {\n        // when when somebody has screwed with setTimeout but no I.E. maddness\n        return cachedSetTimeout(fun, 0);\n    } catch(e){\n        try {\n            // When we are in I.E. but the script has been evaled so I.E. doesn't trust the global object when called normally\n            return cachedSetTimeout.call(null, fun, 0);\n        } catch(e){\n            // same as above but when it's a version of I.E. that must have the global object for 'this', hopfully our context correct otherwise it will throw a global error\n            return cachedSetTimeout.call(this, fun, 0);\n        }\n    }\n\n\n}\nfunction runClearTimeout(marker) {\n    if (cachedClearTimeout === clearTimeout) {\n        //normal enviroments in sane situations\n        return clearTimeout(marker);\n    }\n    // if clearTimeout wasn't available but was latter defined\n    if ((cachedClearTimeout === defaultClearTimeout || !cachedClearTimeout) && clearTimeout) {\n        cachedClearTimeout = clearTimeout;\n        return clearTimeout(marker);\n    }\n    try {\n        // when when somebody has screwed with setTimeout but no I.E. maddness\n        return cachedClearTimeout(marker);\n    } catch (e){\n        try {\n            // When we are in I.E. but the script has been evaled so I.E. doesn't  trust the global object when called normally\n            return cachedClearTimeout.call(null, marker);\n        } catch (e){\n            // same as above but when it's a version of I.E. that must have the global object for 'this', hopfully our context correct otherwise it will throw a global error.\n            // Some versions of I.E. have different rules for clearTimeout vs setTimeout\n            return cachedClearTimeout.call(this, marker);\n        }\n    }\n\n\n\n}\nvar queue = [];\nvar draining = false;\nvar currentQueue;\nvar queueIndex = -1;\n\nfunction cleanUpNextTick() {\n    if (!draining || !currentQueue) {\n        return;\n    }\n    draining = false;\n    if (currentQueue.length) {\n        queue = currentQueue.concat(queue);\n    } else {\n        queueIndex = -1;\n    }\n    if (queue.length) {\n        drainQueue();\n    }\n}\n\nfunction drainQueue() {\n    if (draining) {\n        return;\n    }\n    var timeout = runTimeout(cleanUpNextTick);\n    draining = true;\n\n    var len = queue.length;\n    while(len) {\n        currentQueue = queue;\n        queue = [];\n        while (++queueIndex < len) {\n            if (currentQueue) {\n                currentQueue[queueIndex].run();\n            }\n        }\n        queueIndex = -1;\n        len = queue.length;\n    }\n    currentQueue = null;\n    draining = false;\n    runClearTimeout(timeout);\n}\n\nprocess.nextTick = function (fun) {\n    var args = new Array(arguments.length - 1);\n    if (arguments.length > 1) {\n        for (var i = 1; i < arguments.length; i++) {\n            args[i - 1] = arguments[i];\n        }\n    }\n    queue.push(new Item(fun, args));\n    if (queue.length === 1 && !draining) {\n        runTimeout(drainQueue);\n    }\n};\n\n// v8 likes predictible objects\nfunction Item(fun, array) {\n    this.fun = fun;\n    this.array = array;\n}\nItem.prototype.run = function () {\n    this.fun.apply(null, this.array);\n};\nprocess.title = 'browser';\nprocess.browser = true;\nprocess.env = {};\nprocess.argv = [];\nprocess.version = ''; // empty string to avoid regexp issues\nprocess.versions = {};\n\nfunction noop() {}\n\nprocess.on = noop;\nprocess.addListener = noop;\nprocess.once = noop;\nprocess.off = noop;\nprocess.removeListener = noop;\nprocess.removeAllListeners = noop;\nprocess.emit = noop;\nprocess.prependListener = noop;\nprocess.prependOnceListener = noop;\n\nprocess.listeners = function (name) { return [] }\n\nprocess.binding = function (name) {\n    throw new Error('process.binding is not supported');\n};\n\nprocess.cwd = function () { return '/' };\nprocess.chdir = function (dir) {\n    throw new Error('process.chdir is not supported');\n};\nprocess.umask = function() { return 0; };","deps":{}},{"id":"node_modules/query-string/index.js","source":"'use strict';\nvar strictUriEncode = require('strict-uri-encode');\n\nexports.extract = function (str) {\n\treturn str.split('?')[1] || '';\n};\n\nexports.parse = function (str) {\n\tif (typeof str !== 'string') {\n\t\treturn {};\n\t}\n\n\tstr = str.trim().replace(/^(\\?|#|&)/, '');\n\n\tif (!str) {\n\t\treturn {};\n\t}\n\n\treturn str.split('&').reduce(function (ret, param) {\n\t\tvar parts = param.replace(/\\+/g, ' ').split('=');\n\t\t// Firefox (pre 40) decodes `%3D` to `=`\n\t\t// https://github.com/sindresorhus/query-string/pull/37\n\t\tvar key = parts.shift();\n\t\tvar val = parts.length > 0 ? parts.join('=') : undefined;\n\n\t\tkey = decodeURIComponent(key);\n\n\t\t// missing `=` should be `null`:\n\t\t// http://w3.org/TR/2012/WD-url-20120524/#collect-url-parameters\n\t\tval = val === undefined ? null : decodeURIComponent(val);\n\n\t\tif (!ret.hasOwnProperty(key)) {\n\t\t\tret[key] = val;\n\t\t} else if (Array.isArray(ret[key])) {\n\t\t\tret[key].push(val);\n\t\t} else {\n\t\t\tret[key] = [ret[key], val];\n\t\t}\n\n\t\treturn ret;\n\t}, {});\n};\n\nexports.stringify = function (obj) {\n\treturn obj ? Object.keys(obj).sort().map(function (key) {\n\t\tvar val = obj[key];\n\n\t\tif (val === undefined) {\n\t\t\treturn '';\n\t\t}\n\n\t\tif (val === null) {\n\t\t\treturn key;\n\t\t}\n\n\t\tif (Array.isArray(val)) {\n\t\t\treturn val.slice().sort().map(function (val2) {\n\t\t\t\treturn strictUriEncode(key) + '=' + strictUriEncode(val2);\n\t\t\t}).join('&');\n\t\t}\n\n\t\treturn strictUriEncode(key) + '=' + strictUriEncode(val);\n\t}).filter(function (x) {\n\t\treturn x.length > 0;\n\t}).join('&') : '';\n};","deps":{"strict-uri-encode":"node_modules/strict-uri-encode/index.js"}},{"id":"node_modules/react-router/lib/AsyncUtils.js","source":"\"use strict\";\n\nexports.__esModule = true;\nvar _slice = Array.prototype.slice;\nexports.loopAsync = loopAsync;\nexports.mapAsync = mapAsync;\n\nfunction loopAsync(turns, work, callback) {\n  var currentTurn = 0,\n      isDone = false;\n  var sync = false,\n      hasNext = false,\n      doneArgs = undefined;\n\n  function done() {\n    isDone = true;\n    if (sync) {\n      // Iterate instead of recursing if possible.\n      doneArgs = [].concat(_slice.call(arguments));\n      return;\n    }\n\n    callback.apply(this, arguments);\n  }\n\n  function next() {\n    if (isDone) {\n      return;\n    }\n\n    hasNext = true;\n    if (sync) {\n      // Iterate instead of recursing if possible.\n      return;\n    }\n\n    sync = true;\n\n    while (!isDone && currentTurn < turns && hasNext) {\n      hasNext = false;\n      work.call(this, currentTurn++, next, done);\n    }\n\n    sync = false;\n\n    if (isDone) {\n      // This means the loop finished synchronously.\n      callback.apply(this, doneArgs);\n      return;\n    }\n\n    if (currentTurn >= turns && hasNext) {\n      isDone = true;\n      callback();\n    }\n  }\n\n  next();\n}\n\nfunction mapAsync(array, work, callback) {\n  var length = array.length;\n  var values = [];\n\n  if (length === 0) return callback(null, values);\n\n  var isDone = false,\n      doneCount = 0;\n\n  function done(index, error, value) {\n    if (isDone) return;\n\n    if (error) {\n      isDone = true;\n      callback(error);\n    } else {\n      values[index] = value;\n\n      isDone = ++doneCount === length;\n\n      if (isDone) callback(null, values);\n    }\n  }\n\n  array.forEach(function (item, index) {\n    work(item, index, function (error, value) {\n      done(index, error, value);\n    });\n  });\n}","deps":{}},{"id":"node_modules/react-router/lib/History.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\nvar _InternalPropTypes = require('./InternalPropTypes');\n\n/**\n * A mixin that adds the \"history\" instance variable to components.\n */\nvar History = {\n\n  contextTypes: {\n    history: _InternalPropTypes.history\n  },\n\n  componentWillMount: function componentWillMount() {\n    process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, 'the `History` mixin is deprecated, please access `context.router` with your own `contextTypes`. http://tiny.cc/router-historymixin') : undefined;\n    this.history = this.context.history;\n  }\n\n};\n\nexports['default'] = History;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./InternalPropTypes":"node_modules/react-router/lib/InternalPropTypes.js","./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js"}},{"id":"node_modules/react-router/lib/IndexLink.js","source":"'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _react = require('react');\n\nvar _react2 = _interopRequireDefault(_react);\n\nvar _Link = require('./Link');\n\nvar _Link2 = _interopRequireDefault(_Link);\n\n/**\n * An <IndexLink> is used to link to an <IndexRoute>.\n */\nvar IndexLink = _react2['default'].createClass({\n  displayName: 'IndexLink',\n\n  render: function render() {\n    return _react2['default'].createElement(_Link2['default'], _extends({}, this.props, { onlyActiveOnIndex: true }));\n  }\n\n});\n\nexports['default'] = IndexLink;\nmodule.exports = exports['default'];","deps":{"./Link":"node_modules/react-router/lib/Link.js","react":"node_modules/react/react.js"}},{"id":"node_modules/react-router/lib/IndexRedirect.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _react = require('react');\n\nvar _react2 = _interopRequireDefault(_react);\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\nvar _invariant = require('invariant');\n\nvar _invariant2 = _interopRequireDefault(_invariant);\n\nvar _Redirect = require('./Redirect');\n\nvar _Redirect2 = _interopRequireDefault(_Redirect);\n\nvar _InternalPropTypes = require('./InternalPropTypes');\n\nvar _React$PropTypes = _react2['default'].PropTypes;\nvar string = _React$PropTypes.string;\nvar object = _React$PropTypes.object;\n\n/**\n * An <IndexRedirect> is used to redirect from an indexRoute.\n */\nvar IndexRedirect = _react2['default'].createClass({\n  displayName: 'IndexRedirect',\n\n  statics: {\n\n    createRouteFromReactElement: function createRouteFromReactElement(element, parentRoute) {\n      /* istanbul ignore else: sanity check */\n      if (parentRoute) {\n        parentRoute.indexRoute = _Redirect2['default'].createRouteFromReactElement(element);\n      } else {\n        process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, 'An <IndexRedirect> does not make sense at the root of your route config') : undefined;\n      }\n    }\n\n  },\n\n  propTypes: {\n    to: string.isRequired,\n    query: object,\n    state: object,\n    onEnter: _InternalPropTypes.falsy,\n    children: _InternalPropTypes.falsy\n  },\n\n  /* istanbul ignore next: sanity check */\n  render: function render() {\n    !false ? process.env.NODE_ENV !== 'production' ? _invariant2['default'](false, '<IndexRedirect> elements are for router configuration only and should not be rendered') : _invariant2['default'](false) : undefined;\n  }\n\n});\n\nexports['default'] = IndexRedirect;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./InternalPropTypes":"node_modules/react-router/lib/InternalPropTypes.js","./Redirect":"node_modules/react-router/lib/Redirect.js","./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js","invariant":"node_modules/invariant/browser.js","react":"node_modules/react/react.js"}},{"id":"node_modules/react-router/lib/IndexRoute.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _react = require('react');\n\nvar _react2 = _interopRequireDefault(_react);\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\nvar _invariant = require('invariant');\n\nvar _invariant2 = _interopRequireDefault(_invariant);\n\nvar _RouteUtils = require('./RouteUtils');\n\nvar _InternalPropTypes = require('./InternalPropTypes');\n\nvar func = _react2['default'].PropTypes.func;\n\n/**\n * An <IndexRoute> is used to specify its parent's <Route indexRoute> in\n * a JSX route config.\n */\nvar IndexRoute = _react2['default'].createClass({\n  displayName: 'IndexRoute',\n\n  statics: {\n\n    createRouteFromReactElement: function createRouteFromReactElement(element, parentRoute) {\n      /* istanbul ignore else: sanity check */\n      if (parentRoute) {\n        parentRoute.indexRoute = _RouteUtils.createRouteFromReactElement(element);\n      } else {\n        process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, 'An <IndexRoute> does not make sense at the root of your route config') : undefined;\n      }\n    }\n\n  },\n\n  propTypes: {\n    path: _InternalPropTypes.falsy,\n    component: _InternalPropTypes.component,\n    components: _InternalPropTypes.components,\n    getComponent: func,\n    getComponents: func\n  },\n\n  /* istanbul ignore next: sanity check */\n  render: function render() {\n    !false ? process.env.NODE_ENV !== 'production' ? _invariant2['default'](false, '<IndexRoute> elements are for router configuration only and should not be rendered') : _invariant2['default'](false) : undefined;\n  }\n\n});\n\nexports['default'] = IndexRoute;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./InternalPropTypes":"node_modules/react-router/lib/InternalPropTypes.js","./RouteUtils":"node_modules/react-router/lib/RouteUtils.js","./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js","invariant":"node_modules/invariant/browser.js","react":"node_modules/react/react.js"}},{"id":"node_modules/react-router/lib/InternalPropTypes.js","source":"'use strict';\n\nexports.__esModule = true;\nexports.falsy = falsy;\n\nvar _react = require('react');\n\nvar func = _react.PropTypes.func;\nvar object = _react.PropTypes.object;\nvar arrayOf = _react.PropTypes.arrayOf;\nvar oneOfType = _react.PropTypes.oneOfType;\nvar element = _react.PropTypes.element;\nvar shape = _react.PropTypes.shape;\nvar string = _react.PropTypes.string;\n\nfunction falsy(props, propName, componentName) {\n  if (props[propName]) return new Error('<' + componentName + '> should not have a \"' + propName + '\" prop');\n}\n\nvar history = shape({\n  listen: func.isRequired,\n  push: func.isRequired,\n  replace: func.isRequired,\n  go: func.isRequired,\n  goBack: func.isRequired,\n  goForward: func.isRequired\n});\n\nexports.history = history;\nvar component = oneOfType([func, string]);\nexports.component = component;\nvar components = oneOfType([component, object]);\nexports.components = components;\nvar route = oneOfType([object, element]);\nexports.route = route;\nvar routes = oneOfType([route, arrayOf(route)]);\nexports.routes = routes;","deps":{"react":"node_modules/react/react.js"}},{"id":"node_modules/react-router/lib/Lifecycle.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\nvar _react = require('react');\n\nvar _react2 = _interopRequireDefault(_react);\n\nvar _invariant = require('invariant');\n\nvar _invariant2 = _interopRequireDefault(_invariant);\n\nvar object = _react2['default'].PropTypes.object;\n\n/**\n * The Lifecycle mixin adds the routerWillLeave lifecycle method to a\n * component that may be used to cancel a transition or prompt the user\n * for confirmation.\n *\n * On standard transitions, routerWillLeave receives a single argument: the\n * location we're transitioning to. To cancel the transition, return false.\n * To prompt the user for confirmation, return a prompt message (string).\n *\n * During the beforeunload event (assuming you're using the useBeforeUnload\n * history enhancer), routerWillLeave does not receive a location object\n * because it isn't possible for us to know the location we're transitioning\n * to. In this case routerWillLeave must return a prompt message to prevent\n * the user from closing the window/tab.\n */\nvar Lifecycle = {\n\n  contextTypes: {\n    history: object.isRequired,\n    // Nested children receive the route as context, either\n    // set by the route component using the RouteContext mixin\n    // or by some other ancestor.\n    route: object\n  },\n\n  propTypes: {\n    // Route components receive the route object as a prop.\n    route: object\n  },\n\n  componentDidMount: function componentDidMount() {\n    process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, 'the `Lifecycle` mixin is deprecated, please use `context.router.setRouteLeaveHook(route, hook)`. http://tiny.cc/router-lifecyclemixin') : undefined;\n    !this.routerWillLeave ? process.env.NODE_ENV !== 'production' ? _invariant2['default'](false, 'The Lifecycle mixin requires you to define a routerWillLeave method') : _invariant2['default'](false) : undefined;\n\n    var route = this.props.route || this.context.route;\n\n    !route ? process.env.NODE_ENV !== 'production' ? _invariant2['default'](false, 'The Lifecycle mixin must be used on either a) a <Route component> or ' + 'b) a descendant of a <Route component> that uses the RouteContext mixin') : _invariant2['default'](false) : undefined;\n\n    this._unlistenBeforeLeavingRoute = this.context.history.listenBeforeLeavingRoute(route, this.routerWillLeave);\n  },\n\n  componentWillUnmount: function componentWillUnmount() {\n    if (this._unlistenBeforeLeavingRoute) this._unlistenBeforeLeavingRoute();\n  }\n\n};\n\nexports['default'] = Lifecycle;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js","invariant":"node_modules/invariant/browser.js","react":"node_modules/react/react.js"}},{"id":"node_modules/react-router/lib/Link.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nfunction _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }\n\nvar _react = require('react');\n\nvar _react2 = _interopRequireDefault(_react);\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\nvar _PropTypes = require('./PropTypes');\n\nvar _React$PropTypes = _react2['default'].PropTypes;\nvar bool = _React$PropTypes.bool;\nvar object = _React$PropTypes.object;\nvar string = _React$PropTypes.string;\nvar func = _React$PropTypes.func;\nvar oneOfType = _React$PropTypes.oneOfType;\n\nfunction isLeftClickEvent(event) {\n  return event.button === 0;\n}\n\nfunction isModifiedEvent(event) {\n  return !!(event.metaKey || event.altKey || event.ctrlKey || event.shiftKey);\n}\n\n// TODO: De-duplicate against hasAnyProperties in createTransitionManager.\nfunction isEmptyObject(object) {\n  for (var p in object) {\n    if (Object.prototype.hasOwnProperty.call(object, p)) return false;\n  }return true;\n}\n\nfunction createLocationDescriptor(to, _ref) {\n  var query = _ref.query;\n  var hash = _ref.hash;\n  var state = _ref.state;\n\n  if (query || hash || state) {\n    return { pathname: to, query: query, hash: hash, state: state };\n  }\n\n  return to;\n}\n\n/**\n * A <Link> is used to create an <a> element that links to a route.\n * When that route is active, the link gets the value of its\n * activeClassName prop.\n *\n * For example, assuming you have the following route:\n *\n *   <Route path=\"/posts/:postID\" component={Post} />\n *\n * You could use the following component to link to that route:\n *\n *   <Link to={`/posts/${post.id}`} />\n *\n * Links may pass along location state and/or query string parameters\n * in the state/query props, respectively.\n *\n *   <Link ... query={{ show: true }} state={{ the: 'state' }} />\n */\nvar Link = _react2['default'].createClass({\n  displayName: 'Link',\n\n  contextTypes: {\n    router: _PropTypes.routerShape\n  },\n\n  propTypes: {\n    to: oneOfType([string, object]).isRequired,\n    query: object,\n    hash: string,\n    state: object,\n    activeStyle: object,\n    activeClassName: string,\n    onlyActiveOnIndex: bool.isRequired,\n    onClick: func\n  },\n\n  getDefaultProps: function getDefaultProps() {\n    return {\n      onlyActiveOnIndex: false,\n      style: {}\n    };\n  },\n\n  handleClick: function handleClick(event) {\n    var allowTransition = true;\n\n    if (this.props.onClick) this.props.onClick(event);\n\n    if (isModifiedEvent(event) || !isLeftClickEvent(event)) return;\n\n    if (event.defaultPrevented === true) allowTransition = false;\n\n    // If target prop is set (e.g. to \"_blank\") let browser handle link.\n    /* istanbul ignore if: untestable with Karma */\n    if (this.props.target) {\n      if (!allowTransition) event.preventDefault();\n\n      return;\n    }\n\n    event.preventDefault();\n\n    if (allowTransition) {\n      var _props = this.props;\n      var to = _props.to;\n      var query = _props.query;\n      var hash = _props.hash;\n      var state = _props.state;\n\n      var _location = createLocationDescriptor(to, { query: query, hash: hash, state: state });\n\n      this.context.router.push(_location);\n    }\n  },\n\n  render: function render() {\n    var _props2 = this.props;\n    var to = _props2.to;\n    var query = _props2.query;\n    var hash = _props2.hash;\n    var state = _props2.state;\n    var activeClassName = _props2.activeClassName;\n    var activeStyle = _props2.activeStyle;\n    var onlyActiveOnIndex = _props2.onlyActiveOnIndex;\n\n    var props = _objectWithoutProperties(_props2, ['to', 'query', 'hash', 'state', 'activeClassName', 'activeStyle', 'onlyActiveOnIndex']);\n\n    process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](!(query || hash || state), 'the `query`, `hash`, and `state` props on `<Link>` are deprecated, use `<Link to={{ pathname, query, hash, state }}/>. http://tiny.cc/router-isActivedeprecated') : undefined;\n\n    // Ignore if rendered outside the context of router, simplifies unit testing.\n    var router = this.context.router;\n\n    if (router) {\n      var _location2 = createLocationDescriptor(to, { query: query, hash: hash, state: state });\n      props.href = router.createHref(_location2);\n\n      if (activeClassName || activeStyle != null && !isEmptyObject(activeStyle)) {\n        if (router.isActive(_location2, onlyActiveOnIndex)) {\n          if (activeClassName) {\n            if (props.className) {\n              props.className += ' ' + activeClassName;\n            } else {\n              props.className = activeClassName;\n            }\n          }\n\n          if (activeStyle) props.style = _extends({}, props.style, activeStyle);\n        }\n      }\n    }\n\n    return _react2['default'].createElement('a', _extends({}, props, { onClick: this.handleClick }));\n  }\n\n});\n\nexports['default'] = Link;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./PropTypes":"node_modules/react-router/lib/PropTypes.js","./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js","react":"node_modules/react/react.js"}},{"id":"node_modules/react-router/lib/PatternUtils.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\nexports.compilePattern = compilePattern;\nexports.matchPattern = matchPattern;\nexports.getParamNames = getParamNames;\nexports.getParams = getParams;\nexports.formatPattern = formatPattern;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _invariant = require('invariant');\n\nvar _invariant2 = _interopRequireDefault(_invariant);\n\nfunction escapeRegExp(string) {\n  return string.replace(/[.*+?^${}()|[\\]\\\\]/g, '\\\\$&');\n}\n\nfunction _compilePattern(pattern) {\n  var regexpSource = '';\n  var paramNames = [];\n  var tokens = [];\n\n  var match = undefined,\n      lastIndex = 0,\n      matcher = /:([a-zA-Z_$][a-zA-Z0-9_$]*)|\\*\\*|\\*|\\(|\\)/g;\n  while (match = matcher.exec(pattern)) {\n    if (match.index !== lastIndex) {\n      tokens.push(pattern.slice(lastIndex, match.index));\n      regexpSource += escapeRegExp(pattern.slice(lastIndex, match.index));\n    }\n\n    if (match[1]) {\n      regexpSource += '([^/]+)';\n      paramNames.push(match[1]);\n    } else if (match[0] === '**') {\n      regexpSource += '(.*)';\n      paramNames.push('splat');\n    } else if (match[0] === '*') {\n      regexpSource += '(.*?)';\n      paramNames.push('splat');\n    } else if (match[0] === '(') {\n      regexpSource += '(?:';\n    } else if (match[0] === ')') {\n      regexpSource += ')?';\n    }\n\n    tokens.push(match[0]);\n\n    lastIndex = matcher.lastIndex;\n  }\n\n  if (lastIndex !== pattern.length) {\n    tokens.push(pattern.slice(lastIndex, pattern.length));\n    regexpSource += escapeRegExp(pattern.slice(lastIndex, pattern.length));\n  }\n\n  return {\n    pattern: pattern,\n    regexpSource: regexpSource,\n    paramNames: paramNames,\n    tokens: tokens\n  };\n}\n\nvar CompiledPatternsCache = {};\n\nfunction compilePattern(pattern) {\n  if (!(pattern in CompiledPatternsCache)) CompiledPatternsCache[pattern] = _compilePattern(pattern);\n\n  return CompiledPatternsCache[pattern];\n}\n\n/**\n * Attempts to match a pattern on the given pathname. Patterns may use\n * the following special characters:\n *\n * - :paramName     Matches a URL segment up to the next /, ?, or #. The\n *                  captured string is considered a \"param\"\n * - ()             Wraps a segment of the URL that is optional\n * - *              Consumes (non-greedy) all characters up to the next\n *                  character in the pattern, or to the end of the URL if\n *                  there is none\n * - **             Consumes (greedy) all characters up to the next character\n *                  in the pattern, or to the end of the URL if there is none\n *\n * The return value is an object with the following properties:\n *\n * - remainingPathname\n * - paramNames\n * - paramValues\n */\n\nfunction matchPattern(pattern, pathname) {\n  // Ensure pattern starts with leading slash for consistency with pathname.\n  if (pattern.charAt(0) !== '/') {\n    pattern = '/' + pattern;\n  }\n\n  var _compilePattern2 = compilePattern(pattern);\n\n  var regexpSource = _compilePattern2.regexpSource;\n  var paramNames = _compilePattern2.paramNames;\n  var tokens = _compilePattern2.tokens;\n\n  if (pattern.charAt(pattern.length - 1) !== '/') {\n    regexpSource += '/?'; // Allow optional path separator at end.\n  }\n\n  // Special-case patterns like '*' for catch-all routes.\n  if (tokens[tokens.length - 1] === '*') {\n    regexpSource += '$';\n  }\n\n  var match = pathname.match(new RegExp('^' + regexpSource, 'i'));\n\n  var remainingPathname = undefined,\n      paramValues = undefined;\n  if (match != null) {\n    var matchedPath = match[0];\n    remainingPathname = pathname.substr(matchedPath.length);\n\n    if (remainingPathname) {\n      // Require that the match ends at a path separator, if we didn't match\n      // the full path, so any remaining pathname is a new path segment.\n      if (matchedPath.charAt(matchedPath.length - 1) !== '/') {\n        return {\n          remainingPathname: null,\n          paramNames: paramNames,\n          paramValues: null\n        };\n      }\n\n      // If there is a remaining pathname, treat the path separator as part of\n      // the remaining pathname for properly continuing the match.\n      remainingPathname = '/' + remainingPathname;\n    }\n\n    paramValues = match.slice(1).map(function (v) {\n      return v && decodeURIComponent(v);\n    });\n  } else {\n    remainingPathname = paramValues = null;\n  }\n\n  return {\n    remainingPathname: remainingPathname,\n    paramNames: paramNames,\n    paramValues: paramValues\n  };\n}\n\nfunction getParamNames(pattern) {\n  return compilePattern(pattern).paramNames;\n}\n\nfunction getParams(pattern, pathname) {\n  var _matchPattern = matchPattern(pattern, pathname);\n\n  var paramNames = _matchPattern.paramNames;\n  var paramValues = _matchPattern.paramValues;\n\n  if (paramValues != null) {\n    return paramNames.reduce(function (memo, paramName, index) {\n      memo[paramName] = paramValues[index];\n      return memo;\n    }, {});\n  }\n\n  return null;\n}\n\n/**\n * Returns a version of the given pattern with params interpolated. Throws\n * if there is a dynamic segment of the pattern for which there is no param.\n */\n\nfunction formatPattern(pattern, params) {\n  params = params || {};\n\n  var _compilePattern3 = compilePattern(pattern);\n\n  var tokens = _compilePattern3.tokens;\n\n  var parenCount = 0,\n      pathname = '',\n      splatIndex = 0;\n\n  var token = undefined,\n      paramName = undefined,\n      paramValue = undefined;\n  for (var i = 0, len = tokens.length; i < len; ++i) {\n    token = tokens[i];\n\n    if (token === '*' || token === '**') {\n      paramValue = Array.isArray(params.splat) ? params.splat[splatIndex++] : params.splat;\n\n      !(paramValue != null || parenCount > 0) ? process.env.NODE_ENV !== 'production' ? _invariant2['default'](false, 'Missing splat #%s for path \"%s\"', splatIndex, pattern) : _invariant2['default'](false) : undefined;\n\n      if (paramValue != null) pathname += encodeURI(paramValue);\n    } else if (token === '(') {\n      parenCount += 1;\n    } else if (token === ')') {\n      parenCount -= 1;\n    } else if (token.charAt(0) === ':') {\n      paramName = token.substring(1);\n      paramValue = params[paramName];\n\n      !(paramValue != null || parenCount > 0) ? process.env.NODE_ENV !== 'production' ? _invariant2['default'](false, 'Missing \"%s\" parameter for path \"%s\"', paramName, pattern) : _invariant2['default'](false) : undefined;\n\n      if (paramValue != null) pathname += encodeURIComponent(paramValue);\n    } else {\n      pathname += token;\n    }\n  }\n\n  return pathname.replace(/\\/+/g, '/');\n}\n}).call(this,require('_process'))","deps":{"_process":"node_modules/process/browser.js","invariant":"node_modules/invariant/browser.js"}},{"id":"node_modules/react-router/lib/PropTypes.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nfunction _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj['default'] = obj; return newObj; } }\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _react = require('react');\n\nvar _deprecateObjectProperties = require('./deprecateObjectProperties');\n\nvar _deprecateObjectProperties2 = _interopRequireDefault(_deprecateObjectProperties);\n\nvar _InternalPropTypes = require('./InternalPropTypes');\n\nvar InternalPropTypes = _interopRequireWildcard(_InternalPropTypes);\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\nvar func = _react.PropTypes.func;\nvar object = _react.PropTypes.object;\nvar shape = _react.PropTypes.shape;\nvar string = _react.PropTypes.string;\nvar routerShape = shape({\n  push: func.isRequired,\n  replace: func.isRequired,\n  go: func.isRequired,\n  goBack: func.isRequired,\n  goForward: func.isRequired,\n  setRouteLeaveHook: func.isRequired,\n  isActive: func.isRequired\n});\n\nexports.routerShape = routerShape;\nvar locationShape = shape({\n  pathname: string.isRequired,\n  search: string.isRequired,\n  state: object,\n  action: string.isRequired,\n  key: string\n});\n\nexports.locationShape = locationShape;\n// Deprecated stuff below:\n\nvar falsy = InternalPropTypes.falsy;\nexports.falsy = falsy;\nvar history = InternalPropTypes.history;\nexports.history = history;\nvar location = locationShape;\nexports.location = location;\nvar component = InternalPropTypes.component;\nexports.component = component;\nvar components = InternalPropTypes.components;\nexports.components = components;\nvar route = InternalPropTypes.route;\nexports.route = route;\nvar routes = InternalPropTypes.routes;\nexports.routes = routes;\nvar router = routerShape;\n\nexports.router = router;\nif (process.env.NODE_ENV !== 'production') {\n  (function () {\n    var deprecatePropType = function deprecatePropType(propType, message) {\n      return function () {\n        process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, message) : undefined;\n        return propType.apply(undefined, arguments);\n      };\n    };\n\n    var deprecateInternalPropType = function deprecateInternalPropType(propType) {\n      return deprecatePropType(propType, 'This prop type is not intended for external use, and was previously exported by mistake. These internal prop types are deprecated for external use, and will be removed in a later version.');\n    };\n\n    var deprecateRenamedPropType = function deprecateRenamedPropType(propType, name) {\n      return deprecatePropType(propType, 'The `' + name + '` prop type is now exported as `' + name + 'Shape` to avoid name conflicts. This export is deprecated and will be removed in a later version.');\n    };\n\n    exports.falsy = falsy = deprecateInternalPropType(falsy);\n    exports.history = history = deprecateInternalPropType(history);\n    exports.component = component = deprecateInternalPropType(component);\n    exports.components = components = deprecateInternalPropType(components);\n    exports.route = route = deprecateInternalPropType(route);\n    exports.routes = routes = deprecateInternalPropType(routes);\n\n    exports.location = location = deprecateRenamedPropType(location, 'location');\n    exports.router = router = deprecateRenamedPropType(router, 'router');\n  })();\n}\n\nvar defaultExport = {\n  falsy: falsy,\n  history: history,\n  location: location,\n  component: component,\n  components: components,\n  route: route,\n  // For some reason, routes was never here.\n  router: router\n};\n\nif (process.env.NODE_ENV !== 'production') {\n  defaultExport = _deprecateObjectProperties2['default'](defaultExport, 'The default export from `react-router/lib/PropTypes` is deprecated. Please use the named exports instead.');\n}\n\nexports['default'] = defaultExport;\n}).call(this,require('_process'))","deps":{"./InternalPropTypes":"node_modules/react-router/lib/InternalPropTypes.js","./deprecateObjectProperties":"node_modules/react-router/lib/deprecateObjectProperties.js","./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js","react":"node_modules/react/react.js"}},{"id":"node_modules/react-router/lib/Redirect.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _react = require('react');\n\nvar _react2 = _interopRequireDefault(_react);\n\nvar _invariant = require('invariant');\n\nvar _invariant2 = _interopRequireDefault(_invariant);\n\nvar _RouteUtils = require('./RouteUtils');\n\nvar _PatternUtils = require('./PatternUtils');\n\nvar _InternalPropTypes = require('./InternalPropTypes');\n\nvar _React$PropTypes = _react2['default'].PropTypes;\nvar string = _React$PropTypes.string;\nvar object = _React$PropTypes.object;\n\n/**\n * A <Redirect> is used to declare another URL path a client should\n * be sent to when they request a given URL.\n *\n * Redirects are placed alongside routes in the route configuration\n * and are traversed in the same manner.\n */\nvar Redirect = _react2['default'].createClass({\n  displayName: 'Redirect',\n\n  statics: {\n\n    createRouteFromReactElement: function createRouteFromReactElement(element) {\n      var route = _RouteUtils.createRouteFromReactElement(element);\n\n      if (route.from) route.path = route.from;\n\n      route.onEnter = function (nextState, replace) {\n        var location = nextState.location;\n        var params = nextState.params;\n\n        var pathname = undefined;\n        if (route.to.charAt(0) === '/') {\n          pathname = _PatternUtils.formatPattern(route.to, params);\n        } else if (!route.to) {\n          pathname = location.pathname;\n        } else {\n          var routeIndex = nextState.routes.indexOf(route);\n          var parentPattern = Redirect.getRoutePattern(nextState.routes, routeIndex - 1);\n          var pattern = parentPattern.replace(/\\/*$/, '/') + route.to;\n          pathname = _PatternUtils.formatPattern(pattern, params);\n        }\n\n        replace({\n          pathname: pathname,\n          query: route.query || location.query,\n          state: route.state || location.state\n        });\n      };\n\n      return route;\n    },\n\n    getRoutePattern: function getRoutePattern(routes, routeIndex) {\n      var parentPattern = '';\n\n      for (var i = routeIndex; i >= 0; i--) {\n        var route = routes[i];\n        var pattern = route.path || '';\n\n        parentPattern = pattern.replace(/\\/*$/, '/') + parentPattern;\n\n        if (pattern.indexOf('/') === 0) break;\n      }\n\n      return '/' + parentPattern;\n    }\n\n  },\n\n  propTypes: {\n    path: string,\n    from: string, // Alias for path\n    to: string.isRequired,\n    query: object,\n    state: object,\n    onEnter: _InternalPropTypes.falsy,\n    children: _InternalPropTypes.falsy\n  },\n\n  /* istanbul ignore next: sanity check */\n  render: function render() {\n    !false ? process.env.NODE_ENV !== 'production' ? _invariant2['default'](false, '<Redirect> elements are for router configuration only and should not be rendered') : _invariant2['default'](false) : undefined;\n  }\n\n});\n\nexports['default'] = Redirect;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./InternalPropTypes":"node_modules/react-router/lib/InternalPropTypes.js","./PatternUtils":"node_modules/react-router/lib/PatternUtils.js","./RouteUtils":"node_modules/react-router/lib/RouteUtils.js","_process":"node_modules/process/browser.js","invariant":"node_modules/invariant/browser.js","react":"node_modules/react/react.js"}},{"id":"node_modules/react-router/lib/Route.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _react = require('react');\n\nvar _react2 = _interopRequireDefault(_react);\n\nvar _invariant = require('invariant');\n\nvar _invariant2 = _interopRequireDefault(_invariant);\n\nvar _RouteUtils = require('./RouteUtils');\n\nvar _InternalPropTypes = require('./InternalPropTypes');\n\nvar _React$PropTypes = _react2['default'].PropTypes;\nvar string = _React$PropTypes.string;\nvar func = _React$PropTypes.func;\n\n/**\n * A <Route> is used to declare which components are rendered to the\n * page when the URL matches a given pattern.\n *\n * Routes are arranged in a nested tree structure. When a new URL is\n * requested, the tree is searched depth-first to find a route whose\n * path matches the URL.  When one is found, all routes in the tree\n * that lead to it are considered \"active\" and their components are\n * rendered into the DOM, nested in the same order as in the tree.\n */\nvar Route = _react2['default'].createClass({\n  displayName: 'Route',\n\n  statics: {\n    createRouteFromReactElement: _RouteUtils.createRouteFromReactElement\n  },\n\n  propTypes: {\n    path: string,\n    component: _InternalPropTypes.component,\n    components: _InternalPropTypes.components,\n    getComponent: func,\n    getComponents: func\n  },\n\n  /* istanbul ignore next: sanity check */\n  render: function render() {\n    !false ? process.env.NODE_ENV !== 'production' ? _invariant2['default'](false, '<Route> elements are for router configuration only and should not be rendered') : _invariant2['default'](false) : undefined;\n  }\n\n});\n\nexports['default'] = Route;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./InternalPropTypes":"node_modules/react-router/lib/InternalPropTypes.js","./RouteUtils":"node_modules/react-router/lib/RouteUtils.js","_process":"node_modules/process/browser.js","invariant":"node_modules/invariant/browser.js","react":"node_modules/react/react.js"}},{"id":"node_modules/react-router/lib/RouteContext.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\nvar _react = require('react');\n\nvar _react2 = _interopRequireDefault(_react);\n\nvar object = _react2['default'].PropTypes.object;\n\n/**\n * The RouteContext mixin provides a convenient way for route\n * components to set the route in context. This is needed for\n * routes that render elements that want to use the Lifecycle\n * mixin to prevent transitions.\n */\nvar RouteContext = {\n\n  propTypes: {\n    route: object.isRequired\n  },\n\n  childContextTypes: {\n    route: object.isRequired\n  },\n\n  getChildContext: function getChildContext() {\n    return {\n      route: this.props.route\n    };\n  },\n\n  componentWillMount: function componentWillMount() {\n    process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, 'The `RouteContext` mixin is deprecated. You can provide `this.props.route` on context with your own `contextTypes`. http://tiny.cc/router-routecontextmixin') : undefined;\n  }\n\n};\n\nexports['default'] = RouteContext;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js","react":"node_modules/react/react.js"}},{"id":"node_modules/react-router/lib/RouteUtils.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nexports.isReactChildren = isReactChildren;\nexports.createRouteFromReactElement = createRouteFromReactElement;\nexports.createRoutesFromReactChildren = createRoutesFromReactChildren;\nexports.createRoutes = createRoutes;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _react = require('react');\n\nvar _react2 = _interopRequireDefault(_react);\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\nfunction isValidChild(object) {\n  return object == null || _react2['default'].isValidElement(object);\n}\n\nfunction isReactChildren(object) {\n  return isValidChild(object) || Array.isArray(object) && object.every(isValidChild);\n}\n\nfunction checkPropTypes(componentName, propTypes, props) {\n  componentName = componentName || 'UnknownComponent';\n\n  for (var propName in propTypes) {\n    if (Object.prototype.hasOwnProperty.call(propTypes, propName)) {\n      var error = propTypes[propName](props, propName, componentName);\n\n      /* istanbul ignore if: error logging */\n      if (error instanceof Error) process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, error.message) : undefined;\n    }\n  }\n}\n\nfunction createRoute(defaultProps, props) {\n  return _extends({}, defaultProps, props);\n}\n\nfunction createRouteFromReactElement(element) {\n  var type = element.type;\n  var route = createRoute(type.defaultProps, element.props);\n\n  if (type.propTypes) checkPropTypes(type.displayName || type.name, type.propTypes, route);\n\n  if (route.children) {\n    var childRoutes = createRoutesFromReactChildren(route.children, route);\n\n    if (childRoutes.length) route.childRoutes = childRoutes;\n\n    delete route.children;\n  }\n\n  return route;\n}\n\n/**\n * Creates and returns a routes object from the given ReactChildren. JSX\n * provides a convenient way to visualize how routes in the hierarchy are\n * nested.\n *\n *   import { Route, createRoutesFromReactChildren } from 'react-router'\n *   \n *   const routes = createRoutesFromReactChildren(\n *     <Route component={App}>\n *       <Route path=\"home\" component={Dashboard}/>\n *       <Route path=\"news\" component={NewsFeed}/>\n *     </Route>\n *   )\n *\n * Note: This method is automatically used when you provide <Route> children\n * to a <Router> component.\n */\n\nfunction createRoutesFromReactChildren(children, parentRoute) {\n  var routes = [];\n\n  _react2['default'].Children.forEach(children, function (element) {\n    if (_react2['default'].isValidElement(element)) {\n      // Component classes may have a static create* method.\n      if (element.type.createRouteFromReactElement) {\n        var route = element.type.createRouteFromReactElement(element, parentRoute);\n\n        if (route) routes.push(route);\n      } else {\n        routes.push(createRouteFromReactElement(element));\n      }\n    }\n  });\n\n  return routes;\n}\n\n/**\n * Creates and returns an array of routes from the given object which\n * may be a JSX route, a plain object route, or an array of either.\n */\n\nfunction createRoutes(routes) {\n  if (isReactChildren(routes)) {\n    routes = createRoutesFromReactChildren(routes);\n  } else if (routes && !Array.isArray(routes)) {\n    routes = [routes];\n  }\n\n  return routes;\n}\n}).call(this,require('_process'))","deps":{"./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js","react":"node_modules/react/react.js"}},{"id":"node_modules/react-router/lib/Router.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nfunction _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }\n\nvar _historyLibCreateHashHistory = require('history/lib/createHashHistory');\n\nvar _historyLibCreateHashHistory2 = _interopRequireDefault(_historyLibCreateHashHistory);\n\nvar _historyLibUseQueries = require('history/lib/useQueries');\n\nvar _historyLibUseQueries2 = _interopRequireDefault(_historyLibUseQueries);\n\nvar _react = require('react');\n\nvar _react2 = _interopRequireDefault(_react);\n\nvar _createTransitionManager = require('./createTransitionManager');\n\nvar _createTransitionManager2 = _interopRequireDefault(_createTransitionManager);\n\nvar _InternalPropTypes = require('./InternalPropTypes');\n\nvar _RouterContext = require('./RouterContext');\n\nvar _RouterContext2 = _interopRequireDefault(_RouterContext);\n\nvar _RouteUtils = require('./RouteUtils');\n\nvar _RouterUtils = require('./RouterUtils');\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\nfunction isDeprecatedHistory(history) {\n  return !history || !history.__v2_compatible__;\n}\n\nvar _React$PropTypes = _react2['default'].PropTypes;\nvar func = _React$PropTypes.func;\nvar object = _React$PropTypes.object;\n\n/**\n * A <Router> is a high-level API for automatically setting up\n * a router that renders a <RouterContext> with all the props\n * it needs each time the URL changes.\n */\nvar Router = _react2['default'].createClass({\n  displayName: 'Router',\n\n  propTypes: {\n    history: object,\n    children: _InternalPropTypes.routes,\n    routes: _InternalPropTypes.routes, // alias for children\n    render: func,\n    createElement: func,\n    onError: func,\n    onUpdate: func,\n\n    // PRIVATE: For client-side rehydration of server match.\n    matchContext: object\n  },\n\n  getDefaultProps: function getDefaultProps() {\n    return {\n      render: function render(props) {\n        return _react2['default'].createElement(_RouterContext2['default'], props);\n      }\n    };\n  },\n\n  getInitialState: function getInitialState() {\n    return {\n      location: null,\n      routes: null,\n      params: null,\n      components: null\n    };\n  },\n\n  handleError: function handleError(error) {\n    if (this.props.onError) {\n      this.props.onError.call(this, error);\n    } else {\n      // Throw errors by default so we don't silently swallow them!\n      throw error; // This error probably occurred in getChildRoutes or getComponents.\n    }\n  },\n\n  componentWillMount: function componentWillMount() {\n    var _this = this;\n\n    var _props = this.props;\n    var parseQueryString = _props.parseQueryString;\n    var stringifyQuery = _props.stringifyQuery;\n\n    process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](!(parseQueryString || stringifyQuery), '`parseQueryString` and `stringifyQuery` are deprecated. Please create a custom history. http://tiny.cc/router-customquerystring') : undefined;\n\n    var _createRouterObjects = this.createRouterObjects();\n\n    var history = _createRouterObjects.history;\n    var transitionManager = _createRouterObjects.transitionManager;\n    var router = _createRouterObjects.router;\n\n    this._unlisten = transitionManager.listen(function (error, state) {\n      if (error) {\n        _this.handleError(error);\n      } else {\n        _this.setState(state, _this.props.onUpdate);\n      }\n    });\n\n    this.history = history;\n    this.router = router;\n  },\n\n  createRouterObjects: function createRouterObjects() {\n    var matchContext = this.props.matchContext;\n\n    if (matchContext) {\n      return matchContext;\n    }\n\n    var history = this.props.history;\n    var _props2 = this.props;\n    var routes = _props2.routes;\n    var children = _props2.children;\n\n    if (isDeprecatedHistory(history)) {\n      history = this.wrapDeprecatedHistory(history);\n    }\n\n    var transitionManager = _createTransitionManager2['default'](history, _RouteUtils.createRoutes(routes || children));\n    var router = _RouterUtils.createRouterObject(history, transitionManager);\n    var routingHistory = _RouterUtils.createRoutingHistory(history, transitionManager);\n\n    return { history: routingHistory, transitionManager: transitionManager, router: router };\n  },\n\n  wrapDeprecatedHistory: function wrapDeprecatedHistory(history) {\n    var _props3 = this.props;\n    var parseQueryString = _props3.parseQueryString;\n    var stringifyQuery = _props3.stringifyQuery;\n\n    var createHistory = undefined;\n    if (history) {\n      process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, 'It appears you have provided a deprecated history object to `<Router/>`, please use a history provided by ' + 'React Router with `import { browserHistory } from \\'react-router\\'` or `import { hashHistory } from \\'react-router\\'`. ' + 'If you are using a custom history please create it with `useRouterHistory`, see http://tiny.cc/router-usinghistory for details.') : undefined;\n      createHistory = function () {\n        return history;\n      };\n    } else {\n      process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, '`Router` no longer defaults the history prop to hash history. Please use the `hashHistory` singleton instead. http://tiny.cc/router-defaulthistory') : undefined;\n      createHistory = _historyLibCreateHashHistory2['default'];\n    }\n\n    return _historyLibUseQueries2['default'](createHistory)({ parseQueryString: parseQueryString, stringifyQuery: stringifyQuery });\n  },\n\n  /* istanbul ignore next: sanity check */\n  componentWillReceiveProps: function componentWillReceiveProps(nextProps) {\n    process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](nextProps.history === this.props.history, 'You cannot change <Router history>; it will be ignored') : undefined;\n\n    process.env.NODE_ENV !== 'production' ? _routerWarning2['default']((nextProps.routes || nextProps.children) === (this.props.routes || this.props.children), 'You cannot change <Router routes>; it will be ignored') : undefined;\n  },\n\n  componentWillUnmount: function componentWillUnmount() {\n    if (this._unlisten) this._unlisten();\n  },\n\n  render: function render() {\n    var _state = this.state;\n    var location = _state.location;\n    var routes = _state.routes;\n    var params = _state.params;\n    var components = _state.components;\n    var _props4 = this.props;\n    var createElement = _props4.createElement;\n    var render = _props4.render;\n\n    var props = _objectWithoutProperties(_props4, ['createElement', 'render']);\n\n    if (location == null) return null; // Async match\n\n    // Only forward non-Router-specific props to routing context, as those are\n    // the only ones that might be custom routing context props.\n    Object.keys(Router.propTypes).forEach(function (propType) {\n      return delete props[propType];\n    });\n\n    return render(_extends({}, props, {\n      history: this.history,\n      router: this.router,\n      location: location,\n      routes: routes,\n      params: params,\n      components: components,\n      createElement: createElement\n    }));\n  }\n\n});\n\nexports['default'] = Router;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./InternalPropTypes":"node_modules/react-router/lib/InternalPropTypes.js","./RouteUtils":"node_modules/react-router/lib/RouteUtils.js","./RouterContext":"node_modules/react-router/lib/RouterContext.js","./RouterUtils":"node_modules/react-router/lib/RouterUtils.js","./createTransitionManager":"node_modules/react-router/lib/createTransitionManager.js","./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js","history/lib/createHashHistory":"node_modules/history/lib/createHashHistory.js","history/lib/useQueries":"node_modules/history/lib/useQueries.js","react":"node_modules/react/react.js"}},{"id":"node_modules/react-router/lib/RouterContext.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _invariant = require('invariant');\n\nvar _invariant2 = _interopRequireDefault(_invariant);\n\nvar _react = require('react');\n\nvar _react2 = _interopRequireDefault(_react);\n\nvar _deprecateObjectProperties = require('./deprecateObjectProperties');\n\nvar _deprecateObjectProperties2 = _interopRequireDefault(_deprecateObjectProperties);\n\nvar _getRouteParams = require('./getRouteParams');\n\nvar _getRouteParams2 = _interopRequireDefault(_getRouteParams);\n\nvar _RouteUtils = require('./RouteUtils');\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\nvar _React$PropTypes = _react2['default'].PropTypes;\nvar array = _React$PropTypes.array;\nvar func = _React$PropTypes.func;\nvar object = _React$PropTypes.object;\n\n/**\n * A <RouterContext> renders the component tree for a given router state\n * and sets the history object and the current location in context.\n */\nvar RouterContext = _react2['default'].createClass({\n  displayName: 'RouterContext',\n\n  propTypes: {\n    history: object,\n    router: object.isRequired,\n    location: object.isRequired,\n    routes: array.isRequired,\n    params: object.isRequired,\n    components: array.isRequired,\n    createElement: func.isRequired\n  },\n\n  getDefaultProps: function getDefaultProps() {\n    return {\n      createElement: _react2['default'].createElement\n    };\n  },\n\n  childContextTypes: {\n    history: object,\n    location: object.isRequired,\n    router: object.isRequired\n  },\n\n  getChildContext: function getChildContext() {\n    var _props = this.props;\n    var router = _props.router;\n    var history = _props.history;\n    var location = _props.location;\n\n    if (!router) {\n      process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, '`<RouterContext>` expects a `router` rather than a `history`') : undefined;\n\n      router = _extends({}, history, {\n        setRouteLeaveHook: history.listenBeforeLeavingRoute\n      });\n      delete router.listenBeforeLeavingRoute;\n    }\n\n    if (process.env.NODE_ENV !== 'production') {\n      location = _deprecateObjectProperties2['default'](location, '`context.location` is deprecated, please use a route component\\'s `props.location` instead. http://tiny.cc/router-accessinglocation');\n    }\n\n    return { history: history, location: location, router: router };\n  },\n\n  createElement: function createElement(component, props) {\n    return component == null ? null : this.props.createElement(component, props);\n  },\n\n  render: function render() {\n    var _this = this;\n\n    var _props2 = this.props;\n    var history = _props2.history;\n    var location = _props2.location;\n    var routes = _props2.routes;\n    var params = _props2.params;\n    var components = _props2.components;\n\n    var element = null;\n\n    if (components) {\n      element = components.reduceRight(function (element, components, index) {\n        if (components == null) return element; // Don't create new children; use the grandchildren.\n\n        var route = routes[index];\n        var routeParams = _getRouteParams2['default'](route, params);\n        var props = {\n          history: history,\n          location: location,\n          params: params,\n          route: route,\n          routeParams: routeParams,\n          routes: routes\n        };\n\n        if (_RouteUtils.isReactChildren(element)) {\n          props.children = element;\n        } else if (element) {\n          for (var prop in element) {\n            if (Object.prototype.hasOwnProperty.call(element, prop)) props[prop] = element[prop];\n          }\n        }\n\n        if (typeof components === 'object') {\n          var elements = {};\n\n          for (var key in components) {\n            if (Object.prototype.hasOwnProperty.call(components, key)) {\n              // Pass through the key as a prop to createElement to allow\n              // custom createElement functions to know which named component\n              // they're rendering, for e.g. matching up to fetched data.\n              elements[key] = _this.createElement(components[key], _extends({\n                key: key }, props));\n            }\n          }\n\n          return elements;\n        }\n\n        return _this.createElement(components, props);\n      }, element);\n    }\n\n    !(element === null || element === false || _react2['default'].isValidElement(element)) ? process.env.NODE_ENV !== 'production' ? _invariant2['default'](false, 'The root route must render a single element') : _invariant2['default'](false) : undefined;\n\n    return element;\n  }\n\n});\n\nexports['default'] = RouterContext;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./RouteUtils":"node_modules/react-router/lib/RouteUtils.js","./deprecateObjectProperties":"node_modules/react-router/lib/deprecateObjectProperties.js","./getRouteParams":"node_modules/react-router/lib/getRouteParams.js","./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js","invariant":"node_modules/invariant/browser.js","react":"node_modules/react/react.js"}},{"id":"node_modules/react-router/lib/RouterUtils.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nexports.createRouterObject = createRouterObject;\nexports.createRoutingHistory = createRoutingHistory;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _deprecateObjectProperties = require('./deprecateObjectProperties');\n\nvar _deprecateObjectProperties2 = _interopRequireDefault(_deprecateObjectProperties);\n\nfunction createRouterObject(history, transitionManager) {\n  return _extends({}, history, {\n    setRouteLeaveHook: transitionManager.listenBeforeLeavingRoute,\n    isActive: transitionManager.isActive\n  });\n}\n\n// deprecated\n\nfunction createRoutingHistory(history, transitionManager) {\n  history = _extends({}, history, transitionManager);\n\n  if (process.env.NODE_ENV !== 'production') {\n    history = _deprecateObjectProperties2['default'](history, '`props.history` and `context.history` are deprecated. Please use `context.router`. http://tiny.cc/router-contextchanges');\n  }\n\n  return history;\n}\n}).call(this,require('_process'))","deps":{"./deprecateObjectProperties":"node_modules/react-router/lib/deprecateObjectProperties.js","_process":"node_modules/process/browser.js"}},{"id":"node_modules/react-router/lib/RoutingContext.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _react = require('react');\n\nvar _react2 = _interopRequireDefault(_react);\n\nvar _RouterContext = require('./RouterContext');\n\nvar _RouterContext2 = _interopRequireDefault(_RouterContext);\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\nvar RoutingContext = _react2['default'].createClass({\n  displayName: 'RoutingContext',\n\n  componentWillMount: function componentWillMount() {\n    process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, '`RoutingContext` has been renamed to `RouterContext`. Please use `import { RouterContext } from \\'react-router\\'`. http://tiny.cc/router-routercontext') : undefined;\n  },\n\n  render: function render() {\n    return _react2['default'].createElement(_RouterContext2['default'], this.props);\n  }\n});\n\nexports['default'] = RoutingContext;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./RouterContext":"node_modules/react-router/lib/RouterContext.js","./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js","react":"node_modules/react/react.js"}},{"id":"node_modules/react-router/lib/TransitionUtils.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\nexports.runEnterHooks = runEnterHooks;\nexports.runChangeHooks = runChangeHooks;\nexports.runLeaveHooks = runLeaveHooks;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _AsyncUtils = require('./AsyncUtils');\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\nfunction createTransitionHook(hook, route, asyncArity) {\n  return function () {\n    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {\n      args[_key] = arguments[_key];\n    }\n\n    hook.apply(route, args);\n\n    if (hook.length < asyncArity) {\n      var callback = args[args.length - 1];\n      // Assume hook executes synchronously and\n      // automatically call the callback.\n      callback();\n    }\n  };\n}\n\nfunction getEnterHooks(routes) {\n  return routes.reduce(function (hooks, route) {\n    if (route.onEnter) hooks.push(createTransitionHook(route.onEnter, route, 3));\n\n    return hooks;\n  }, []);\n}\n\nfunction getChangeHooks(routes) {\n  return routes.reduce(function (hooks, route) {\n    if (route.onChange) hooks.push(createTransitionHook(route.onChange, route, 4));\n    return hooks;\n  }, []);\n}\n\nfunction runTransitionHooks(length, iter, callback) {\n  if (!length) {\n    callback();\n    return;\n  }\n\n  var redirectInfo = undefined;\n  function replace(location, deprecatedPathname, deprecatedQuery) {\n    if (deprecatedPathname) {\n      process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, '`replaceState(state, pathname, query) is deprecated; use `replace(location)` with a location descriptor instead. http://tiny.cc/router-isActivedeprecated') : undefined;\n      redirectInfo = {\n        pathname: deprecatedPathname,\n        query: deprecatedQuery,\n        state: location\n      };\n\n      return;\n    }\n\n    redirectInfo = location;\n  }\n\n  _AsyncUtils.loopAsync(length, function (index, next, done) {\n    iter(index, replace, function (error) {\n      if (error || redirectInfo) {\n        done(error, redirectInfo); // No need to continue.\n      } else {\n          next();\n        }\n    });\n  }, callback);\n}\n\n/**\n * Runs all onEnter hooks in the given array of routes in order\n * with onEnter(nextState, replace, callback) and calls\n * callback(error, redirectInfo) when finished. The first hook\n * to use replace short-circuits the loop.\n *\n * If a hook needs to run asynchronously, it may use the callback\n * function. However, doing so will cause the transition to pause,\n * which could lead to a non-responsive UI if the hook is slow.\n */\n\nfunction runEnterHooks(routes, nextState, callback) {\n  var hooks = getEnterHooks(routes);\n  return runTransitionHooks(hooks.length, function (index, replace, next) {\n    hooks[index](nextState, replace, next);\n  }, callback);\n}\n\n/**\n * Runs all onChange hooks in the given array of routes in order\n * with onChange(prevState, nextState, replace, callback) and calls\n * callback(error, redirectInfo) when finished. The first hook\n * to use replace short-circuits the loop.\n *\n * If a hook needs to run asynchronously, it may use the callback\n * function. However, doing so will cause the transition to pause,\n * which could lead to a non-responsive UI if the hook is slow.\n */\n\nfunction runChangeHooks(routes, state, nextState, callback) {\n  var hooks = getChangeHooks(routes);\n  return runTransitionHooks(hooks.length, function (index, replace, next) {\n    hooks[index](state, nextState, replace, next);\n  }, callback);\n}\n\n/**\n * Runs all onLeave hooks in the given array of routes in order.\n */\n\nfunction runLeaveHooks(routes) {\n  for (var i = 0, len = routes.length; i < len; ++i) {\n    if (routes[i].onLeave) routes[i].onLeave.call(routes[i]);\n  }\n}\n}).call(this,require('_process'))","deps":{"./AsyncUtils":"node_modules/react-router/lib/AsyncUtils.js","./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js"}},{"id":"node_modules/react-router/lib/applyRouterMiddleware.js","source":"'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _react = require('react');\n\nvar _react2 = _interopRequireDefault(_react);\n\nvar _RouterContext = require('./RouterContext');\n\nvar _RouterContext2 = _interopRequireDefault(_RouterContext);\n\nexports['default'] = function () {\n  for (var _len = arguments.length, middlewares = Array(_len), _key = 0; _key < _len; _key++) {\n    middlewares[_key] = arguments[_key];\n  }\n\n  var withContext = middlewares.map(function (m) {\n    return m.renderRouterContext;\n  }).filter(function (f) {\n    return f;\n  });\n  var withComponent = middlewares.map(function (m) {\n    return m.renderRouteComponent;\n  }).filter(function (f) {\n    return f;\n  });\n  var makeCreateElement = function makeCreateElement() {\n    var baseCreateElement = arguments.length <= 0 || arguments[0] === undefined ? _react.createElement : arguments[0];\n    return function (Component, props) {\n      return withComponent.reduceRight(function (previous, renderRouteComponent) {\n        return renderRouteComponent(previous, props);\n      }, baseCreateElement(Component, props));\n    };\n  };\n\n  return function (renderProps) {\n    return withContext.reduceRight(function (previous, renderRouterContext) {\n      return renderRouterContext(previous, renderProps);\n    }, _react2['default'].createElement(_RouterContext2['default'], _extends({}, renderProps, {\n      createElement: makeCreateElement(renderProps.createElement)\n    })));\n  };\n};\n\nmodule.exports = exports['default'];","deps":{"./RouterContext":"node_modules/react-router/lib/RouterContext.js","react":"node_modules/react/react.js"}},{"id":"node_modules/react-router/lib/browserHistory.js","source":"'use strict';\n\nexports.__esModule = true;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _historyLibCreateBrowserHistory = require('history/lib/createBrowserHistory');\n\nvar _historyLibCreateBrowserHistory2 = _interopRequireDefault(_historyLibCreateBrowserHistory);\n\nvar _createRouterHistory = require('./createRouterHistory');\n\nvar _createRouterHistory2 = _interopRequireDefault(_createRouterHistory);\n\nexports['default'] = _createRouterHistory2['default'](_historyLibCreateBrowserHistory2['default']);\nmodule.exports = exports['default'];","deps":{"./createRouterHistory":"node_modules/react-router/lib/createRouterHistory.js","history/lib/createBrowserHistory":"node_modules/history/lib/createBrowserHistory.js"}},{"id":"node_modules/react-router/lib/computeChangedRoutes.js","source":"'use strict';\n\nexports.__esModule = true;\n\nvar _PatternUtils = require('./PatternUtils');\n\nfunction routeParamsChanged(route, prevState, nextState) {\n  if (!route.path) return false;\n\n  var paramNames = _PatternUtils.getParamNames(route.path);\n\n  return paramNames.some(function (paramName) {\n    return prevState.params[paramName] !== nextState.params[paramName];\n  });\n}\n\n/**\n * Returns an object of { leaveRoutes, changeRoutes, enterRoutes } determined by\n * the change from prevState to nextState. We leave routes if either\n * 1) they are not in the next state or 2) they are in the next state\n * but their params have changed (i.e. /users/123 => /users/456).\n *\n * leaveRoutes are ordered starting at the leaf route of the tree\n * we're leaving up to the common parent route. enterRoutes are ordered\n * from the top of the tree we're entering down to the leaf route.\n *\n * changeRoutes are any routes that didn't leave or enter during\n * the transition.\n */\nfunction computeChangedRoutes(prevState, nextState) {\n  var prevRoutes = prevState && prevState.routes;\n  var nextRoutes = nextState.routes;\n\n  var leaveRoutes = undefined,\n      changeRoutes = undefined,\n      enterRoutes = undefined;\n  if (prevRoutes) {\n    (function () {\n      var parentIsLeaving = false;\n      leaveRoutes = prevRoutes.filter(function (route) {\n        if (parentIsLeaving) {\n          return true;\n        } else {\n          var isLeaving = nextRoutes.indexOf(route) === -1 || routeParamsChanged(route, prevState, nextState);\n          if (isLeaving) parentIsLeaving = true;\n          return isLeaving;\n        }\n      });\n\n      // onLeave hooks start at the leaf route.\n      leaveRoutes.reverse();\n\n      enterRoutes = [];\n      changeRoutes = [];\n\n      nextRoutes.forEach(function (route) {\n        var isNew = prevRoutes.indexOf(route) === -1;\n        var paramsChanged = leaveRoutes.indexOf(route) !== -1;\n\n        if (isNew || paramsChanged) enterRoutes.push(route);else changeRoutes.push(route);\n      });\n    })();\n  } else {\n    leaveRoutes = [];\n    changeRoutes = [];\n    enterRoutes = nextRoutes;\n  }\n\n  return {\n    leaveRoutes: leaveRoutes,\n    changeRoutes: changeRoutes,\n    enterRoutes: enterRoutes\n  };\n}\n\nexports['default'] = computeChangedRoutes;\nmodule.exports = exports['default'];","deps":{"./PatternUtils":"node_modules/react-router/lib/PatternUtils.js"}},{"id":"node_modules/react-router/lib/createMemoryHistory.js","source":"'use strict';\n\nexports.__esModule = true;\nexports['default'] = createMemoryHistory;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _historyLibUseQueries = require('history/lib/useQueries');\n\nvar _historyLibUseQueries2 = _interopRequireDefault(_historyLibUseQueries);\n\nvar _historyLibUseBasename = require('history/lib/useBasename');\n\nvar _historyLibUseBasename2 = _interopRequireDefault(_historyLibUseBasename);\n\nvar _historyLibCreateMemoryHistory = require('history/lib/createMemoryHistory');\n\nvar _historyLibCreateMemoryHistory2 = _interopRequireDefault(_historyLibCreateMemoryHistory);\n\nfunction createMemoryHistory(options) {\n  // signatures and type checking differ between `useRoutes` and\n  // `createMemoryHistory`, have to create `memoryHistory` first because\n  // `useQueries` doesn't understand the signature\n  var memoryHistory = _historyLibCreateMemoryHistory2['default'](options);\n  var createHistory = function createHistory() {\n    return memoryHistory;\n  };\n  var history = _historyLibUseQueries2['default'](_historyLibUseBasename2['default'](createHistory))(options);\n  history.__v2_compatible__ = true;\n  return history;\n}\n\nmodule.exports = exports['default'];","deps":{"history/lib/createMemoryHistory":"node_modules/history/lib/createMemoryHistory.js","history/lib/useBasename":"node_modules/history/lib/useBasename.js","history/lib/useQueries":"node_modules/history/lib/useQueries.js"}},{"id":"node_modules/react-router/lib/createRouterHistory.js","source":"'use strict';\n\nexports.__esModule = true;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _useRouterHistory = require('./useRouterHistory');\n\nvar _useRouterHistory2 = _interopRequireDefault(_useRouterHistory);\n\nvar canUseDOM = !!(typeof window !== 'undefined' && window.document && window.document.createElement);\n\nexports['default'] = function (createHistory) {\n  var history = undefined;\n  if (canUseDOM) history = _useRouterHistory2['default'](createHistory)();\n  return history;\n};\n\nmodule.exports = exports['default'];","deps":{"./useRouterHistory":"node_modules/react-router/lib/useRouterHistory.js"}},{"id":"node_modules/react-router/lib/createTransitionManager.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nexports['default'] = createTransitionManager;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\nvar _historyLibActions = require('history/lib/Actions');\n\nvar _computeChangedRoutes2 = require('./computeChangedRoutes');\n\nvar _computeChangedRoutes3 = _interopRequireDefault(_computeChangedRoutes2);\n\nvar _TransitionUtils = require('./TransitionUtils');\n\nvar _isActive2 = require('./isActive');\n\nvar _isActive3 = _interopRequireDefault(_isActive2);\n\nvar _getComponents = require('./getComponents');\n\nvar _getComponents2 = _interopRequireDefault(_getComponents);\n\nvar _matchRoutes = require('./matchRoutes');\n\nvar _matchRoutes2 = _interopRequireDefault(_matchRoutes);\n\nfunction hasAnyProperties(object) {\n  for (var p in object) {\n    if (Object.prototype.hasOwnProperty.call(object, p)) return true;\n  }return false;\n}\n\nfunction createTransitionManager(history, routes) {\n  var state = {};\n\n  // Signature should be (location, indexOnly), but needs to support (path,\n  // query, indexOnly)\n  function isActive(location) {\n    var indexOnlyOrDeprecatedQuery = arguments.length <= 1 || arguments[1] === undefined ? false : arguments[1];\n    var deprecatedIndexOnly = arguments.length <= 2 || arguments[2] === undefined ? null : arguments[2];\n\n    var indexOnly = undefined;\n    if (indexOnlyOrDeprecatedQuery && indexOnlyOrDeprecatedQuery !== true || deprecatedIndexOnly !== null) {\n      process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, '`isActive(pathname, query, indexOnly) is deprecated; use `isActive(location, indexOnly)` with a location descriptor instead. http://tiny.cc/router-isActivedeprecated') : undefined;\n      location = { pathname: location, query: indexOnlyOrDeprecatedQuery };\n      indexOnly = deprecatedIndexOnly || false;\n    } else {\n      location = history.createLocation(location);\n      indexOnly = indexOnlyOrDeprecatedQuery;\n    }\n\n    return _isActive3['default'](location, indexOnly, state.location, state.routes, state.params);\n  }\n\n  function createLocationFromRedirectInfo(location) {\n    return history.createLocation(location, _historyLibActions.REPLACE);\n  }\n\n  var partialNextState = undefined;\n\n  function match(location, callback) {\n    if (partialNextState && partialNextState.location === location) {\n      // Continue from where we left off.\n      finishMatch(partialNextState, callback);\n    } else {\n      _matchRoutes2['default'](routes, location, function (error, nextState) {\n        if (error) {\n          callback(error);\n        } else if (nextState) {\n          finishMatch(_extends({}, nextState, { location: location }), callback);\n        } else {\n          callback();\n        }\n      });\n    }\n  }\n\n  function finishMatch(nextState, callback) {\n    var _computeChangedRoutes = _computeChangedRoutes3['default'](state, nextState);\n\n    var leaveRoutes = _computeChangedRoutes.leaveRoutes;\n    var changeRoutes = _computeChangedRoutes.changeRoutes;\n    var enterRoutes = _computeChangedRoutes.enterRoutes;\n\n    _TransitionUtils.runLeaveHooks(leaveRoutes);\n\n    // Tear down confirmation hooks for left routes\n    leaveRoutes.filter(function (route) {\n      return enterRoutes.indexOf(route) === -1;\n    }).forEach(removeListenBeforeHooksForRoute);\n\n    // change and enter hooks are run in series\n    _TransitionUtils.runChangeHooks(changeRoutes, state, nextState, function (error, redirectInfo) {\n      if (error || redirectInfo) return handleErrorOrRedirect(error, redirectInfo);\n\n      _TransitionUtils.runEnterHooks(enterRoutes, nextState, finishEnterHooks);\n    });\n\n    function finishEnterHooks(error, redirectInfo) {\n      if (error || redirectInfo) return handleErrorOrRedirect(error, redirectInfo);\n\n      // TODO: Fetch components after state is updated.\n      _getComponents2['default'](nextState, function (error, components) {\n        if (error) {\n          callback(error);\n        } else {\n          // TODO: Make match a pure function and have some other API\n          // for \"match and update state\".\n          callback(null, null, state = _extends({}, nextState, { components: components }));\n        }\n      });\n    }\n\n    function handleErrorOrRedirect(error, redirectInfo) {\n      if (error) callback(error);else callback(null, createLocationFromRedirectInfo(redirectInfo));\n    }\n  }\n\n  var RouteGuid = 1;\n\n  function getRouteID(route) {\n    var create = arguments.length <= 1 || arguments[1] === undefined ? true : arguments[1];\n\n    return route.__id__ || create && (route.__id__ = RouteGuid++);\n  }\n\n  var RouteHooks = Object.create(null);\n\n  function getRouteHooksForRoutes(routes) {\n    return routes.reduce(function (hooks, route) {\n      hooks.push.apply(hooks, RouteHooks[getRouteID(route)]);\n      return hooks;\n    }, []);\n  }\n\n  function transitionHook(location, callback) {\n    _matchRoutes2['default'](routes, location, function (error, nextState) {\n      if (nextState == null) {\n        // TODO: We didn't actually match anything, but hang\n        // onto error/nextState so we don't have to matchRoutes\n        // again in the listen callback.\n        callback();\n        return;\n      }\n\n      // Cache some state here so we don't have to\n      // matchRoutes() again in the listen callback.\n      partialNextState = _extends({}, nextState, { location: location });\n\n      var hooks = getRouteHooksForRoutes(_computeChangedRoutes3['default'](state, partialNextState).leaveRoutes);\n\n      var result = undefined;\n      for (var i = 0, len = hooks.length; result == null && i < len; ++i) {\n        // Passing the location arg here indicates to\n        // the user that this is a transition hook.\n        result = hooks[i](location);\n      }\n\n      callback(result);\n    });\n  }\n\n  /* istanbul ignore next: untestable with Karma */\n  function beforeUnloadHook() {\n    // Synchronously check to see if any route hooks want\n    // to prevent the current window/tab from closing.\n    if (state.routes) {\n      var hooks = getRouteHooksForRoutes(state.routes);\n\n      var message = undefined;\n      for (var i = 0, len = hooks.length; typeof message !== 'string' && i < len; ++i) {\n        // Passing no args indicates to the user that this is a\n        // beforeunload hook. We don't know the next location.\n        message = hooks[i]();\n      }\n\n      return message;\n    }\n  }\n\n  var unlistenBefore = undefined,\n      unlistenBeforeUnload = undefined;\n\n  function removeListenBeforeHooksForRoute(route) {\n    var routeID = getRouteID(route, false);\n    if (!routeID) {\n      return;\n    }\n\n    delete RouteHooks[routeID];\n\n    if (!hasAnyProperties(RouteHooks)) {\n      // teardown transition & beforeunload hooks\n      if (unlistenBefore) {\n        unlistenBefore();\n        unlistenBefore = null;\n      }\n\n      if (unlistenBeforeUnload) {\n        unlistenBeforeUnload();\n        unlistenBeforeUnload = null;\n      }\n    }\n  }\n\n  /**\n   * Registers the given hook function to run before leaving the given route.\n   *\n   * During a normal transition, the hook function receives the next location\n   * as its only argument and must return either a) a prompt message to show\n   * the user, to make sure they want to leave the page or b) false, to prevent\n   * the transition.\n   *\n   * During the beforeunload event (in browsers) the hook receives no arguments.\n   * In this case it must return a prompt message to prevent the transition.\n   *\n   * Returns a function that may be used to unbind the listener.\n   */\n  function listenBeforeLeavingRoute(route, hook) {\n    // TODO: Warn if they register for a route that isn't currently\n    // active. They're probably doing something wrong, like re-creating\n    // route objects on every location change.\n    var routeID = getRouteID(route);\n    var hooks = RouteHooks[routeID];\n\n    if (!hooks) {\n      var thereWereNoRouteHooks = !hasAnyProperties(RouteHooks);\n\n      RouteHooks[routeID] = [hook];\n\n      if (thereWereNoRouteHooks) {\n        // setup transition & beforeunload hooks\n        unlistenBefore = history.listenBefore(transitionHook);\n\n        if (history.listenBeforeUnload) unlistenBeforeUnload = history.listenBeforeUnload(beforeUnloadHook);\n      }\n    } else {\n      if (hooks.indexOf(hook) === -1) {\n        process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, 'adding multiple leave hooks for the same route is deprecated; manage multiple confirmations in your own code instead') : undefined;\n\n        hooks.push(hook);\n      }\n    }\n\n    return function () {\n      var hooks = RouteHooks[routeID];\n\n      if (hooks) {\n        var newHooks = hooks.filter(function (item) {\n          return item !== hook;\n        });\n\n        if (newHooks.length === 0) {\n          removeListenBeforeHooksForRoute(route);\n        } else {\n          RouteHooks[routeID] = newHooks;\n        }\n      }\n    };\n  }\n\n  /**\n   * This is the API for stateful environments. As the location\n   * changes, we update state and call the listener. We can also\n   * gracefully handle errors and redirects.\n   */\n  function listen(listener) {\n    // TODO: Only use a single history listener. Otherwise we'll\n    // end up with multiple concurrent calls to match.\n    return history.listen(function (location) {\n      if (state.location === location) {\n        listener(null, state);\n      } else {\n        match(location, function (error, redirectLocation, nextState) {\n          if (error) {\n            listener(error);\n          } else if (redirectLocation) {\n            history.transitionTo(redirectLocation);\n          } else if (nextState) {\n            listener(null, nextState);\n          } else {\n            process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, 'Location \"%s\" did not match any routes', location.pathname + location.search + location.hash) : undefined;\n          }\n        });\n      }\n    });\n  }\n\n  return {\n    isActive: isActive,\n    match: match,\n    listenBeforeLeavingRoute: listenBeforeLeavingRoute,\n    listen: listen\n  };\n}\n\n//export default useRoutes\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./TransitionUtils":"node_modules/react-router/lib/TransitionUtils.js","./computeChangedRoutes":"node_modules/react-router/lib/computeChangedRoutes.js","./getComponents":"node_modules/react-router/lib/getComponents.js","./isActive":"node_modules/react-router/lib/isActive.js","./matchRoutes":"node_modules/react-router/lib/matchRoutes.js","./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js","history/lib/Actions":"node_modules/history/lib/Actions.js"}},{"id":"node_modules/react-router/lib/deprecateObjectProperties.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\nvar canUseMembrane = false;\n\nexports.canUseMembrane = canUseMembrane;\n// No-op by default.\nvar deprecateObjectProperties = function deprecateObjectProperties(object) {\n  return object;\n};\n\nif (process.env.NODE_ENV !== 'production') {\n  try {\n    if (Object.defineProperty({}, 'x', { get: function get() {\n        return true;\n      } }).x) {\n      exports.canUseMembrane = canUseMembrane = true;\n    }\n    /* eslint-disable no-empty */\n  } catch (e) {}\n  /* eslint-enable no-empty */\n\n  if (canUseMembrane) {\n    deprecateObjectProperties = function (object, message) {\n      // Wrap the deprecated object in a membrane to warn on property access.\n      var membrane = {};\n\n      var _loop = function (prop) {\n        if (!Object.prototype.hasOwnProperty.call(object, prop)) {\n          return 'continue';\n        }\n\n        if (typeof object[prop] === 'function') {\n          // Can't use fat arrow here because of use of arguments below.\n          membrane[prop] = function () {\n            process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, message) : undefined;\n            return object[prop].apply(object, arguments);\n          };\n          return 'continue';\n        }\n\n        // These properties are non-enumerable to prevent React dev tools from\n        // seeing them and causing spurious warnings when accessing them. In\n        // principle this could be done with a proxy, but support for the\n        // ownKeys trap on proxies is not universal, even among browsers that\n        // otherwise support proxies.\n        Object.defineProperty(membrane, prop, {\n          get: function get() {\n            process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, message) : undefined;\n            return object[prop];\n          }\n        });\n      };\n\n      for (var prop in object) {\n        var _ret = _loop(prop);\n\n        if (_ret === 'continue') continue;\n      }\n\n      return membrane;\n    };\n  }\n}\n\nexports['default'] = deprecateObjectProperties;\n}).call(this,require('_process'))","deps":{"./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js"}},{"id":"node_modules/react-router/lib/getComponents.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _AsyncUtils = require('./AsyncUtils');\n\nvar _deprecateObjectProperties = require('./deprecateObjectProperties');\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\nfunction getComponentsForRoute(nextState, route, callback) {\n  if (route.component || route.components) {\n    callback(null, route.component || route.components);\n    return;\n  }\n\n  var getComponent = route.getComponent || route.getComponents;\n  if (!getComponent) {\n    callback();\n    return;\n  }\n\n  var location = nextState.location;\n\n  var nextStateWithLocation = undefined;\n\n  if (process.env.NODE_ENV !== 'production' && _deprecateObjectProperties.canUseMembrane) {\n    nextStateWithLocation = _extends({}, nextState);\n\n    // I don't use deprecateObjectProperties here because I want to keep the\n    // same code path between development and production, in that we just\n    // assign extra properties to the copy of the state object in both cases.\n\n    var _loop = function (prop) {\n      if (!Object.prototype.hasOwnProperty.call(location, prop)) {\n        return 'continue';\n      }\n\n      Object.defineProperty(nextStateWithLocation, prop, {\n        get: function get() {\n          process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, 'Accessing location properties from the first argument to `getComponent` and `getComponents` is deprecated. That argument is now the router state (`nextState`) rather than the location. To access the location, use `nextState.location`.') : undefined;\n          return location[prop];\n        }\n      });\n    };\n\n    for (var prop in location) {\n      var _ret = _loop(prop);\n\n      if (_ret === 'continue') continue;\n    }\n  } else {\n    nextStateWithLocation = _extends({}, nextState, location);\n  }\n\n  getComponent.call(route, nextStateWithLocation, callback);\n}\n\n/**\n * Asynchronously fetches all components needed for the given router\n * state and calls callback(error, components) when finished.\n *\n * Note: This operation may finish synchronously if no routes have an\n * asynchronous getComponents method.\n */\nfunction getComponents(nextState, callback) {\n  _AsyncUtils.mapAsync(nextState.routes, function (route, index, callback) {\n    getComponentsForRoute(nextState, route, callback);\n  }, callback);\n}\n\nexports['default'] = getComponents;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./AsyncUtils":"node_modules/react-router/lib/AsyncUtils.js","./deprecateObjectProperties":"node_modules/react-router/lib/deprecateObjectProperties.js","./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js"}},{"id":"node_modules/react-router/lib/getRouteParams.js","source":"'use strict';\n\nexports.__esModule = true;\n\nvar _PatternUtils = require('./PatternUtils');\n\n/**\n * Extracts an object of params the given route cares about from\n * the given params object.\n */\nfunction getRouteParams(route, params) {\n  var routeParams = {};\n\n  if (!route.path) return routeParams;\n\n  var paramNames = _PatternUtils.getParamNames(route.path);\n\n  for (var p in params) {\n    if (Object.prototype.hasOwnProperty.call(params, p) && paramNames.indexOf(p) !== -1) {\n      routeParams[p] = params[p];\n    }\n  }\n\n  return routeParams;\n}\n\nexports['default'] = getRouteParams;\nmodule.exports = exports['default'];","deps":{"./PatternUtils":"node_modules/react-router/lib/PatternUtils.js"}},{"id":"node_modules/react-router/lib/hashHistory.js","source":"'use strict';\n\nexports.__esModule = true;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _historyLibCreateHashHistory = require('history/lib/createHashHistory');\n\nvar _historyLibCreateHashHistory2 = _interopRequireDefault(_historyLibCreateHashHistory);\n\nvar _createRouterHistory = require('./createRouterHistory');\n\nvar _createRouterHistory2 = _interopRequireDefault(_createRouterHistory);\n\nexports['default'] = _createRouterHistory2['default'](_historyLibCreateHashHistory2['default']);\nmodule.exports = exports['default'];","deps":{"./createRouterHistory":"node_modules/react-router/lib/createRouterHistory.js","history/lib/createHashHistory":"node_modules/history/lib/createHashHistory.js"}},{"id":"node_modules/react-router/lib/index.js","source":"'use strict';\n\nexports.__esModule = true;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _Router2 = require('./Router');\n\nvar _Router3 = _interopRequireDefault(_Router2);\n\nexports.Router = _Router3['default'];\n\nvar _Link2 = require('./Link');\n\nvar _Link3 = _interopRequireDefault(_Link2);\n\nexports.Link = _Link3['default'];\n\nvar _IndexLink2 = require('./IndexLink');\n\nvar _IndexLink3 = _interopRequireDefault(_IndexLink2);\n\nexports.IndexLink = _IndexLink3['default'];\n\n/* components (configuration) */\n\nvar _IndexRedirect2 = require('./IndexRedirect');\n\nvar _IndexRedirect3 = _interopRequireDefault(_IndexRedirect2);\n\nexports.IndexRedirect = _IndexRedirect3['default'];\n\nvar _IndexRoute2 = require('./IndexRoute');\n\nvar _IndexRoute3 = _interopRequireDefault(_IndexRoute2);\n\nexports.IndexRoute = _IndexRoute3['default'];\n\nvar _Redirect2 = require('./Redirect');\n\nvar _Redirect3 = _interopRequireDefault(_Redirect2);\n\nexports.Redirect = _Redirect3['default'];\n\nvar _Route2 = require('./Route');\n\nvar _Route3 = _interopRequireDefault(_Route2);\n\nexports.Route = _Route3['default'];\n\n/* mixins */\n\nvar _History2 = require('./History');\n\nvar _History3 = _interopRequireDefault(_History2);\n\nexports.History = _History3['default'];\n\nvar _Lifecycle2 = require('./Lifecycle');\n\nvar _Lifecycle3 = _interopRequireDefault(_Lifecycle2);\n\nexports.Lifecycle = _Lifecycle3['default'];\n\nvar _RouteContext2 = require('./RouteContext');\n\nvar _RouteContext3 = _interopRequireDefault(_RouteContext2);\n\nexports.RouteContext = _RouteContext3['default'];\n\n/* utils */\n\nvar _useRoutes2 = require('./useRoutes');\n\nvar _useRoutes3 = _interopRequireDefault(_useRoutes2);\n\nexports.useRoutes = _useRoutes3['default'];\n\nvar _RouteUtils = require('./RouteUtils');\n\nexports.createRoutes = _RouteUtils.createRoutes;\n\nvar _RouterContext2 = require('./RouterContext');\n\nvar _RouterContext3 = _interopRequireDefault(_RouterContext2);\n\nexports.RouterContext = _RouterContext3['default'];\n\nvar _RoutingContext2 = require('./RoutingContext');\n\nvar _RoutingContext3 = _interopRequireDefault(_RoutingContext2);\n\nexports.RoutingContext = _RoutingContext3['default'];\n\nvar _PropTypes2 = require('./PropTypes');\n\nvar _PropTypes3 = _interopRequireDefault(_PropTypes2);\n\nexports.PropTypes = _PropTypes3['default'];\nexports.locationShape = _PropTypes2.locationShape;\nexports.routerShape = _PropTypes2.routerShape;\n\nvar _match2 = require('./match');\n\nvar _match3 = _interopRequireDefault(_match2);\n\nexports.match = _match3['default'];\n\nvar _useRouterHistory2 = require('./useRouterHistory');\n\nvar _useRouterHistory3 = _interopRequireDefault(_useRouterHistory2);\n\nexports.useRouterHistory = _useRouterHistory3['default'];\n\nvar _PatternUtils = require('./PatternUtils');\n\nexports.formatPattern = _PatternUtils.formatPattern;\n\nvar _applyRouterMiddleware2 = require('./applyRouterMiddleware');\n\nvar _applyRouterMiddleware3 = _interopRequireDefault(_applyRouterMiddleware2);\n\nexports.applyRouterMiddleware = _applyRouterMiddleware3['default'];\n\n/* histories */\n\nvar _browserHistory2 = require('./browserHistory');\n\nvar _browserHistory3 = _interopRequireDefault(_browserHistory2);\n\nexports.browserHistory = _browserHistory3['default'];\n\nvar _hashHistory2 = require('./hashHistory');\n\nvar _hashHistory3 = _interopRequireDefault(_hashHistory2);\n\nexports.hashHistory = _hashHistory3['default'];\n\nvar _createMemoryHistory2 = require('./createMemoryHistory');\n\nvar _createMemoryHistory3 = _interopRequireDefault(_createMemoryHistory2);\n\nexports.createMemoryHistory = _createMemoryHistory3['default'];","deps":{"./History":"node_modules/react-router/lib/History.js","./IndexLink":"node_modules/react-router/lib/IndexLink.js","./IndexRedirect":"node_modules/react-router/lib/IndexRedirect.js","./IndexRoute":"node_modules/react-router/lib/IndexRoute.js","./Lifecycle":"node_modules/react-router/lib/Lifecycle.js","./Link":"node_modules/react-router/lib/Link.js","./PatternUtils":"node_modules/react-router/lib/PatternUtils.js","./PropTypes":"node_modules/react-router/lib/PropTypes.js","./Redirect":"node_modules/react-router/lib/Redirect.js","./Route":"node_modules/react-router/lib/Route.js","./RouteContext":"node_modules/react-router/lib/RouteContext.js","./RouteUtils":"node_modules/react-router/lib/RouteUtils.js","./Router":"node_modules/react-router/lib/Router.js","./RouterContext":"node_modules/react-router/lib/RouterContext.js","./RoutingContext":"node_modules/react-router/lib/RoutingContext.js","./applyRouterMiddleware":"node_modules/react-router/lib/applyRouterMiddleware.js","./browserHistory":"node_modules/react-router/lib/browserHistory.js","./createMemoryHistory":"node_modules/react-router/lib/createMemoryHistory.js","./hashHistory":"node_modules/react-router/lib/hashHistory.js","./match":"node_modules/react-router/lib/match.js","./useRouterHistory":"node_modules/react-router/lib/useRouterHistory.js","./useRoutes":"node_modules/react-router/lib/useRoutes.js"}},{"id":"node_modules/react-router/lib/isActive.js","source":"'use strict';\n\nexports.__esModule = true;\nexports['default'] = isActive;\n\nvar _PatternUtils = require('./PatternUtils');\n\nfunction deepEqual(a, b) {\n  if (a == b) return true;\n\n  if (a == null || b == null) return false;\n\n  if (Array.isArray(a)) {\n    return Array.isArray(b) && a.length === b.length && a.every(function (item, index) {\n      return deepEqual(item, b[index]);\n    });\n  }\n\n  if (typeof a === 'object') {\n    for (var p in a) {\n      if (!Object.prototype.hasOwnProperty.call(a, p)) {\n        continue;\n      }\n\n      if (a[p] === undefined) {\n        if (b[p] !== undefined) {\n          return false;\n        }\n      } else if (!Object.prototype.hasOwnProperty.call(b, p)) {\n        return false;\n      } else if (!deepEqual(a[p], b[p])) {\n        return false;\n      }\n    }\n\n    return true;\n  }\n\n  return String(a) === String(b);\n}\n\n/**\n * Returns true if the current pathname matches the supplied one, net of\n * leading and trailing slash normalization. This is sufficient for an\n * indexOnly route match.\n */\nfunction pathIsActive(pathname, currentPathname) {\n  // Normalize leading slash for consistency. Leading slash on pathname has\n  // already been normalized in isActive. See caveat there.\n  if (currentPathname.charAt(0) !== '/') {\n    currentPathname = '/' + currentPathname;\n  }\n\n  // Normalize the end of both path names too. Maybe `/foo/` shouldn't show\n  // `/foo` as active, but in this case, we would already have failed the\n  // match.\n  if (pathname.charAt(pathname.length - 1) !== '/') {\n    pathname += '/';\n  }\n  if (currentPathname.charAt(currentPathname.length - 1) !== '/') {\n    currentPathname += '/';\n  }\n\n  return currentPathname === pathname;\n}\n\n/**\n * Returns true if the given pathname matches the active routes and params.\n */\nfunction routeIsActive(pathname, routes, params) {\n  var remainingPathname = pathname,\n      paramNames = [],\n      paramValues = [];\n\n  // for...of would work here but it's probably slower post-transpilation.\n  for (var i = 0, len = routes.length; i < len; ++i) {\n    var route = routes[i];\n    var pattern = route.path || '';\n\n    if (pattern.charAt(0) === '/') {\n      remainingPathname = pathname;\n      paramNames = [];\n      paramValues = [];\n    }\n\n    if (remainingPathname !== null && pattern) {\n      var matched = _PatternUtils.matchPattern(pattern, remainingPathname);\n      remainingPathname = matched.remainingPathname;\n      paramNames = [].concat(paramNames, matched.paramNames);\n      paramValues = [].concat(paramValues, matched.paramValues);\n\n      if (remainingPathname === '') {\n        // We have an exact match on the route. Just check that all the params\n        // match.\n        // FIXME: This doesn't work on repeated params.\n        return paramNames.every(function (paramName, index) {\n          return String(paramValues[index]) === String(params[paramName]);\n        });\n      }\n    }\n  }\n\n  return false;\n}\n\n/**\n * Returns true if all key/value pairs in the given query are\n * currently active.\n */\nfunction queryIsActive(query, activeQuery) {\n  if (activeQuery == null) return query == null;\n\n  if (query == null) return true;\n\n  return deepEqual(query, activeQuery);\n}\n\n/**\n * Returns true if a <Link> to the given pathname/query combination is\n * currently active.\n */\n\nfunction isActive(_ref, indexOnly, currentLocation, routes, params) {\n  var pathname = _ref.pathname;\n  var query = _ref.query;\n\n  if (currentLocation == null) return false;\n\n  // TODO: This is a bit ugly. It keeps around support for treating pathnames\n  // without preceding slashes as absolute paths, but possibly also works\n  // around the same quirks with basenames as in matchRoutes.\n  if (pathname.charAt(0) !== '/') {\n    pathname = '/' + pathname;\n  }\n\n  if (!pathIsActive(pathname, currentLocation.pathname)) {\n    // The path check is necessary and sufficient for indexOnly, but otherwise\n    // we still need to check the routes.\n    if (indexOnly || !routeIsActive(pathname, routes, params)) {\n      return false;\n    }\n  }\n\n  return queryIsActive(query, currentLocation.query);\n}\n\nmodule.exports = exports['default'];","deps":{"./PatternUtils":"node_modules/react-router/lib/PatternUtils.js"}},{"id":"node_modules/react-router/lib/match.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nfunction _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }\n\nvar _invariant = require('invariant');\n\nvar _invariant2 = _interopRequireDefault(_invariant);\n\nvar _createMemoryHistory = require('./createMemoryHistory');\n\nvar _createMemoryHistory2 = _interopRequireDefault(_createMemoryHistory);\n\nvar _createTransitionManager = require('./createTransitionManager');\n\nvar _createTransitionManager2 = _interopRequireDefault(_createTransitionManager);\n\nvar _RouteUtils = require('./RouteUtils');\n\nvar _RouterUtils = require('./RouterUtils');\n\n/**\n * A high-level API to be used for server-side rendering.\n *\n * This function matches a location to a set of routes and calls\n * callback(error, redirectLocation, renderProps) when finished.\n *\n * Note: You probably don't want to use this in a browser unless you're using\n * server-side rendering with async routes.\n */\nfunction match(_ref, callback) {\n  var history = _ref.history;\n  var routes = _ref.routes;\n  var location = _ref.location;\n\n  var options = _objectWithoutProperties(_ref, ['history', 'routes', 'location']);\n\n  !(history || location) ? process.env.NODE_ENV !== 'production' ? _invariant2['default'](false, 'match needs a history or a location') : _invariant2['default'](false) : undefined;\n\n  history = history ? history : _createMemoryHistory2['default'](options);\n  var transitionManager = _createTransitionManager2['default'](history, _RouteUtils.createRoutes(routes));\n\n  var unlisten = undefined;\n\n  if (location) {\n    // Allow match({ location: '/the/path', ... })\n    location = history.createLocation(location);\n  } else {\n    // Pick up the location from the history via synchronous history.listen\n    // call if needed.\n    unlisten = history.listen(function (historyLocation) {\n      location = historyLocation;\n    });\n  }\n\n  var router = _RouterUtils.createRouterObject(history, transitionManager);\n  history = _RouterUtils.createRoutingHistory(history, transitionManager);\n\n  transitionManager.match(location, function (error, redirectLocation, nextState) {\n    callback(error, redirectLocation, nextState && _extends({}, nextState, {\n      history: history,\n      router: router,\n      matchContext: { history: history, transitionManager: transitionManager, router: router }\n    }));\n\n    // Defer removing the listener to here to prevent DOM histories from having\n    // to unwind DOM event listeners unnecessarily, in case callback renders a\n    // <Router> and attaches another history listener.\n    if (unlisten) {\n      unlisten();\n    }\n  });\n}\n\nexports['default'] = match;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./RouteUtils":"node_modules/react-router/lib/RouteUtils.js","./RouterUtils":"node_modules/react-router/lib/RouterUtils.js","./createMemoryHistory":"node_modules/react-router/lib/createMemoryHistory.js","./createTransitionManager":"node_modules/react-router/lib/createTransitionManager.js","_process":"node_modules/process/browser.js","invariant":"node_modules/invariant/browser.js"}},{"id":"node_modules/react-router/lib/matchRoutes.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nexports['default'] = matchRoutes;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\nvar _AsyncUtils = require('./AsyncUtils');\n\nvar _PatternUtils = require('./PatternUtils');\n\nvar _RouteUtils = require('./RouteUtils');\n\nfunction getChildRoutes(route, location, callback) {\n  if (route.childRoutes) {\n    return [null, route.childRoutes];\n  }\n  if (!route.getChildRoutes) {\n    return [];\n  }\n\n  var sync = true,\n      result = undefined;\n\n  route.getChildRoutes(location, function (error, childRoutes) {\n    childRoutes = !error && _RouteUtils.createRoutes(childRoutes);\n    if (sync) {\n      result = [error, childRoutes];\n      return;\n    }\n\n    callback(error, childRoutes);\n  });\n\n  sync = false;\n  return result; // Might be undefined.\n}\n\nfunction getIndexRoute(route, location, callback) {\n  if (route.indexRoute) {\n    callback(null, route.indexRoute);\n  } else if (route.getIndexRoute) {\n    route.getIndexRoute(location, function (error, indexRoute) {\n      callback(error, !error && _RouteUtils.createRoutes(indexRoute)[0]);\n    });\n  } else if (route.childRoutes) {\n    (function () {\n      var pathless = route.childRoutes.filter(function (childRoute) {\n        return !childRoute.path;\n      });\n\n      _AsyncUtils.loopAsync(pathless.length, function (index, next, done) {\n        getIndexRoute(pathless[index], location, function (error, indexRoute) {\n          if (error || indexRoute) {\n            var routes = [pathless[index]].concat(Array.isArray(indexRoute) ? indexRoute : [indexRoute]);\n            done(error, routes);\n          } else {\n            next();\n          }\n        });\n      }, function (err, routes) {\n        callback(null, routes);\n      });\n    })();\n  } else {\n    callback();\n  }\n}\n\nfunction assignParams(params, paramNames, paramValues) {\n  return paramNames.reduce(function (params, paramName, index) {\n    var paramValue = paramValues && paramValues[index];\n\n    if (Array.isArray(params[paramName])) {\n      params[paramName].push(paramValue);\n    } else if (paramName in params) {\n      params[paramName] = [params[paramName], paramValue];\n    } else {\n      params[paramName] = paramValue;\n    }\n\n    return params;\n  }, params);\n}\n\nfunction createParams(paramNames, paramValues) {\n  return assignParams({}, paramNames, paramValues);\n}\n\nfunction matchRouteDeep(route, location, remainingPathname, paramNames, paramValues, callback) {\n  var pattern = route.path || '';\n\n  if (pattern.charAt(0) === '/') {\n    remainingPathname = location.pathname;\n    paramNames = [];\n    paramValues = [];\n  }\n\n  // Only try to match the path if the route actually has a pattern, and if\n  // we're not just searching for potential nested absolute paths.\n  if (remainingPathname !== null && pattern) {\n    var matched = _PatternUtils.matchPattern(pattern, remainingPathname);\n    remainingPathname = matched.remainingPathname;\n    paramNames = [].concat(paramNames, matched.paramNames);\n    paramValues = [].concat(paramValues, matched.paramValues);\n\n    // By assumption, pattern is non-empty here, which is the prerequisite for\n    // actually terminating a match.\n    if (remainingPathname === '') {\n      var _ret2 = (function () {\n        var match = {\n          routes: [route],\n          params: createParams(paramNames, paramValues)\n        };\n\n        getIndexRoute(route, location, function (error, indexRoute) {\n          if (error) {\n            callback(error);\n          } else {\n            if (Array.isArray(indexRoute)) {\n              var _match$routes;\n\n              process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](indexRoute.every(function (route) {\n                return !route.path;\n              }), 'Index routes should not have paths') : undefined;\n              (_match$routes = match.routes).push.apply(_match$routes, indexRoute);\n            } else if (indexRoute) {\n              process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](!indexRoute.path, 'Index routes should not have paths') : undefined;\n              match.routes.push(indexRoute);\n            }\n\n            callback(null, match);\n          }\n        });\n\n        return {\n          v: undefined\n        };\n      })();\n\n      if (typeof _ret2 === 'object') return _ret2.v;\n    }\n  }\n\n  if (remainingPathname != null || route.childRoutes) {\n    // Either a) this route matched at least some of the path or b)\n    // we don't have to load this route's children asynchronously. In\n    // either case continue checking for matches in the subtree.\n    var onChildRoutes = function onChildRoutes(error, childRoutes) {\n      if (error) {\n        callback(error);\n      } else if (childRoutes) {\n        // Check the child routes to see if any of them match.\n        matchRoutes(childRoutes, location, function (error, match) {\n          if (error) {\n            callback(error);\n          } else if (match) {\n            // A child route matched! Augment the match and pass it up the stack.\n            match.routes.unshift(route);\n            callback(null, match);\n          } else {\n            callback();\n          }\n        }, remainingPathname, paramNames, paramValues);\n      } else {\n        callback();\n      }\n    };\n\n    var result = getChildRoutes(route, location, onChildRoutes);\n    if (result) {\n      onChildRoutes.apply(undefined, result);\n    }\n  } else {\n    callback();\n  }\n}\n\n/**\n * Asynchronously matches the given location to a set of routes and calls\n * callback(error, state) when finished. The state object will have the\n * following properties:\n *\n * - routes       An array of routes that matched, in hierarchical order\n * - params       An object of URL parameters\n *\n * Note: This operation may finish synchronously if no routes have an\n * asynchronous getChildRoutes method.\n */\n\nfunction matchRoutes(routes, location, callback, remainingPathname) {\n  var paramNames = arguments.length <= 4 || arguments[4] === undefined ? [] : arguments[4];\n  var paramValues = arguments.length <= 5 || arguments[5] === undefined ? [] : arguments[5];\n\n  if (remainingPathname === undefined) {\n    // TODO: This is a little bit ugly, but it works around a quirk in history\n    // that strips the leading slash from pathnames when using basenames with\n    // trailing slashes.\n    if (location.pathname.charAt(0) !== '/') {\n      location = _extends({}, location, {\n        pathname: '/' + location.pathname\n      });\n    }\n    remainingPathname = location.pathname;\n  }\n\n  _AsyncUtils.loopAsync(routes.length, function (index, next, done) {\n    matchRouteDeep(routes[index], location, remainingPathname, paramNames, paramValues, function (error, match) {\n      if (error || match) {\n        done(error, match);\n      } else {\n        next();\n      }\n    });\n  }, callback);\n}\n\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./AsyncUtils":"node_modules/react-router/lib/AsyncUtils.js","./PatternUtils":"node_modules/react-router/lib/PatternUtils.js","./RouteUtils":"node_modules/react-router/lib/RouteUtils.js","./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js"}},{"id":"node_modules/react-router/lib/routerWarning.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\nexports['default'] = routerWarning;\nexports._resetWarned = _resetWarned;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _warning = require('warning');\n\nvar _warning2 = _interopRequireDefault(_warning);\n\nvar warned = {};\n\nfunction routerWarning(falseToWarn, message) {\n  // Only issue deprecation warnings once.\n  if (message.indexOf('deprecated') !== -1) {\n    if (warned[message]) {\n      return;\n    }\n\n    warned[message] = true;\n  }\n\n  message = '[react-router] ' + message;\n\n  for (var _len = arguments.length, args = Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {\n    args[_key - 2] = arguments[_key];\n  }\n\n  process.env.NODE_ENV !== 'production' ? _warning2['default'].apply(undefined, [falseToWarn, message].concat(args)) : undefined;\n}\n\nfunction _resetWarned() {\n  warned = {};\n}\n}).call(this,require('_process'))","deps":{"_process":"node_modules/process/browser.js","warning":"node_modules/warning/browser.js"}},{"id":"node_modules/react-router/lib/useRouterHistory.js","source":"'use strict';\n\nexports.__esModule = true;\nexports['default'] = useRouterHistory;\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nvar _historyLibUseQueries = require('history/lib/useQueries');\n\nvar _historyLibUseQueries2 = _interopRequireDefault(_historyLibUseQueries);\n\nvar _historyLibUseBasename = require('history/lib/useBasename');\n\nvar _historyLibUseBasename2 = _interopRequireDefault(_historyLibUseBasename);\n\nfunction useRouterHistory(createHistory) {\n  return function (options) {\n    var history = _historyLibUseQueries2['default'](_historyLibUseBasename2['default'](createHistory))(options);\n    history.__v2_compatible__ = true;\n    return history;\n  };\n}\n\nmodule.exports = exports['default'];","deps":{"history/lib/useBasename":"node_modules/history/lib/useBasename.js","history/lib/useQueries":"node_modules/history/lib/useQueries.js"}},{"id":"node_modules/react-router/lib/useRoutes.js","source":"(function (process){\n'use strict';\n\nexports.__esModule = true;\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }\n\nfunction _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }\n\nvar _historyLibUseQueries = require('history/lib/useQueries');\n\nvar _historyLibUseQueries2 = _interopRequireDefault(_historyLibUseQueries);\n\nvar _createTransitionManager = require('./createTransitionManager');\n\nvar _createTransitionManager2 = _interopRequireDefault(_createTransitionManager);\n\nvar _routerWarning = require('./routerWarning');\n\nvar _routerWarning2 = _interopRequireDefault(_routerWarning);\n\n/**\n * Returns a new createHistory function that may be used to create\n * history objects that know about routing.\n *\n * Enhances history objects with the following methods:\n *\n * - listen((error, nextState) => {})\n * - listenBeforeLeavingRoute(route, (nextLocation) => {})\n * - match(location, (error, redirectLocation, nextState) => {})\n * - isActive(pathname, query, indexOnly=false)\n */\nfunction useRoutes(createHistory) {\n  process.env.NODE_ENV !== 'production' ? _routerWarning2['default'](false, '`useRoutes` is deprecated. Please use `createTransitionManager` instead.') : undefined;\n\n  return function () {\n    var _ref = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];\n\n    var routes = _ref.routes;\n\n    var options = _objectWithoutProperties(_ref, ['routes']);\n\n    var history = _historyLibUseQueries2['default'](createHistory)(options);\n    var transitionManager = _createTransitionManager2['default'](history, routes);\n    return _extends({}, history, transitionManager);\n  };\n}\n\nexports['default'] = useRoutes;\nmodule.exports = exports['default'];\n}).call(this,require('_process'))","deps":{"./createTransitionManager":"node_modules/react-router/lib/createTransitionManager.js","./routerWarning":"node_modules/react-router/lib/routerWarning.js","_process":"node_modules/process/browser.js","history/lib/useQueries":"node_modules/history/lib/useQueries.js"}},{"id":"node_modules/react/react.js","source":"module.exports = require('@jenkins-cd/js-modules').requireModule('react:react@any');","deps":{"@jenkins-cd/js-modules":"node_modules/@jenkins-cd/js-modules/js/index.js"}},{"id":"node_modules/strict-uri-encode/index.js","source":"'use strict';\nmodule.exports = function (str) {\n\treturn encodeURIComponent(str).replace(/[!'()*]/g, function (c) {\n\t\treturn '%' + c.charCodeAt(0).toString(16).toUpperCase();\n\t});\n};","deps":{}},{"id":"node_modules/warning/browser.js","source":"'use strict';\n\n/**\n * Similar to invariant but only logs a warning if the condition is not met.\n * This can be used to log issues in development environments in critical\n * paths. Removing the logging code for production environments will keep the\n * same logic and follow the same code paths.\n */\n\nvar warning = function() {};\n\nif (\"production\" !== 'production') {\n  warning = function(condition, format, args) {\n    var len = arguments.length;\n    args = new Array(len > 2 ? len - 2 : 0);\n    for (var key = 2; key < len; key++) {\n      args[key - 2] = arguments[key];\n    }\n    if (format === undefined) {\n      throw new Error(\n        '`warning(condition, format, ...args)` requires a warning ' +\n        'message argument'\n      );\n    }\n\n    if (format.length < 10 || (/^[s\\W]*$/).test(format)) {\n      throw new Error(\n        'The warning format should be able to uniquely identify this ' +\n        'warning. Please, use a more descriptive format than: ' + format\n      );\n    }\n\n    if (!condition) {\n      var argIndex = 0;\n      var message = 'Warning: ' +\n        format.replace(/%s/g, function() {\n          return args[argIndex++];\n        });\n      if (typeof console !== 'undefined') {\n        console.error(message);\n      }\n      try {\n        // This error was thrown as a convenience so that you can use this stack\n        // to find the callsite that caused this warning to fire.\n        throw new Error(message);\n      } catch(x) {}\n    }\n  };\n}\n\nmodule.exports = warning;","deps":{}},{"id":"target/js-bundle-src/react-router-2-3-0.js","source":"var ___$$$___requiredModuleMappings = [\"react:react@15.3.2\",\"react:react@any\"];\n\nvar ___$$$___jsModules = require('@jenkins-cd/js-modules');\n\nif (!window.jenkinsCIGlobal) {\n    window.jenkinsCIGlobal = {};\n}\nif (!window.jenkinsCIGlobal._internal) {\n    window.jenkinsCIGlobal._internal = {};\n}\n\nvar whoami = 'react-router-2-3-0';\nvar loadTimestamp = Date.now();\n\n___$$$___jsModules.whoami(whoami);\n\n// Clear out the session storage if this is the first\n// bundle to export on the page.\nvar trackKeyPrefix = 'jenkins-cd/js-modules/tracking/';\nif (window.sessionStorage && !jenkinsCIGlobal._internal.bundleLoadIdx) {\n    jenkinsCIGlobal._internal.bundleLoadIdx = 0;\n    var toRemove = [];\n    for (var i = 0; i < sessionStorage.length; i++) {\n        var key = sessionStorage.key(i);\n        if (key.indexOf(trackKeyPrefix) === 0) {\n            toRemove.push(key);\n        }\n    }\n    for (var i = 0; i < toRemove.length; i++) {\n        sessionStorage.removeItem(toRemove[i]);\n    }\n}\njenkinsCIGlobal._internal.bundleLoadIdx++;\n\nif (window.sessionStorage) {\n    sessionStorage.setItem(trackKeyPrefix + 'load:' + whoami, JSON.stringify({\n        event: 'load',\n        bundleId: whoami,\n        bundlePath: 'target/classes/org/jenkins/ui/jsmodules/react-router/react-router-2-3-0.js',\n        at: loadTimestamp,\n        loadIdx: jenkinsCIGlobal._internal.bundleLoadIdx\n    }));\n}\n\nfunction ___$$$___doExport(namespace, moduleName, module) {\n    var exportedModuleId = (namespace !== undefined ? (namespace + ':' + moduleName) : moduleName);\n    try {\n        ___$$$___jsModules.requireModule(exportedModuleId);\n        // No exception => already exported. Shouldn't happen, but okay !!\n        return;\n    } catch (e) {\n        // Not exported yet, hence exception on require. Okay to export !!\n        ___$$$___jsModules.exportModule(namespace, moduleName, module);\n        if (window.sessionStorage) {\n            sessionStorage.setItem(trackKeyPrefix + 'export:' + exportedModuleId, JSON.stringify({\n                event: 'export',\n                moduleId: exportedModuleId,\n                at: loadTimestamp,\n                bundleId: whoami\n            }));\n        }\n    }\n}\n\n/*** Start Module Exec Function ***************************************/\nfunction ___$$$___exec(onExec) {\n    'use strict';\n\n//\n// NOTE: This file is generated and should NOT be added to source control.\n//\n\n___$$$___doExport('react-router', 'react-router@2.3.0', require('react-router'));\n___$$$___doExport('react-router', 'react-router@2.3.x', require('react-router'));\n___$$$___doExport('react-router', 'react-router@2.x', require('react-router'));\n___$$$___doExport('react-router', 'react-router@any', require('react-router'));\n\n    onExec();\n}\n/*** End Module Exec Function   ***************************************/\n\nfunction ___$$$___doExports() {\n    // Do exports, if any ....\n    \n\n}\n\nfunction ___$$$___doCSS() {\n}\n\nfunction ___$$$___doBundleInit() {\n    try {\n        ___$$$___exec(function() {\n            ___$$$___doExports();\n            ___$$$___doCSS();\n        });\n    } catch (e) {\n        console.error('Error initializing Jenkins JavaScript bundle \"react-router-2-3-0\"', e);\n    }\n}\n\nif (___$$$___requiredModuleMappings.length > 0) {\n    ___$$$___jsModules.importModule.apply(___$$$___jsModules.importModule, ___$$$___requiredModuleMappings)\n        .onFulfilled(function() {\n        ___$$$___doBundleInit();\n    });\n} else {\n    ___$$$___doBundleInit();\n}","deps":{"@jenkins-cd/js-modules":"node_modules/@jenkins-cd/js-modules/js/index.js","react-router":"node_modules/react-router/lib/index.js"},"entry":true}]